@@ -41,7 +41,7 @@ import com.clustercontrol.repository.ejb.session.RepositoryController;
  * 
  * 管理対象ノードで起動する際に呼び出されるクラスです。
  * 
- * @version $Revision: 680 $
+ * @version $Revision:2230 $
  * @since 1.0.0
  */
 public class Agent {
@@ -73,12 +73,25 @@ public class Agent {
 	 * @param args プロパティファイル名
 	 */
 	public static void main(String[] args) throws Exception{
-
+		
+		log.info("starting Hinemos job agent...");
+		log.info("java.vm.version = " + System.getProperty("java.vm.version"));
+		log.info("java.vm.vendor = " + System.getProperty("java.vm.vendor"));
+		log.info("java.home = " + System.getProperty("java.home"));
+		log.info("os.name = " + System.getProperty("os.name"));
+		log.info("os.arch = " + System.getProperty("os.arch"));
+		// 起動ユーザを表示
+		log.info("user.name = " + System.getProperty("user.name"));
+		// 作業ディレクトリを表示
+		log.info("user.dir = " + System.getProperty("user.dir"));
+		
 		Agent agent = new Agent(args[0]);
-
+		
 		//エージェント処理開始
 		agent.exec();
-
+		
+		log.info("Hinemos job agent started");
+		
 		
 		//終了待ち
 		BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
@@ -95,7 +108,8 @@ public class Agent {
             } 
 		}
 		
-
+		
+		
 		//------------
 		//-- 終了処理
 		//------------
@@ -134,7 +148,7 @@ public class Agent {
 		}
 		
 		m_ejbConnectionManager = new EjbConnectionManager(m_props);
-		m_sendQueue = new SendQueue(m_props);
+		m_sendQueue = new SendQueue(this, m_props);
 
 		//終了呼び出し設定
     	Runtime.getRuntime().addShutdownHook(new Thread() {
@@ -161,7 +175,7 @@ public class Agent {
 
 		//自局のファシリティID取得
 
-		m_receiveTopic = new ReceiveTopic(getFacility(), m_sendQueue, m_props);
+		m_receiveTopic = new ReceiveTopic(this, getFacility(), m_sendQueue, m_props);
 		
 		m_updateRepository = new UpdateRepositoryInfoReceiveTopic(this, m_props);
 
@@ -273,6 +287,8 @@ public class Agent {
 		m_sendQueue.terminate();
 
 		m_timer.cancel();
+		
+		log.info("Hinemos job agent stopped");
 
 	}
 	
@@ -307,4 +323,21 @@ public class Agent {
 		m_receiveTopic.setFacilityIdList(getFacility());
 
 	}
+	
+	/**
+	 * 全てのTopicとQueueの再接続処理を行う
+	 * 
+	 */
+	synchronized public void reConnection() {
+		
+		log.info("Hinemos job agent reconnect start");
+		
+		m_receiveTopic.reconnect();
+		
+		m_updateRepository.reconnect();
+		
+		m_sendQueue.reconnect();
+		
+		log.info("Hinemos job agent reconnect end");
+	}
 }
