@@ -40,7 +40,6 @@ import javax.naming.InitialContext;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.agent.util.InternalLogger;
 import com.clustercontrol.agent.util.RunHistoryUtil;
 import com.clustercontrol.jobmanagement.bean.CommandConstant;
 import com.clustercontrol.jobmanagement.bean.CommandTypeConstant;
@@ -57,7 +56,7 @@ import com.clustercontrol.jobmanagement.message.RunResultInfo;
  * 
  * Topicでマネージャからのジョブ実行指示を受け取ります。
  * 
- * @version $Revision: 3158 $
+ * @version $Revision: 2485 $
  * @since 1.0.0
  * 
  */
@@ -67,6 +66,8 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
 	private static final String TOPIC_USER_NAME = "topic.user.name";
 	private static final String TOPIC_USER_PASSWORD = "topic.user.password";
 
+	protected Agent m_agent;
+	
 	protected ArrayList m_facilityIdList;
     protected SendQueue m_sendQueue;
     
@@ -82,24 +83,31 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
     protected TopicSubscriber m_subscriber;
 
 	private long RETRY_INTERVAL = 30000;
+	private long DELAY = -1;
     
 	private boolean m_errFlg = false;
+	private static boolean m_clearFlg = false;
 
 	/** メッセージサービス再接続用タイマー * */
 	protected static Timer m_timer = new Timer(true);
+	
+	/** 実行履歴削除用タイマー　**/
+	protected static Timer m_historyClearTimer = new Timer(true);
 
 	//ロガー
 	private static Log log = LogFactory.getLog(ReceiveTopic.class);
 	
 	/**
 	 * コンストラクタ
+	 * @param agent ジョブエージェント
 	 * @param facilityIdList ファシリティIDのリスト　
 	 * @param sendQueue　メッセージ送信用クラス
 	 * @param props　プロパティファイル情報
 	 */
 	@SuppressWarnings("unchecked")
-	public ReceiveTopic(Collection facilityIdList, SendQueue sendQueue, Properties props) {
+	public ReceiveTopic(Agent agent, Collection facilityIdList, SendQueue sendQueue, Properties props) {
 		super();
+		m_agent = agent;
 		m_facilityIdList = new ArrayList(facilityIdList);
 		m_sendQueue = sendQueue;
 		m_props = props;
@@ -116,6 +124,16 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
 			}
 		}
 		
+		// ジョブ実行履歴の削除実行時間を取得
+		String delay = m_props.getProperty("runhistory.clear.delay");
+		if (delay != null) {
+			try {
+				// プロパティファイルには秒で記述されているため、1000をかける
+				DELAY = Integer.parseInt(delay) * 1000;
+			} catch (NumberFormatException e) {
+				log.error("runhistory.clear.delay",e);
+			}
+		}
 		
 		//接続処理
         initial();
@@ -265,14 +283,9 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
      */
     public void onException(JMSException arg0) {
 
-    	log.error(arg0);
+    	log.error(arg0.getMessage(), arg0);
     	
-    	// syslogにログ出力
-		InternalLogger.error("hinemos_jobagent: A problem has been detected with the connection to MGR");
-    	
-        setErrFlg(true);
-        
-        terminate();
+    	m_agent.reConnection();
     }
 
     /**
@@ -284,6 +297,10 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
 
 			m_timer.schedule(new ReSetupTask(), RETRY_INTERVAL,
 					RETRY_INTERVAL);
+			// 履歴情報クリアのタイマーを起動する
+			if (DELAY >= 0) {
+				m_historyClearTimer.schedule(new RunHistoryClearTask(), DELAY);
+			}
 
 		}
 		m_errFlg = errFlg;
@@ -314,6 +331,8 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
 
 			//エラーフラグ解除
 			setErrFlg(false);
+			//履歴クリアフラグ解除
+			setClearFlg(false);
 
 
 		} else {
@@ -465,6 +484,37 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
 		return true;
 
 	}
+	
+	/**
+	 * 再接続処理を行う
+	 */
+	synchronized public void reconnect() {
+		
+        setErrFlg(true);
+        
+        terminate();
+        
+	}
+	
+	
+	
+	/**
+	 * clearFlgの設定
+	 * @param clearFlg
+	 */
+	synchronized private void setClearFlg(boolean clearFlg) {
+		m_clearFlg = clearFlg;
+	}
+	
+	/**
+	 * clearFlgの取得
+	 * @return
+	 */
+	synchronized static public boolean isHistoryClear(){
+		return m_clearFlg;
+	}
+	
+	
 	/**
 	 * EJB再接続タイマータスク
 	 * 通信エラーとなった場合に定周期で呼ばれ再接続を行う 
@@ -483,4 +533,24 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
 
 	}
 	
+	/**
+	 * ジョブ実行履歴削除タイマーマスク
+	 * 通信エラーとなった場合に、一定時間後、再度接続確認を行い、
+	 * 接続していない場合は、ジョブ履歴情報を削除する
+	 */
+	protected class RunHistoryClearTask extends TimerTask {
+		
+		public void run() {
+			// まだマネージャとの接続が回復していない場合
+			if (isErrFlg()) {
+				RunHistoryUtil.clearRunHistory(m_runHistory);
+				setClearFlg(true);
+				log.info("job history was deleted.");
+			}
+			
+			cancel();
+		}
+		
+	}
+	
 }
