@@ -33,9 +33,10 @@ import javax.naming.NamingException;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.jboss.jms.server.destination.SubscriptionInfo;
 import org.jboss.jmx.adaptor.rmi.RMIAdaptor;
-import org.jboss.mq.Subscription;
-import org.jboss.mq.selectors.Selector;
+//import org.jboss.mq.Subscription;
+//import org.jboss.mq.selectors.Selector;
 
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.YesNoConstant;
@@ -43,6 +44,7 @@ import com.clustercontrol.hinemosagent.ejb.entity.MonitorAgentInfoLocal;
 import com.clustercontrol.hinemosagent.ejb.entity.MonitorAgentInfoPK;
 import com.clustercontrol.hinemosagent.ejb.entity.MonitorAgentInfoUtil;
 import com.clustercontrol.monitor.run.bean.MonitorJudgementInfo;
+import com.clustercontrol.monitor.run.factory.RunMonitor;
 import com.clustercontrol.monitor.run.factory.RunMonitorTruthValueType;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.apllog.AplLogger;
@@ -58,8 +60,10 @@ public class RunMonitorAgent extends RunMonitorTruthValueType {
 	protected static Log m_log = LogFactory.getLog( RunMonitorAgent.class );
 
 	public static final String LOOKUP_NAME = "jmx/invoker/RMIAdaptor";
-	public static final String JOB_AGENT_OBJECT_NAME = "jboss.mq.destination:name=clustercontrol/JobManagement/execute,service=Topic";
-	public static final String LOG_AGENT_OBJECT_NAME = "jboss.mq.destination:name=clustercontrol/Logtransfer/update,service=Topic";
+	public static final String JOB_AGENT_OBJECT_NAME = "jboss.messaging.destination:name=clustercontrolJobManagementExecute,service=Topic";
+	public static final String LOG_AGENT_OBJECT_NAME = "jboss.messaging.destination:name=clustercontrolLogtransferUpdate,service=Topic";
+//	public static final String JOB_AGENT_OBJECT_NAME = "jboss.mq.destination:name=clustercontrol/JobManagement/execute,service=Topic";
+//	public static final String LOG_AGENT_OBJECT_NAME = "jboss.mq.destination:name=clustercontrol/Logtransfer/update,service=Topic";
 	public static final String OPERATION_NAME = "listAllSubscriptions";
 	
 	public static final String MESSAGE_ID_INFO = "001";
@@ -90,6 +94,17 @@ public class RunMonitorAgent extends RunMonitorTruthValueType {
 	public RunMonitorAgent() throws NamingException, JMSException, CreateException{
 		super();
 	}
+	
+	/**
+	 * マルチスレッドを実現するCallableTaskに渡すためのインスタンスを作成するメソッド
+	 * 
+	 * @see com.clustercontrol.monitor.run.factory.RunMonitor#runMonitorInfo()
+	 * @see com.clustercontrol.monitor.run.util.CallableTask
+	 */
+	public RunMonitor createMonitorInstance() throws NamingException, JMSException, CreateException{
+		return new RunMonitorAgent();
+	}
+	
 	/**
 	 * Hinemos ジョブエージェント・ログ転送エージェントをチェック
 	 * 
@@ -175,42 +190,73 @@ public class RunMonitorAgent extends RunMonitorTruthValueType {
 	        	HashMap<String, String> map = new HashMap<String, String>();
 	        	
 	        	for(int i = 0; i < ((List)returnObject).size(); i++){
-	        		//Subscription取得
-	        		Subscription subscription = (Subscription)((List)returnObject).get(i);
-	        		
-	        		try {
-	        			//SubscriptionからSelectorを取得
-	        			Selector selecter = subscription.getSelector();
+	        		//SubscriptionInfo取得
+	        		SubscriptionInfo subscription = (SubscriptionInfo)((List)returnObject).get(i);
+        			String selecter = subscription.getSelector();
 	        			
-	        			//Selectorとチェック文字列を比較
-		        		if(selecter != null && 
-		        				selecter.selector.indexOf(checkString) != -1){
-		        			//チャック文字列を含む場合
-		        			
-		        			//既に同じファシリティIDが存在しているかチェック
-		        			if(map.get(facilityId) == null){
-		        				//存在していない場合
-			        			m_valueJobAgent = true;
-			        			map.put(facilityId, facilityId);
-		        			}
-		        			else{
-		        				//存在している場合
-		        				m_valueJobAgent = false;
-		        				duplication = true;
-		        				
-		        				//イベントに出力
-		                        AplLogger apllog = new AplLogger("AGT","agt");
-		                        String[] args = {facilityId};
-		                        apllog.put("SYS","001", args);
-		                        
-		                        break;
-		        			}
-		        		}
-					} catch (InvalidSelectorException e) {
-						m_log.debug("collect() : " + e.getMessage());
-					}
+        			//Selectorとチェック文字列を比較
+	        		if(selecter != null && 
+	        				selecter.indexOf(checkString) != -1){
+	        			//チェック文字列を含む場合
+	        			//既に同じファシリティIDが存在しているかチェック
+	        			if(map.get(facilityId) == null){
+	        				//存在していない場合
+		        			m_valueJobAgent = true;
+		        			map.put(facilityId, facilityId);
+	        			}
+	        			else{
+	        				//存在している場合
+	        				m_valueJobAgent = false;
+	        				duplication = true;
+	        				
+	        				//イベントに出力
+	                        AplLogger apllog = new AplLogger("AGT","agt");
+	                        String[] args = {facilityId};
+	                        apllog.put("SYS","001", args);
+	                        
+	                        break;
+	        			}
+	        		}
 	        	}
 	        	
+//	        	for(int i = 0; i < ((List)returnObject).size(); i++){
+//	        		//Subscription取得
+//	        		Subscription subscription = (Subscription)((List)returnObject).get(i);
+//	        		
+//	        		try {
+//	        			//SubscriptionからSelectorを取得
+//	        			Selector selecter = subscription.getSelector();
+//	        			
+//	        			//Selectorとチェック文字列を比較
+//		        		if(selecter != null && 
+//		        				selecter.selector.indexOf(checkString) != -1){
+//		        			//チャック文字列を含む場合
+//		        			
+//		        			//既に同じファシリティIDが存在しているかチェック
+//		        			if(map.get(facilityId) == null){
+//		        				//存在していない場合
+//			        			m_valueJobAgent = true;
+//			        			map.put(facilityId, facilityId);
+//		        			}
+//		        			else{
+//		        				//存在している場合
+//		        				m_valueJobAgent = false;
+//		        				duplication = true;
+//		        				
+//		        				//イベントに出力
+//		                        AplLogger apllog = new AplLogger("AGT","agt");
+//		                        String[] args = {facilityId};
+//		                        apllog.put("SYS","001", args);
+//		                        
+//		                        break;
+//		        			}
+//		        		}
+//					} catch (InvalidSelectorException e) {
+//						m_log.debug("collect() : " + e.getMessage());
+//					}
+//	        	}
+	        	
+	        	
         		if(!duplication){
     	        	if(m_valueJobAgent){
     	        		//OK
@@ -294,42 +340,73 @@ public class RunMonitorAgent extends RunMonitorTruthValueType {
 	        	HashMap<String, String> map = new HashMap<String, String>();
 	        	
 	        	for(int i = 0; i < ((List)returnObject).size(); i++){
-	        		//Subscription取得
-	        		Subscription subscription = (Subscription)((List)returnObject).get(i);
-	        		
-	        		try {
-	        			//SubscriptionからSelectorを取得
-	        			Selector selecter = subscription.getSelector();
+	        		//SubscriptionInfo取得
+	        		SubscriptionInfo subscription = (SubscriptionInfo)((List)returnObject).get(i);
+        			String selecter = subscription.getSelector();
+        			
+        			//Selectorとチェック文字列を比較
+	        		if(selecter != null && 
+	        				selecter.indexOf(checkString) != -1){
+	        			//チャック文字列を含む場合
 	        			
-	        			//Selectorとチェック文字列を比較
-		        		if(selecter != null && 
-		        				selecter.selector.indexOf(checkString) != -1){
-		        			//チャック文字列を含む場合
-		        			
-		        			//既に同じファシリティIDが存在しているかチェック
-		        			if(map.get(facilityId) == null){
-		        				//存在していない場合
-			        			m_valueLogAgent = true;
-			        			map.put(facilityId, facilityId);
-		        			}
-		        			else{
-		        				//存在している場合
-		        				m_valueLogAgent = false;
-		        				duplication = true;
-		        				
-		        				//イベントに出力
-		                        AplLogger apllog = new AplLogger("AGT","agt");
-		                        String[] args = {facilityId};
-		                        apllog.put("SYS","002", args);
-		                        
-		                        break;
-		        			}
-		        		}
-					} catch (InvalidSelectorException e) {
-						m_log.debug("collect() : " + e.getMessage());
-					}
+	        			//既に同じファシリティIDが存在しているかチェック
+	        			if(map.get(facilityId) == null){
+	        				//存在していない場合
+		        			m_valueLogAgent = true;
+		        			map.put(facilityId, facilityId);
+	        			}
+	        			else{
+	        				//存在している場合
+	        				m_valueLogAgent = false;
+	        				duplication = true;
+	        				
+	        				//イベントに出力
+	                        AplLogger apllog = new AplLogger("AGT","agt");
+	                        String[] args = {facilityId};
+	                        apllog.put("SYS","002", args);
+	                        
+	                        break;
+	        			}
+	        		}
 	        	}
 	        	
+//	        	for(int i = 0; i < ((List)returnObject).size(); i++){
+//	        		//Subscription取得
+//	        		Subscription subscription = (Subscription)((List)returnObject).get(i);
+//	        		
+//	        		try {
+//	        			//SubscriptionからSelectorを取得
+//	        			Selector selecter = subscription.getSelector();
+//	        			
+//	        			//Selectorとチェック文字列を比較
+//		        		if(selecter != null && 
+//		        				selecter.selector.indexOf(checkString) != -1){
+//		        			//チャック文字列を含む場合
+//		        			
+//		        			//既に同じファシリティIDが存在しているかチェック
+//		        			if(map.get(facilityId) == null){
+//		        				//存在していない場合
+//			        			m_valueLogAgent = true;
+//			        			map.put(facilityId, facilityId);
+//		        			}
+//		        			else{
+//		        				//存在している場合
+//		        				m_valueLogAgent = false;
+//		        				duplication = true;
+//		        				
+//		        				//イベントに出力
+//		                        AplLogger apllog = new AplLogger("AGT","agt");
+//		                        String[] args = {facilityId};
+//		                        apllog.put("SYS","002", args);
+//		                        
+//		                        break;
+//		        			}
+//		        		}
+//					} catch (InvalidSelectorException e) {
+//						m_log.debug("collect() : " + e.getMessage());
+//					}
+//	        	}
+	        	
         		if(!duplication){
     	        	if(m_valueLogAgent){
     	        		//OK
