@@ -34,6 +34,7 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.JobParamTypeConstant;
+import com.clustercontrol.bean.OutputNotifyGroupInfo;
 import com.clustercontrol.commons.util.ConnectionManager;
 import com.clustercontrol.jobmanagement.bean.SystemParameterConstant;
 import com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoBean;
@@ -43,12 +44,11 @@ import com.clustercontrol.jobmanagement.ejb.entity.JobSessionLocal;
 import com.clustercontrol.jobmanagement.ejb.entity.JobSessionPK;
 import com.clustercontrol.jobmanagement.ejb.entity.JobSessionUtil;
 import com.clustercontrol.jobmanagement.util.ParameterUtil;
-import com.clustercontrol.monitor.message.LogOutputInfo;
 
 /**
  * ジョブパラメータ情報のDAOインターフェースを実装するクラス<BR>
  * 
- * @version 2.1.0
+ * @version 3.0.0
  * @since 2.1.0
  * 
  * @see com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoBean
@@ -535,10 +535,10 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 	 * @throws FinderException
 	 * @throws NamingException
 	 * 
-	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoBean#ejbHomeMakeSession(String, String, LogOutputInfo)
-	 * @see com.clustercontrol.monitor.message.LogOutputInfo
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobParamInfoBean#ejbHomeMakeSession(String, String, OutputNotifyGroupInfo)
+	 * @see com.clustercontrol.notify.message.OutputNotifyGroupInfo
 	 */
-	public void makeSession(String sessionId, String jobId, LogOutputInfo info) throws CreateException, FinderException, NamingException{
+	public void makeSession(String sessionId, String jobId, OutputNotifyGroupInfo info) throws CreateException, FinderException, NamingException{
 		m_log.debug("makeSession() start : " + sessionId );
 		
 		Connection conn = null;
@@ -588,21 +588,33 @@ public class JobParamInfoDAOImpl implements JobParamInfoDAO {
 				String value = null;
 				if(paramType == JobParamTypeConstant.TYPE_SYSTEM){
 					//システム変数
-					if(paramId.equals(SystemParameterConstant.START_DATE)){
-						//セッション開始日時
-						try {
-							JobSessionLocal session = JobSessionUtil.getLocalHome().findByPrimaryKey(new JobSessionPK(sessionId));
-							value = DateFormat.getDateTimeInstance().format(session.getSchedule_date());
-						} catch (FinderException e) {
-							throw e;
-						} catch (NamingException e) {
-							throw e;
-						}
-					}
-					else{
-						//その他
+					// システム変数に格納する情報が、どの機能のものかチェック
+					int functionType = ParameterUtil.checkFunctionType(paramId);
+					
+					if (functionType == ParameterUtil.TYPE_JOB){
+						// ジョブ管理の情報を取得する場合
+						value = ParameterUtil.getJobParameterValue(sessionId, paramId);
+						
+					} else if (functionType == ParameterUtil.TYPE_MONITOR){
+						// 監視管理の情報を取得する場合
 						value = ParameterUtil.getParameterValue(paramId, info);
 					}
+					
+//					if(paramId.equals(SystemParameterConstant.START_DATE)){
+//						//セッション開始日時
+//						try {
+//							JobSessionLocal session = JobSessionUtil.getLocalHome().findByPrimaryKey(new JobSessionPK(sessionId));
+//							value = DateFormat.getDateTimeInstance().format(session.getSchedule_date());
+//						} catch (FinderException e) {
+//							throw e;
+//						} catch (NamingException e) {
+//							throw e;
+//						}
+//					}
+//					else{
+//						//その他
+//						value = ParameterUtil.getParameterValue(paramId, info);
+//					}
 				}
 				else{
 					//ユーザ変数
