@@ -25,15 +25,16 @@ import javax.naming.NamingException;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.quartz.SchedulerException;
 
-import com.clustercontrol.maintenance.ejb.entity.MaintenanceInfoData;
+
 import com.clustercontrol.maintenance.ejb.session.MaintenanceController;
 import com.clustercontrol.maintenance.util.EjbConnectionManager;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.maintenance.bean.MaintenanceInfoDataImp;
 
 /**
  * メンテナンス情報を取得するクライアント側アクションクラス<BR>
  * 
- * @version 2.2.0
+ * @version 3.0.0
  * @since 2.2.0
  */
 public class GetMaintenance {
@@ -45,10 +46,10 @@ public class GetMaintenance {
 	 * @param maintenanceId
 	 * @return
 	 */
-	public MaintenanceInfoData getMaintenanceInfo(String maintenanceId) {
+	public MaintenanceInfoDataImp getMaintenanceInfo(String maintenanceId) {
 		
     	MaintenanceController maintenance = EjbConnectionManager.getConnectionManager().getMaintenanceController();
-    	MaintenanceInfoData info = null;
+    	MaintenanceInfoDataImp info = null;
     	
 		try {
 			info = maintenance.getMaintenanceInfo(maintenanceId);
