@@ -27,6 +27,7 @@ import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.Date;
 import java.util.GregorianCalendar;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Locale;
 
@@ -54,6 +55,7 @@ import org.quartz.SchedulerException;
 import com.clustercontrol.calendar.ejb.session.CalendarControllerLocal;
 import com.clustercontrol.calendar.ejb.session.CalendarControllerUtil;
 import com.clustercontrol.commons.util.ConnectionManager;
+import com.clustercontrol.maintenance.bean.MaintenanceInfoDataImp;
 import com.clustercontrol.maintenance.bean.MaintenanceKeepMstConstant;
 import com.clustercontrol.maintenance.bean.ScheduleInfo;
 import com.clustercontrol.maintenance.ejb.entity.MaintenanceInfoData;
@@ -69,8 +71,11 @@ import com.clustercontrol.maintenance.factory.SelectMaintenanceInfo;
 import com.clustercontrol.maintenance.factory.SelectMaintenanceKeepMst;
 import com.clustercontrol.maintenance.factory.SelectMaintenanceTypeMst;
 import com.clustercontrol.maintenance.factory.SelectSchedule;
-import com.clustercontrol.maintenance.util.MaintenanceProperties;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
+import com.clustercontrol.notify.ejb.session.NotifyControllerLocal;
+import com.clustercontrol.notify.ejb.session.NotifyControllerUtil;
 import com.clustercontrol.util.apllog.AplLogger;
+import com.sun.org.apache.bcel.internal.generic.GETSTATIC;
 
 /**
  * 
@@ -99,7 +104,7 @@ import com.clustercontrol.util.apllog.AplLogger;
 public abstract class MaintenanceControllerBean implements SessionBean {
 
    protected static Log m_log = LogFactory.getLog( MaintenanceControllerBean.class );
-
+   
 	/** コンテキスト情報 */
 	@SuppressWarnings("unused")
 	private SessionContext m_context;
@@ -130,13 +135,14 @@ public abstract class MaintenanceControllerBean implements SessionBean {
      *     method-intf="Remote"
 	 * 
 	 */
-	public void addMaintenance(MaintenanceInfoData data, ScheduleInfo schedule) throws CreateException, NamingException, IllegalStateException, SystemException, NotSupportedException, RollbackException, HeuristicMixedException, HeuristicRollbackException, SchedulerException, ParseException, RemoteException {
+	public void addMaintenance(MaintenanceInfoDataImp data, ScheduleInfo schedule) throws CreateException, NamingException, IllegalStateException, SystemException, NotSupportedException, RollbackException, HeuristicMixedException, HeuristicRollbackException, SchedulerException, ParseException, RemoteException {
 		m_log.debug("addMaintenance");
 		
 		Principal pri = m_context.getCallerPrincipal();
 		
 		TransactionManager tm = null;
-		Transaction tx = null;
+//		Transaction tx = null;
+//		Transactionの利用を取りやめたため、関連箇所ふくめコメントアウトした : uchiyama		
 		Transaction oldTx = null;
 		boolean result = false;
 		
@@ -155,7 +161,7 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 					// トランザクション開始
 					if(tm.getTransaction() == null){
 						tm.begin();	
-						tx = tm.getTransaction();
+//						tx = tm.getTransaction();
 					}
 					
 					// メンテナンス情報を登録
@@ -169,7 +175,8 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 					
 					if(result){
 						// コミット
-						tx.commit();
+//						tx.commit();
+						tm.commit();
 					}
 			} catch (SecurityException e) {
 				m_log.debug("addMaintenance() : " + e.getMessage());
@@ -191,11 +198,16 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 				throw e;
 			} finally {
 				// トランザクション関連の例外が発生した場合は、ロールバック
-				if(tx != null){
+//				if(tx != null){
+//					if(!result){
+//						tx.rollback();
+//					}
+//					tx = null;
+//				}
+				if(tm.getTransaction() != null){
 					if(!result){
-						tx.rollback();
+						tm.rollback();
 					}
-					tx = null;
 				}
 			}
 				
@@ -246,6 +258,8 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 	 * @throws SchedulerException 
 	 * @throws ParseException 
 	 * @throws RemoteException 
+	 * @throws RemoveException 
+	 * @throws CreateException 
 	 * @ejb.interface-method
 	 * 
 	 * @ejb.permission
@@ -253,13 +267,14 @@ public abstract class MaintenanceControllerBean implements SessionBean {
      *     method-intf="Remote"
 	 * 
 	 */
-	public void modifyMaintenance(MaintenanceInfoData data, ScheduleInfo schedule) throws FinderException, NamingException, SystemException, NotSupportedException, RollbackException, HeuristicMixedException, HeuristicRollbackException, SchedulerException, ParseException, RemoteException {
+	public void modifyMaintenance(MaintenanceInfoDataImp data, ScheduleInfo schedule) throws FinderException, NamingException, SystemException, NotSupportedException, RollbackException, HeuristicMixedException, HeuristicRollbackException, SchedulerException, ParseException, RemoteException {
 		m_log.debug("modifyMaintenance");
 		
 		Principal pri = m_context.getCallerPrincipal();
 		
 		TransactionManager tm = null;
-		Transaction tx = null;
+//		Transaction tx = null;
+//		Transactionの利用を取りやめたため、関連箇所ふくめコメントアウトした : uchiyama
 		Transaction oldTx = null;
 		boolean result = false;
 		
@@ -278,7 +293,7 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 					// トランザクション開始
 					if(tm.getTransaction() == null){
 						tm.begin();	
-						tx = tm.getTransaction();
+//						tx = tm.getTransaction();
 					}
 					
 					// メンテナンス情報を登録
@@ -292,7 +307,8 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 					
 					if(result){
 						// コミット
-						tx.commit();
+//						tx.commit();
+						tm.commit();
 					}
 			} catch (SecurityException e) {
 				m_log.debug("modifyMaintenance() : " + e.getMessage());
@@ -312,13 +328,24 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 			} catch (HeuristicRollbackException e) {
 				m_log.debug("modifyMaintenance() : " + e.getMessage());
 				throw e;
+			} catch (CreateException e) {
+				m_log.debug("modifyMaintenance() : " + e.getMessage());
+				e.printStackTrace();
+			} catch (RemoveException e) {
+				m_log.debug("modifyMaintenance() : " + e.getMessage());
+				e.printStackTrace();
 			} finally {
 				// トランザクション関連の例外が発生した場合は、ロールバック
-				if(tx != null){
+//				if(tx != null){
+//					if(!result){
+//						tx.rollback();
+//					}
+//					tx = null;
+//				}
+				if(tm.getTransaction() != null){
 					if(!result){
-						tx.rollback();
+						tm.rollback();
 					}
-					tx = null;
 				}
 			}
 				
@@ -365,6 +392,9 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 	 * @throws HeuristicRollbackException 
 	 * @throws SchedulerException 
 	 * @throws RemoteException 
+	 * @throws CreateException 
+	 * @throws FinderException 
+	 * @throws EJBException 
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -373,11 +403,12 @@ public abstract class MaintenanceControllerBean implements SessionBean {
      *     method-intf="Remote"
 	 * 
 	 */
-	public void deleteMaintenance(String maintenanceId) throws RemoveException, NamingException, SystemException, NotSupportedException, RollbackException, HeuristicMixedException, HeuristicRollbackException, SchedulerException, RemoteException {
+	public void deleteMaintenance(String maintenanceId) throws RemoveException, NamingException, SystemException, NotSupportedException, RollbackException, HeuristicMixedException, HeuristicRollbackException, SchedulerException, RemoteException, EJBException{
 		m_log.debug("deleteMaintenance");
 		
 		TransactionManager tm = null;
-		Transaction tx = null;
+//		Transaction tx = null;
+//		Transactionの利用を取りやめたため、関連箇所ふくめコメントアウトした : uchiyama		
 		Transaction oldTx = null;
 		boolean result = false;
 		
@@ -396,7 +427,7 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 					// トランザクション開始
 					if(tm.getTransaction() == null){
 						tm.begin();	
-						tx = tm.getTransaction();
+//						tx = tm.getTransaction();
 					}
 					
 					// メンテナンス情報を削除
@@ -410,7 +441,8 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 					
 					if(result){
 						// コミット
-						tx.commit();
+//						tx.commit();
+						tm.commit();
 					}
 			} catch (SecurityException e) {
 				m_log.debug("deleteMaintenance() : " + e.getMessage());
@@ -430,13 +462,24 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 			} catch (HeuristicRollbackException e) {
 				m_log.debug("deleteMaintenance() : " + e.getMessage());
 				throw e;
+			} catch (FinderException e) {
+				m_log.debug("deleteMaintenance() : " + e.getMessage());
+					e.printStackTrace();
+			} catch (CreateException e) {
+				m_log.debug("deleteMaintenance() : " + e.getMessage());
+					e.printStackTrace();
 			} finally {
 				// トランザクション関連の例外が発生した場合は、ロールバック
-				if(tx != null){
+//				if(tx != null){
+//					if(!result){
+//						tx.rollback();
+//					}
+//					tx = null;
+//				}
+				if(tm.getTransaction() != null){
 					if(!result){
-						tx.rollback();
+						tm.rollback();
 					}
-					tx = null;
 				}
 			}
 				
@@ -490,7 +533,7 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 	public int deleteEventLog(String keep_id) throws FinderException, NamingException, CreateException, SQLException {
 		m_log.debug("deleteEventLog()");
 		
-		int ret = 0;
+		int ret = -1;
 		Connection conn = null;
 		Statement stmt = null;
 		
@@ -504,16 +547,16 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 			
 			//SQL文の定義
 			StringBuffer sql = new StringBuffer();
-			sql.append("DELETE FROM cc_event_multi_info");
-			sql.append(" WHERE (monitor_id, plugin_id, output_date, facility_id)");
-			sql.append(" IN (SELECT monitor_id, plugin_id, output_date, facility_id FROM cc_event_log");
-			sql.append(" WHERE output_date < '" + timestamp.toString() + "'");
-			sql.append(" AND confirm_flg='1'); ");
-			
-			m_log.debug("execute : " + sql.toString());
-			stmt.executeUpdate(sql.toString());
-			
-			sql.delete(0, sql.length());
+//			sql.append("DELETE FROM cc_event_multi_info");
+//			sql.append(" WHERE (monitor_id, plugin_id, output_date, facility_id)");
+//			sql.append(" IN (SELECT monitor_id, plugin_id, output_date, facility_id FROM cc_event_log");
+//			sql.append(" WHERE output_date < '" + timestamp.toString() + "'");
+//			sql.append(" AND confirm_flg='1'); ");
+//			
+//			m_log.debug("execute : " + sql.toString());
+//			stmt.executeUpdate(sql.toString());
+//			
+//			sql.delete(0, sql.length());
 			sql.append("DELETE FROM cc_event_log WHERE output_date < '" + timestamp.toString() + "' AND confirm_flg='1';");
 			ret = stmt.executeUpdate(sql.toString());
 			
@@ -546,6 +589,8 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 	 * @throws CreateException 
 	 * @throws NamingException 
 	 * @throws FinderException 
+	 * @throws SQLException
+	 * @throws RemoveException 
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -554,10 +599,9 @@ public abstract class MaintenanceControllerBean implements SessionBean {
      *     method-intf="Remote"
      *     
 	 */
-	public int deleteJobHistory(String keep_id) throws FinderException, NamingException, CreateException, SQLException {
+	public int deleteJobHistory(String keep_id) throws FinderException, NamingException, CreateException, SQLException, RemoveException {
 		m_log.debug("deleteJobHistory()");
 		
-		// 削除件数
 		int ret = 0;
 		Connection conn = null;
 		Statement stmt = null;
@@ -570,94 +614,101 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 			//SQL文のセット
 			stmt = conn.createStatement();
 			
-			//削除対象となるsession_idをセレクトする
-			String sql_select_list = "select distinct session_id from cc_job_session_job " +
-					"where (status='300' OR status='301')" +
-					" AND end_date < '" + timestamp.toString() + "'" +
-					" AND session_id IN (select session_id from cc_job_session);";
+			// 削除対象となるsession_idを検索する副問い合わせをもつwhere句
+			String select_sessionId = "SELECT session_id from cc_job_session_job where (status='300' OR status='301') and end_date < '" + timestamp.toString() + "'";
 			
-			m_log.debug("sql : " + sql_select_list);
+			// cc_job_session テーブルの情報を削除する際に利用する、削除対象となるsession_idのリスト
+			String sql_select_list = "select session_id, job_id from cc_job_session_job WHERE session_id IN (" + select_sessionId + ");";
 			
-			//削除対象ジョブのセッションIDを取得する
 			ResultSet res = stmt.executeQuery(sql_select_list);
+			ArrayList<String> notifyGroupIdList = new ArrayList<String>();
 			
-			//セッションIDのリストを分割し、ArrayListに入れる
-			ArrayList<String> sessionIdsList = convertSessionIdsToArrayList(res);
-
-//			if (sb.length() == 0) {
-			if (sessionIdsList.size() == 0) {
+			// 削除対象となるセッションIDのセット
+			HashSet<String> sessionIds = new HashSet<String>();
+			
+			while(res.next()){
+				sessionIds.add(res.getString(1));
+				
+				//　削除する通知グループIDの取得
+				notifyGroupIdList.add(
+						NotifyRelationInfo.createNotifyGroupIdJobInfo(res.getString(1), res.getString(2), 0)
+						);
+			}
+			
+			
+			if (sessionIds.size() == 0) {
 				ret = 0;
 				
 			} else {
 				
-				Iterator iterator = sessionIdsList.iterator();
-				while (iterator.hasNext()) {
-					
-					String sessionIdList = (String) iterator.next();
-					
-					m_log.debug("delete list : " + sessionIdList);
-					
-					//削除用SQL文の定義、実行
-					StringBuffer sql = new StringBuffer();
-					sql.append("DELETE FROM cc_job_param_info WHERE session_id IN (" + sessionIdList + ");");
-					stmt.executeUpdate(sql.toString());
-					
-					sql.delete(0, sql.length());
-					sql.append("DELETE FROM cc_job_end_info WHERE session_id IN (" + sessionIdList + ");");
-					stmt.executeUpdate(sql.toString());
-					
-					sql.delete(0, sql.length());
-					sql.append("DELETE FROM cc_job_notice_info WHERE session_id IN (" + sessionIdList + ");");
-					stmt.executeUpdate(sql.toString());
-					
-					sql.delete(0, sql.length());
-					sql.append("DELETE FROM cc_job_command_info WHERE session_id IN (" + sessionIdList + ");");
-					stmt.executeUpdate(sql.toString());
-					
-					sql.delete(0, sql.length());
-					sql.append("DELETE FROM cc_job_start_info WHERE session_id IN (" + sessionIdList + ");");
-					stmt.executeUpdate(sql.toString());
-					
-					sql.delete(0, sql.length());
-					sql.append("DELETE FROM cc_job_start_job_info WHERE session_id IN (" + sessionIdList + ");");
-					stmt.executeUpdate(sql.toString());
-					
-					sql.delete(0, sql.length());
-					sql.append("DELETE FROM cc_job_start_time_info WHERE session_id IN (" + sessionIdList + ");");
-					stmt.executeUpdate(sql.toString());
-					
-					sql.delete(0, sql.length());
-					sql.append("DELETE FROM cc_job_file_info WHERE session_id IN (" + sessionIdList + ");");
-					stmt.executeUpdate(sql.toString());
-					
-					sql.delete(0, sql.length());
-					sql.append("DELETE FROM cc_job_info WHERE session_id IN (" + sessionIdList + ");");
-					stmt.executeUpdate(sql.toString());
-					
-					sql.delete(0, sql.length());
-					sql.append("DELETE FROM cc_job_relation_info WHERE session_id IN (" + sessionIdList + ");");
-					stmt.executeUpdate(sql.toString());
-					
-					sql.delete(0, sql.length());
-					sql.append("DELETE FROM cc_job_session_node WHERE session_id IN (" + sessionIdList + ");");
-					stmt.executeUpdate(sql.toString());
-
-					sql.delete(0, sql.length());
-					sql.append("DELETE FROM cc_job_session_job WHERE session_id IN (" + sessionIdList + ");");
-					stmt.executeUpdate(sql.toString());
-					
-					//cc_job_sessionの削除件数を返り値とする
-					sql.delete(0, sql.length());
-					sql.append("DELETE FROM cc_job_session WHERE session_id IN (" + sessionIdList + ");");
-					
-					//　削除件数を加算
-					ret = ret + stmt.executeUpdate(sql.toString());
-					
-				}
+				m_log.debug("delete start");
+				m_log.debug("DELETE FROM cc_job_session WHERE session_id IN (" + select_sessionId + ");");
+				
+				ret = stmt.executeUpdate("DELETE FROM cc_job_session WHERE session_id IN (" + select_sessionId + ");");
+				
+//				stmt.executeUpdate("DELETE FROM cc_job_param_info WHERE session_id IN (" + select_sessionId + ");");
+//				stmt.executeUpdate("DELETE FROM cc_job_end_info WHERE session_id IN (" + select_sessionId + ");");
+//				stmt.executeUpdate("DELETE FROM cc_job_notice_info WHERE session_id IN (" + select_sessionId + ");");
+//				stmt.executeUpdate("DELETE FROM cc_job_command_info WHERE session_id IN (" + select_sessionId + ");");
+//				stmt.executeUpdate("DELETE FROM cc_job_start_info WHERE session_id IN (" + select_sessionId + ");");
+//				stmt.executeUpdate("DELETE FROM cc_job_start_job_info WHERE session_id IN (" + select_sessionId + ");");
+//				stmt.executeUpdate("DELETE FROM cc_job_start_time_info WHERE session_id IN (" + select_sessionId + ");");
+//				stmt.executeUpdate("DELETE FROM cc_job_file_info WHERE session_id IN (" + select_sessionId + ");");
+//				stmt.executeUpdate("DELETE FROM cc_job_info WHERE session_id IN (" + select_sessionId + ");");
+//				stmt.executeUpdate("DELETE FROM cc_job_relation_info WHERE session_id IN (" + select_sessionId + ");");
+//				stmt.executeUpdate("DELETE FROM cc_job_session_node WHERE session_id IN (" + select_sessionId + ");");
+//				stmt.executeUpdate("DELETE FROM cc_job_session_job WHERE session_id IN (" + select_sessionId + ");");
+//				
+//				// cc_job_session テーブルの内容を削除する際には、cc_job_session_jobテーブルが削除されているので、
+//				// あらかじめ作成しておいたsession_idのリストを使用する
+//				
+//				// session_idのリストが長すぎるとエラーとなるため、プロパティで設定した数だけ繰り返し消す
+//				int bufsize = MaintenanceProperties.getInstance().getDeleteBufSize();
+//				m_log.debug("bufsize : " + bufsize);
+//				StringBuffer stb = new StringBuffer();
+//				
+//				Iterator<String> ite = sessionIds.iterator();
+//				while (ite.hasNext()){
+//					
+//					//指定されたバッファサイズ分だけ、session_idを取り出す
+//					for (int i = 0; i < bufsize; i++) {
+//						if (ite.hasNext()){
+//							stb.append("'");
+//							stb.append(ite.next());
+//							stb.append("'");
+//							stb.append(",");
+//						}
+//					}
+//					
+//					// 余分に付いているカンマを削除
+//					stb.delete(stb.length() - 1, stb.length());
+//					
+//					String sql = "DELETE FROM cc_job_session WHERE session_id IN (" + stb.toString() + ");";
+//					m_log.debug("delete cc_job_session : " + sql);
+//					
+//					//cc_job_sessionの削除件数を返り値とする
+//					int updateResult = stmt.executeUpdate(sql);
+//					m_log.debug("delete : " + updateResult);
+//					
+//					ret = ret + updateResult;
+//					
+//					stb.delete(0, stb.length());
+//				}
+//				
 			}
-
 			m_log.debug("delete count : " + ret);
 			
+			
+			// 通知連携と抑制の削除
+			NotifyControllerLocal notifyController = NotifyControllerUtil.getLocalHome().create();		
+			Iterator<String> itr = notifyGroupIdList.iterator();
+			String deleteNotifyGroupId = null;
+			while(itr.hasNext()) {
+				deleteNotifyGroupId = itr.next();
+				notifyController.deleteNotifyRelation(deleteNotifyGroupId);
+				notifyController.deleteNotifyInhibition(deleteNotifyGroupId);
+			}
+			
 			return ret;
 			
 		} catch (SQLException e) {
@@ -665,6 +716,9 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 			throw e;
 //			e.printStackTrace();
 
+		} catch (RemoveException e) {
+			m_log.error("removeAll() error : RemoveException " + e.getMessage());
+			throw e;
 		} finally {
 			try {
 				stmt.close();
@@ -694,7 +748,7 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 	public int deleteCollectiveRunHistory(String keep_id) throws FinderException, NamingException, CreateException, SQLException {
 		m_log.debug("deleteCollectiveRunHistory()");
 		
-		int ret = 0;
+		int ret = -1;
 		Connection conn = null;
 		Statement stmt = null;
 
@@ -706,46 +760,12 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 			stmt = conn.createStatement();
 			
 			//削除対象となるsession_idをセレクトする
-			String sql_select_list = "SELECT distinct session_id from cc_crun_session" +
-					" WHERE end_date < '" + timestamp.toString() + "' AND status='300';";
+			String select_sessionId = "SELECT session_id from cc_crun_session" + 
+			" WHERE end_date < '" + timestamp.toString() + "' AND status='300'";
 			
-			m_log.debug("sql : " + sql_select_list);
-			
-			//削除対象ジョブのセッションIDを取得する
-			ResultSet res = stmt.executeQuery(sql_select_list);
-			
-			//セッションIDのリストを分割し、ArrayListに入れる
-			ArrayList<String> sessionIdsList = convertSessionIdsToArrayList(res);
-
-//			if (sb.length() == 0) {
-			if (sessionIdsList.size() == 0) {
-				ret = 0;
-			} else {
-				
-				Iterator iterator = sessionIdsList.iterator();
-				while (iterator.hasNext()) {
-					
-					String sessionIdList = (String) iterator.next();
-					
-					m_log.debug("delete list : " + sessionIdList);
-					
-					//SQL文の定義、実行
-					StringBuffer sql = new StringBuffer();
-					sql.append("DELETE FROM cc_crun_session_detail WHERE session_id IN(" + sessionIdList + ");");
-					stmt.executeUpdate(sql.toString());						
-					
-					sql.delete(0, sql.length());
-					sql.append("DELETE FROM cc_crun_session_param WHERE session_id IN(" + sessionIdList + ");");
-					stmt.executeUpdate(sql.toString());			
-					
-					//cc_crun_sessionの削除件数を返り値とする
-					sql.delete(0, sql.length());
-					sql.append("DELETE FROM cc_crun_session WHERE session_id IN(" + sessionIdList + ");");
-					
-					//　削除件数を加算
-					ret = ret + stmt.executeUpdate(sql.toString());
-				}
-			}
+//			stmt.executeUpdate("DELETE FROM cc_crun_session_detail WHERE session_id IN(" + select_sessionId + ");");
+//			stmt.executeUpdate("DELETE FROM cc_crun_session_param WHERE session_id IN(" + select_sessionId + ");");
+			ret = stmt.executeUpdate("DELETE FROM cc_crun_session WHERE session_id IN(" + select_sessionId + ");");
 			
 			m_log.debug("delete count : " + ret);
 			
@@ -898,11 +918,11 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 	 * @throws NamingException 
 	 * @throws FinderException 
 	 */
-	public MaintenanceInfoData getMaintenanceInfo(String maintenanceId) throws FinderException, NamingException, CreateException {
+	public MaintenanceInfoDataImp getMaintenanceInfo(String maintenanceId) throws FinderException, NamingException, CreateException {
 		m_log.debug("getMaintenanceInfoData()");
 		
 		SelectMaintenanceInfo select = new SelectMaintenanceInfo();
-		MaintenanceInfoData info = select.getMaintenanceInfo(maintenanceId);
+		MaintenanceInfoDataImp info = select.getMaintenanceInfo(maintenanceId);
 		
 		return info;
 		
@@ -1210,8 +1230,7 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 	}
 	
 	private Timestamp getTimestamp(String keep_id) throws FinderException, NamingException, CreateException {
-
-		m_log.debug("keep_id : " +  keep_id);
+		
 		int order_no = 0;
 		
 		//削除対象外期間が設定されていた場合
@@ -1238,11 +1257,11 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 		case MaintenanceKeepMstConstant.ONE_MONTH_INDEX:
 			calendar.add(Calendar.MONTH, -1);
 			break;
-			
+		
 		case MaintenanceKeepMstConstant.TWO_MONTHS_INDEX:
 			calendar.add(Calendar.MONTH, -2);
 			break;
-			
+		
 		case MaintenanceKeepMstConstant.THREE_MONTHS_INDEX:
 			calendar.add(Calendar.MONTH, -3);
 			break;
@@ -1256,64 +1275,10 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 			break;
 		}
 		
-		m_log.debug(calendar.getTime());
-		
 		return new Timestamp(calendar.getTimeInMillis());
 		
 	}
 	
-	/**
-	 * 
-	 * セッションIDのリストを分割し、ArrayListにつめるメソッド
-	 * 
-	 * セッションIDのリストは、カンマ区切りのString文字列である
-	 * 例 : session_id1, session_id2, session_id3, session_id4 ...
-	 * 
-	 * クラス変数limitで指定された数だけセッションIDが含まれるような、
-	 * 上記形式の文字列が、ArrayListの１要素となるように変換する
-	 * 
-	 * @param res
-	 * @return
-	 * @throws SQLException
-	 */
-	private ArrayList<String> convertSessionIdsToArrayList(ResultSet res) throws SQLException {
-		
-		//セッションIDのリストを半角スペース区切りから、コンマ区切りに変更する
-		ArrayList<String> sessionIdsList = new ArrayList<String>();
-		StringBuffer sb = new StringBuffer();
-		
-		// リストに追加したsession_id数のカウンタ
-		int count = 0;
-		while(res.next()){
-			
-			sb.append("'");
-			sb.append(res.getString(1));
-			sb.append("'");
-			sb.append(", ");
-			count++;
-			
-			// session_idリストが制限値に達していたら、
-			// 余分についているカンマを削除した後、
-			// 別のArrayListに登録して、初期化
-			if (count == MaintenanceProperties.getInstance().getDeleteBufSize()) {
-				// 余分に付いているカンマを削除
-				sb.delete(sb.length() - 2, sb.length());
-				m_log.debug("add list : " + sb.toString());
-				sessionIdsList.add(sb.toString());
-				sb.delete(0, sb.length());
-				count = 0;
-			}
-		}
-		
-		if (sb.length() > 0) {
-			// 余分に付いているカンマを削除
-			sb.delete(sb.length() - 2, sb.length());
-			// 残りを追加
-			sessionIdsList.add(sb.toString());
-		}
-		
-		return sessionIdsList;
-	}
 	
 	public void ejbRemove() throws EJBException, RemoteException {}
 
