@@ -12,7 +12,7 @@ package com.clustercontrol.monitor.bean;
  *
  */
 public class StatusInfoData extends
-		com.clustercontrol.monitor.ejb.entity.StatusInfoData {
+		com.clustercontrol.notify.monitor.ejb.entity.StatusInfoData {
 	
 	public String facilityPath;
 	
