@@ -35,10 +35,9 @@ import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.ViewListInfo;
 import com.clustercontrol.monitor.bean.ReportEventInfo;
-import com.clustercontrol.monitor.bean.ScopeInfoData;
-import com.clustercontrol.monitor.ejb.entity.EventLogData;
-import com.clustercontrol.monitor.ejb.entity.EventLogLocal;
-import com.clustercontrol.monitor.ejb.entity.EventLogUtil;
+import com.clustercontrol.notify.monitor.ejb.entity.EventLogData;
+import com.clustercontrol.notify.monitor.ejb.entity.EventLogLocal;
+import com.clustercontrol.notify.monitor.ejb.entity.EventLogUtil;
 import com.clustercontrol.monitor.ejb.session.MonitorControllerBean;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
@@ -48,7 +47,7 @@ import com.clustercontrol.util.apllog.AplLogger;
 /**
  * イベント情報を検索するクラス<BR>
  * 
- * @version 2.1.0
+ * @version 3.0.0
  * @since 1.0.0
  */
 public class SelectEvent {
