@@ -71,16 +71,10 @@ public abstract class MonitorInfoBean implements EntityBean {
 	 * @param monitorBlock 監視単位
 	 * @param determinationId 判定ID（未使用）
 	 * @param failurePriority 値取得の失敗時の重要度
-	 * @param notifyId 通知ID
 	 * @param application アプリケーション
-	 * @param jobRun ジョブ実行
-	 * @param failureMessageId 値取得の失敗時のメッセージID（未使用）
+     * @param failureMessageId 値取得の失敗時のメッセージID（未使用）
 	 * @param failureMessage 値取得の失敗時のメッセージ（未使用）
-	 * @param failureJobRun 値取得の失敗時のジョブ実行（未使用）
-	 * @param failureJobId  値取得の失敗時のジョブID（未使用）
-	 * @param failureJobInhibitionFlg 値取得の失敗時の通知抑制と連動（未使用）
-	 * @param failureJobFailurePriority 値取得の失敗時のジョブ呼出の失敗時の重要度（未使用）
-	 * @param regDate 作成日時
+	 * @param notifyGroupId 通知グループID
 	 * @param updateDate 最終変更日時
 	 * @param regUser 新規作成ユーザ
 	 * @param updateUser 最終変更ユーザ
@@ -105,15 +99,10 @@ public abstract class MonitorInfoBean implements EntityBean {
 			Integer monitorBlock, 
 			String determinationId, 
 			Integer failurePriority,
-			String notifyId, 
 			String application, 
-			Integer jobRun, 
 			String failureMessageId, 
 			String failureMessage,
-			Integer failureJobRun,
-			String failureJobId,
-			Integer failureJobInhibitionFlg,
-			Integer failureJobFailurePriority,
+			String notifyGroupId,
 			Timestamp regDate,  
 			Timestamp updateDate, 
 			String regUser, 
@@ -131,15 +120,10 @@ public abstract class MonitorInfoBean implements EntityBean {
 		this.setMonitorBlock(monitorBlock);
 		this.setDeterminationId(determinationId);
 		this.setFailurePriority(failurePriority);
-		this.setNotifyId(notifyId);
 		this.setApplication(application);
-		this.setJobRun(jobRun);
 		this.setFailureMessageId(failureMessageId);
 		this.setFailureMessage(failureMessage);
-		this.setFailureJobRun(failureJobRun);
-		this.setFailureJobId(failureJobId);
-		this.setFailureJobInhibitionFlg(failureJobInhibitionFlg);
-		this.setFailureJobFailurePriority(failureJobFailurePriority);
+		this.setNotifyGroupId(notifyGroupId);
 		this.setRegDate(regDate);
 		this.setUpdateDate(updateDate);
 		this.setRegUser(regUser);
@@ -147,6 +131,84 @@ public abstract class MonitorInfoBean implements EntityBean {
 		
 		return null;
 	}
+	
+	
+	/**
+	 * 通知グループIDを返します。
+	 * 
+	 * @ejb.persistent-field 
+	 * @ejb.persistence
+	 *    column-name="notify_group_id"
+	 *     jdbc-type="VARCHAR"
+	 *     sql-type="VARCHAR(1024)"
+	 *     read-only="false"
+	 *
+	 * @ejb.interface-method
+	 * 
+	 * @return 通知グループID
+	 */
+	public abstract String getNotifyGroupId();
+
+	/**
+	 * 通知グループIDを設定します。
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @param failureMessage 通知グループID
+	 */
+	public abstract void setNotifyGroupId(String notifyGroupId);
+	
+	
+	/**
+	 * 値取得の失敗時のメッセージを返します（未使用）。
+	 * 
+	 * @ejb.persistent-field 
+	 * @ejb.persistence
+	 *    column-name="failure_message"
+	 *     jdbc-type="VARCHAR"
+	 *     sql-type="VARCHAR(256)"
+	 *     read-only="false"
+	 *
+	 * @ejb.interface-method
+	 * 
+	 * @return 値取得の失敗時のメッセージ
+	 */
+	public abstract String getFailureMessage();
+
+	/**
+	 * 値取得の失敗時のメッセージを設定します（未使用）。
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @param failureMessage 値取得の失敗時のメッセージ
+	 */
+	public abstract void setFailureMessage(String failureMessage);
+
+	/**
+	 * 値取得の失敗時のメッセージIDを返します（未使用）。
+	 * 
+	 * @ejb.persistent-field 
+	 * @ejb.persistence
+	 *    column-name="failure_message_id"
+	 *     jdbc-type="VARCHAR"
+	 *     sql-type="VARCHAR(64)"
+	 *     read-only="false"
+	 *
+	 * @ejb.interface-method
+	 * 
+	 * @return 値取得の失敗時のメッセージID
+	 */
+	public abstract String getFailureMessageId();
+
+	/**
+	 * 値取得の失敗時のメッセージIDを設定します（未使用）。
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @param failureMessageId 値取得の失敗時のメッセージID
+	 */
+	public abstract void setFailureMessageId(String failureMessageId);
+	
 
 	/**
 	 * アプリケーションを返します。
@@ -273,167 +335,6 @@ public abstract class MonitorInfoBean implements EntityBean {
 	 */
 	public abstract void setFacilityId(String facilityId);
 	
-	/**
-	 * 値取得の失敗時のジョブ呼出の失敗時の重要度を返します（未使用）。
-	 * 
-	 * @ejb.persistent-field 
-	 * @ejb.persistence
-	 *    column-name="failure_job_failure_priority"
-	 *     jdbc-type="SMALLINT"
-	 *     sql-type="smallint"
-	 *     read-only="false"
-	 *  
-	 * @ejb.interface-method
-	 * 
-	 * @return 値取得の失敗時のジョブ呼出の失敗時の重要度
-	 * 
-	 * @see com.clustercontrol.bean.PriorityConstant
-	 */
-	public abstract Integer getFailureJobFailurePriority();
-
-	/**
-	 * 値取得の失敗時のジョブ呼出の失敗時の重要度を設定します（未使用）。
-	 * 
-	 * @ejb.interface-method
-	 * 
-	 * @param failureJobFailurePriority 値取得の失敗時のジョブ呼出の失敗時の重要度
-	 * 
-	 * @see com.clustercontrol.bean.PriorityConstant
-	 */
-	public abstract void setFailureJobFailurePriority(Integer failureJobFailurePriority);
-	
-	/**
-	 * 値取得の失敗時のジョブIDを返します（未使用）。
-	 * 
-	 * @ejb.persistent-field 
-	 * @ejb.persistence
-	 *    column-name="failure_job_id"
-	 *     jdbc-type="VARCHAR"
-	 *     sql-type="VARCHAR(64)"
-	 *     read-only="false"
-	 *
-	 * @ejb.interface-method
-	 * 
-	 * @return 値取得の失敗時のジョブID
-	 */
-	public abstract String getFailureJobId();
-
-	/**
-	 * 値取得の失敗時のジョブIDを設定します（未使用）。
-	 * 
-	 * @ejb.interface-method
-	 * 
-	 * @param failureJobId 値取得の失敗時のジョブID
-	 */
-	public abstract void setFailureJobId(String failureJobId);
-	
-	/**
-	 * 値取得の失敗時の通知抑制と連動を返します（未使用）。
-	 * 
-	 * @ejb.persistent-field 
-	 * @ejb.persistence
-	 *    column-name="failure_job_inhibition_flg"
-	 *     jdbc-type="SMALLINT"
-	 *     sql-type="smallint"
-	 *     read-only="false"
-	 *  
-	 * @ejb.interface-method
-	 * 
-	 * @return 値取得の失敗時の通知抑制と連動
-	 * 
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */
-	public abstract Integer getFailureJobInhibitionFlg();
-
-	/**
-	 * 値取得の失敗時の通知抑制と連動を設定します（未使用）。
-	 * 
-	 * @ejb.interface-method
-	 * 
-	 * @param failureJobInhibitionFlg 値取得の失敗時の通知抑制と連動
-	 * 
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */
-	public abstract void setFailureJobInhibitionFlg(Integer failureJobInhibitionFlg);
-	
-	/**
-	 * 値取得の失敗時のジョブ実行を返します（未使用）。
-	 * 
-	 * @ejb.persistent-field 
-	 * @ejb.persistence
-	 *    column-name="failure_job_run"
-	 *     jdbc-type="SMALLINT"
-	 *     sql-type="smallint"
-	 *     read-only="false"
-	 *  
-	 * @ejb.interface-method
-	 * 
-	 * @return 値取得の失敗時のジョブ実行
-	 * 
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */
-	public abstract Integer getFailureJobRun();
-
-	/**
-	 * 値取得の失敗時のジョブ実行を設定します（未使用）。
-	 * 
-	 * @ejb.interface-method
-	 * 
-	 * @param failureJobRun 値取得の失敗時のジョブ実行
-	 * 
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */
-	public abstract void setFailureJobRun(Integer failureJobRun);
-	
-	/**
-	 * 値取得の失敗時のメッセージを返します（未使用）。
-	 * 
-	 * @ejb.persistent-field 
-	 * @ejb.persistence
-	 *    column-name="failure_message"
-	 *     jdbc-type="VARCHAR"
-	 *     sql-type="VARCHAR(256)"
-	 *     read-only="false"
-	 *
-	 * @ejb.interface-method
-	 * 
-	 * @return 値取得の失敗時のメッセージ
-	 */
-	public abstract String getFailureMessage();
-
-	/**
-	 * 値取得の失敗時のメッセージを設定します（未使用）。
-	 * 
-	 * @ejb.interface-method
-	 * 
-	 * @param failureMessage 値取得の失敗時のメッセージ
-	 */
-	public abstract void setFailureMessage(String failureMessage);
-
-	/**
-	 * 値取得の失敗時のメッセージIDを返します（未使用）。
-	 * 
-	 * @ejb.persistent-field 
-	 * @ejb.persistence
-	 *    column-name="failure_message_id"
-	 *     jdbc-type="VARCHAR"
-	 *     sql-type="VARCHAR(64)"
-	 *     read-only="false"
-	 *
-	 * @ejb.interface-method
-	 * 
-	 * @return 値取得の失敗時のメッセージID
-	 */
-	public abstract String getFailureMessageId();
-
-	/**
-	 * 値取得の失敗時のメッセージIDを設定します（未使用）。
-	 * 
-	 * @ejb.interface-method
-	 * 
-	 * @param failureMessageId 値取得の失敗時のメッセージID
-	 */
-	public abstract void setFailureMessageId(String failureMessageId);
 	
 	/**
 	 * 値取得の失敗時の重要度を返します。
@@ -463,36 +364,7 @@ public abstract class MonitorInfoBean implements EntityBean {
 	 * @see com.clustercontrol.bean.PriorityConstant
 	 */
 	public abstract void setFailurePriority(Integer failurePriority);
-	
-	/**
-	 * ジョブ実行を返します。
-	 * 
-	 * @ejb.persistent-field 
-	 * @ejb.persistence
-	 *    column-name="job_run"
-	 *     jdbc-type="SMALLINT"
-	 *     sql-type="smallint"
-	 *     read-only="false"
-	 *  
-	 * @ejb.interface-method
-	 * 
-	 * @return ジョブ実行
-	 * 
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */
-	public abstract Integer getJobRun();
-
-	/**
-	 * ジョブ実行を設定します。
-	 * 
-	 * @ejb.interface-method
-	 * 
-	 * @param jobRun ジョブ実行
-	 * 
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */
-	public abstract void setJobRun(Integer jobRun);
-	
+		
 
 	/**
 	 * 監視単位を返します。
@@ -604,31 +476,7 @@ public abstract class MonitorInfoBean implements EntityBean {
 	 */
 	public abstract void setMonitorTypeId(String monitorTypeId);
 
-	/**
-	 * 通知IDを返します。
-	 * 
-	 * @ejb.persistent-field 
-	 * @ejb.persistence
-	 *    column-name="notify_id"
-	 *     jdbc-type="VARCHAR"
-	 *     sql-type="VARCHAR(64)"
-	 *     read-only="false"
-	 *
-	 * @ejb.interface-method
-	 * 
-	 * @return 通知ID
-	 */
-	public abstract String getNotifyId();
-
-	/**
-	 * 通知IDを設定します。
-	 * 
-	 * @ejb.interface-method
-	 * 
-	 * @param notifyId 通知ID
-	 */
-	public abstract void setNotifyId(String notifyId);
-
+	
 	/**
 	 * 作成日時を返します。
 	 * 
@@ -865,4 +713,5 @@ public abstract class MonitorInfoBean implements EntityBean {
 	 */
 	public abstract void setMonitorStringValueInfo(Collection collection);
 	
+	
 }
