@@ -23,18 +23,16 @@ import java.util.List;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.swt.events.SelectionAdapter;
 
-import com.clustercontrol.bean.FacilityInfo;
 import com.clustercontrol.bean.FacilityTreeItem;
 import com.clustercontrol.performance.bean.GraphDisplayRange;
 import com.clustercontrol.performance.bean.GraphProperty;
 import com.clustercontrol.performance.composite.RecordGraphComposite;
 import com.clustercontrol.performance.util.CollectorItemCodeFactory;
 import com.clustercontrol.performance.util.Messages;
-import com.clustercontrol.performanceMGR.bean.CollectedDataInfo;
-import com.clustercontrol.performanceMGR.bean.CollectedDataSet;
-import com.clustercontrol.performanceMGR.bean.CollectorItemInfo;
-import com.clustercontrol.performanceMGR.ejb.bmp.RecordCollectorData;
-import com.clustercontrol.performanceMGR.bean.CollectorRunStatus;
+import com.clustercontrol.performance.bean.CollectedDataInfo;
+import com.clustercontrol.performance.bean.CollectedDataSet;
+import com.clustercontrol.performance.bean.CollectorItemInfo;
+import com.clustercontrol.performance.ejb.bmp.RecordCollectorData;
 
 /**
  * 実績グラフを描画するためのアクションクラス
@@ -52,21 +50,28 @@ public class DrawRecordGraphAction extends SelectionAdapter {
 
     private RecordCollectorData m_collectorData;
 
-    private List m_itemInfoList;
+    private List<CollectorItemInfo> m_itemInfoList;
 
+//    private FacilityTreeItem m_facilityTree;
+    
+    // 表示対象収集項目
     private CollectorItemInfo m_currentItem;
 
-    private FacilityTreeItem m_facilityTree;
+    // 表示対象ファシリティ
+    private FacilityTreeItem m_targetFacility;
+    
+    private long m_graphStartTime;
+    private long m_graphEndTime;
 
     // 既に描画されている範囲をリストで保持する
-    private ArrayList m_gotTimeArea;
+    private ArrayList<GraphDisplayRange> m_gotTimeArea;
 
     /**
      * 新しい DrawRecordGraphAction オブジェクトを割り当てます。
      *
      */
     public DrawRecordGraphAction() {
-        this.m_gotTimeArea = new ArrayList();
+        this.m_gotTimeArea = new ArrayList<GraphDisplayRange>();
     }
 
     /**
@@ -75,8 +80,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
      * @param collectorData 実績収集の収集定義
      * @param itemInfoList 収集項目のリスト
      */
-    public DrawRecordGraphAction(RecordCollectorData collectorData,
-            List itemInfoList) {
+    public DrawRecordGraphAction(RecordCollectorData collectorData, List<CollectorItemInfo> itemInfoList) {
         this.m_collectorData = collectorData;
         this.m_itemInfoList = itemInfoList;
     }
@@ -97,84 +101,136 @@ public class DrawRecordGraphAction extends SelectionAdapter {
      * @param itemInfoList　収集項目のリスト
      * @param facilityTree ファシリティツリー
      */
-    public void setData(RecordCollectorData collectorData, List itemInfoList,
-            FacilityTreeItem facilityTree) {
+    public void setData(RecordCollectorData collectorData, List<CollectorItemInfo> itemInfoList) {
         this.m_collectorData = collectorData;
         this.m_itemInfoList = itemInfoList;
-        this.m_facilityTree = facilityTree;
+//        this.m_facilityTree = facilityTree;
     }
 
     /**
      * グラフを描画します。
      * 
      * @param facilityTree ファシリティツリー
-     * @param itemID 収集項目コード
+     * @param itemCode 収集項目コード
      * @param graphType グラフ種別
      */
-    public void drawGraph(FacilityTreeItem facilityTree, int itemID,
-            int graphType) {
-        setTargetFacility(facilityTree);
-        setTargetItemID(itemID);
-        this.m_graphType = graphType;
-
+    public void drawGraph(
+    		FacilityTreeItem facilityTree, 
+    		CollectorItemInfo itemInfo,
+            int graphType, 
+            Date startDate, 
+            Date endDate) {
+    	// 表示設定がまったく変更になっていない場合は再描画しない
+    	if(m_targetFacility == facilityTree && 
+    			m_currentItem == itemInfo &&
+    			m_graphStartTime == startDate.getTime() &&
+    			m_graphEndTime == endDate.getTime()){
+    		return;
+    	}
+    	
+        // 現在表示されているグラフを消去
+    	m_composite.clearData();
+    	
         // グラフを生成します。
-        createGraph();
+        if (m_collectorData == null || itemInfo == null) {
+            return;
+        }
 
-        double lowerBound = (this.m_composite.getHorizontalBar().getSelection()) * 1000D;
-        double upperBound = (this.m_composite.getHorizontalBar().getThumb() + this.m_composite
-                .getHorizontalBar().getSelection()) * 1000D;
+        String itemCode = itemInfo.getItemCode(); // 収集項目コード
+        String deviceName = itemInfo.getDeviceName();
 
-        drawGraph((long) lowerBound, (long) upperBound);
-    }
+        // 収集項目名をタイトルに設定
+        String title = CollectorItemCodeFactory.getFullItemName(itemCode, deviceName);
 
-    /**
-     * グラフを描画します。
-     * 
-     * @param lowerBound　表示されるグラフ範囲の最小時間
-     * @param upperBound　表示されるグラフ範囲の最大時間
-     */
-    private void drawGraph(long lowerBound, long upperBound) {
-        if (m_collectorData == null || m_itemInfoList == null
-                || m_currentItem == null || m_facilityTree == null) {
+//        if (CollectorItemCodeFactory.isDeviceSupport(itemCode)) {
+//            title = title + "(" + itemInfo.getDeviceName() + ")";
+//        }
+
+        if (graphType == GraphProperty.TYPE1) {
+            title = title + " "
+                    + Messages.getString("SCOPE_REPRESENTING_VALUE"); // "スコープ代表値"
+        } else if (graphType == GraphProperty.TYPE2) {
+            title = title + " "
+                    + Messages
+                            .getString("DETAIL_SCOPE_REPRESENTING_VALUE"); // "スコープ代表値詳細"
+        } else if (graphType == GraphProperty.TYPE3) {
+            title = title + " "
+                    + Messages
+                            .getString("SUB_SCOPE_REP_VAL"); // "サブスコープ代表値"
+        }
+
+//        Date stopDate; // 収集終了時刻
+//        if (m_collectorData.getStatus() == CollectorRunStatus.RUNNING) { // 収集中の場合
+//            long stopTime = m_collectorData.getStartDate().getTime()
+//                    + m_collectorData.getRealCollectPeriod();
+//            stopDate = new Date(stopTime);
+//        } else {
+//        	stopDate = m_collectorData.getStopDate();
+//        }
+
+        this.m_composite.createGraph(title, // タイトル
+        		Messages.getString("TIME"), // 横軸ラベル
+        		CollectorItemCodeFactory.getMeasure(itemCode), // 縦軸ラベル
+        		graphType, // グラフタイプ
+        		CollectorItemCodeFactory.isRangeFixed(itemCode), // 軸固定フラグ
+        		m_collectorData.getIntervalSec(), // インターバル
+        		startDate, // グラフ表示開始時刻
+        		endDate // グラフ表示終了時刻
+//        		m_collectorData.getStartDate(), // 収集開始時刻
+//        		m_collectorData.getLastCollectDate() //最終収集時刻
+        );
+
+
+        
+        
+        
+        if (m_collectorData == null || itemInfo == null) {
             return;
         }
         
-        long startTime = m_collectorData.getStartDate().getTime() + lowerBound;
-        long endTime = m_collectorData.getStartDate().getTime() + upperBound;
+//        GraphDisplayRange dr = getDisplayRange(
+//        		new GraphDisplayRange(startDate.getTime(), endDate.getTime()));
+//
+//        long startTime;
+//        long endTime;
+//        
+//        if (dr == null) {
+//            // 新規に描画する範囲はない
+//        	return;
+//        } else {
+//        	startTime = dr.getStartTime();
+//        	endTime = dr.getEndTime();
+//        }
+//
+//        // グラフに表示される時刻の前後2プロット分を余分に取得する。
+//        startDate = new Date(startTime
+//        		- this.m_collectorData.getIntervalSec() * 2 * 1000); // 秒単位
+//        endDate = new Date(endTime
+//        		+ this.m_collectorData.getIntervalSec() * 2 * 1000); // 秒単位
 
-        GraphDisplayRange dr = getDisplayRange(new GraphDisplayRange(startTime,
-                endTime));
-
-        if (dr == null) {
-            // 新規に描画する範囲はない
-        	return;
-        } else {
-            startTime = dr.getStartTime();
-            endTime = dr.getEndTime();
-        }
-
-        // グラフに表示される時刻の前後2プロット分を余分に取得する。
-        Date startDate = new Date(startTime
-                - this.m_collectorData.getInterval() * 2 * 1000); // 秒単位
-        Date endDate = new Date(endTime + this.m_collectorData.getInterval()
-                * 2 * 1000); // 秒単位
-
-        switch (m_graphType) {
+        switch (graphType) {
         case GraphProperty.TYPE1:
-            drawGraph1(m_currentItem, m_facilityTree, startDate, endDate);
-            break;
+        	drawGraph1(itemInfo, facilityTree, startDate, endDate);
+        	break;
         case GraphProperty.TYPE2:
-            drawGraph2(m_currentItem, m_facilityTree, startDate, endDate);
-            break;
+        	drawGraph2(itemInfo, facilityTree, startDate, endDate);
+        	break;
         case GraphProperty.TYPE3:
-            drawGraph3(m_currentItem, m_facilityTree, startDate, endDate);
-            break;
+        	drawGraph3(itemInfo, facilityTree, startDate, endDate);
+        	break;
         default:
-            break;
+        	break;
         }
 
-        // 描画した範囲を描画済み範囲リストに追加する
-        addGotTimeArea(dr);
+//        // 描画した範囲を描画済み範囲リストに追加する
+//        addGotTimeArea(dr);
+        
+    	// グラフ表示した内容で更新
+    	this.m_targetFacility = facilityTree;
+        this.m_currentItem = itemInfo;
+        this.m_graphType = graphType;
+        this.m_graphStartTime = startDate.getTime();
+        this.m_graphEndTime = endDate.getTime();
     }
 
     /**
@@ -182,9 +238,9 @@ public class DrawRecordGraphAction extends SelectionAdapter {
      * 
      * @param graphType
      */
-    public void setGraphType(int graphType) {
-        this.m_graphType = graphType;
-    }
+//    public void setGraphType(int graphType) {
+//        this.m_graphType = graphType;
+//    }
 
     /**
      * グラス種別を取得します。
@@ -195,21 +251,21 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         return this.m_graphType;
     }
 
-    /**
-     * グラフ描画対象の収集項目IDを設定します。
-     * 
-     * @param itemID 収集項目ID
-     */
-    public void setTargetItemID(int itemID) {
-        Iterator itr = this.m_itemInfoList.iterator();
-
-        while (itr.hasNext()) {
-            CollectorItemInfo itemInfo = (CollectorItemInfo) itr.next();
-            if (itemInfo.getCollectorItemID() == itemID) {
-                this.m_currentItem = itemInfo;
-            }
-        }
-    }
+//    /**
+//     * グラフ描画対象の収集項目IDを設定します。
+//     * 
+//     * @param itemID 収集項目ID
+//     */
+//    public void setTargetItemID(int itemID) {
+//        Iterator itr = this.m_itemInfoList.iterator();
+//
+//        while (itr.hasNext()) {
+//            CollectorItemInfo itemInfo = (CollectorItemInfo) itr.next();
+//            if (itemInfo.getCollectorItemID() == itemID) {
+//                this.m_currentItem = itemInfo;
+//            }
+//        }
+//    }
 
     /**
      * グラフ描画対象の収集項目IDを取得します。
@@ -220,17 +276,17 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         return this.m_currentItem;
     }
 
-    /**
-     * グラフ描画対象のファシリティ情報を設定します。
-     * 
-     * @param facilityTree ファシリティツリー
-     */
-    public void setTargetFacility(FacilityTreeItem facilityTree) {
-        this.m_facilityTree = facilityTree;
-
-        // グラフを生成します。
-        createGraph();
-    }
+//    /**
+//     * グラフ描画対象のファシリティ情報を設定します。
+//     * 
+//     * @param facilityTree ファシリティツリー
+//     */
+//    public void setTargetFacility(FacilityTreeItem facilityTree) {
+//        this.m_facilityTree = facilityTree;
+//
+//        // グラフを生成します。
+//        createGraph();
+//    }
 
     /**
      * グラフ描画対象のファシリティ情報を取得します。
@@ -238,75 +294,29 @@ public class DrawRecordGraphAction extends SelectionAdapter {
      * @return ファシリティツリー
      */
     public FacilityTreeItem getTargetFacility() {
-        return this.m_facilityTree;
+        return this.m_targetFacility;
     }
 
     /**
      * グラフを生成します。
      */
     public void createGraph() {
-        if (m_collectorData == null || m_itemInfoList == null
-                || m_currentItem == null) {
-            return;
-        }
 
-        String itemCode = m_currentItem.getCollectorItemCode(); // 収集項目コード
-        String deviceName = m_currentItem.getDeviceName();
-
-        String title = CollectorItemCodeFactory.getCategoryName(itemCode);
-
-        if (CollectorItemCodeFactory.isDeviceSupport(itemCode)) {
-            title = title + "(" + m_currentItem.getDeviceName() + ")";
-        }
-
-        if (this.m_graphType == GraphProperty.TYPE1) {
-            title = title + " "
-                    + Messages.getString("SCOPE_REPRESENTING_VALUE"); // "スコープ代表値"
-        } else if (this.m_graphType == GraphProperty.TYPE2) {
-            title = title + " "
-                    + Messages
-                            .getString("DETAIL_SCOPE_REPRESENTING_VALUE"); // "スコープ代表値詳細"
-        } else if (this.m_graphType == GraphProperty.TYPE3) {
-            title = title + " "
-                    + Messages
-                            .getString("SUB_SCOPE_REP_VAL"); // "サブスコープ代表値"
-        }
-
-        Date stopDate; // 収集終了時刻
-        if (m_collectorData.getStatus() == CollectorRunStatus.RUNNING) { // 収集中の場合
-            long stopTime = m_collectorData.getStartDate().getTime()
-                    + m_collectorData.getRealCollectPeriod();
-            stopDate = new Date(stopTime);
-        } else {
-            stopDate = m_collectorData.getStopDate();
-        }
-
-        this.m_composite.createGraph(title, // タイトル
-                Messages.getString("TIME"), // 横軸ラベル
-                CollectorItemCodeFactory.getFullItemName(itemCode, deviceName)
-                        + "("
-                        + CollectorItemCodeFactory.getMeasure(itemCode) + ")", // 縦軸ラベル
-                m_graphType, // グラフタイプ
-                CollectorItemCodeFactory.isRangeFixed(itemCode), // 軸固定フラグ
-                m_collectorData.getInterval(), // インターバル
-                m_collectorData.getStartDate(), // 収集開始時刻
-                stopDate // 収集終了時刻
-                );
     }
 
-    /**
-     * Widgetが選択されたときのアクションを定義します。
-     */
-    public synchronized void widgetSelected(
-            org.eclipse.swt.events.SelectionEvent e) {
-        double lowerBound = (this.m_composite.getHorizontalBar().getSelection()) * 1000D;
-        double upperBound = (this.m_composite.getHorizontalBar().getThumb() + this.m_composite
-                .getHorizontalBar().getSelection()) * 1000D;
-
-        this.drawGraph((long) lowerBound, (long) upperBound);
-
-        this.m_composite.setRange(lowerBound, upperBound);
-    }
+//    /**
+//     * Widgetが選択されたときのアクションを定義します。
+//     */
+//    public synchronized void widgetSelected(
+//            org.eclipse.swt.events.SelectionEvent e) {
+//        double lowerBound = (this.m_composite.getHorizontalBar().getSelection()) * 1000D;
+//        double upperBound = (this.m_composite.getHorizontalBar().getThumb() + this.m_composite
+//                .getHorizontalBar().getSelection()) * 1000D;
+//
+//        this.drawGraph((long) lowerBound, (long) upperBound);
+//
+//        this.m_composite.setRange(lowerBound, upperBound);
+//    }
 
     /**
      * 
@@ -319,13 +329,9 @@ public class DrawRecordGraphAction extends SelectionAdapter {
      */
     public synchronized void drawGraph1(CollectorItemInfo itemInfo,
             FacilityTreeItem treeItem, Date startDate, Date endDate) {
-
+    	
         // マネージャからデータを取得
-        String[] facilityIDs = new String[1];
-        facilityIDs[0] = treeItem.getData().getFacilityId();
-
-        int[] itemIDs = new int[1];
-        itemIDs[0] = itemInfo.getCollectorItemID();
+        String facilityId = treeItem.getData().getFacilityId();
 
         RecordController controller = RecordController.getInstance();
         // マネージャとの接続に失敗した場合はエラーダイアログを表示
@@ -336,69 +342,25 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             return;
         }
 
-        CollectedDataSet dataSet = controller.getRecordCollectedData(itemInfo
-                .getCollectorID(), facilityIDs, itemIDs, startDate, endDate);
-        // 性能データの取得に失敗した場合はエラーダイアログを表示
-        if (dataSet == null) {
-            MessageDialog.openError(this.m_composite.getShell(), 
-            		Messages.getString("MESSAGE_0020"),  // "確認"
-            		Messages.getString("GET_COLLECTEDDATA_ERROR_MESSAGE"));
-            return;
-        }
-
-        List dataList = dataSet
-                .getCollectedDataList(facilityIDs[0], itemIDs[0]);
-
-        if (dataList.size() != 0) { // 収集中のグラフ表示ではマネージャから値を取得できていない場合もあるため
-            // グラフに値を設定
-            setItemData(itemInfo.getCollectorItemCode(), itemInfo
-                    .getDeviceName(), dataList);
-        }
-    }
-
-    public synchronized void drawGraph1Test1(
-    		String collectorID,
-    		String itemCode,
-			CollectorItemInfo itemInfo,
-			String facilityId,
-			Date startDate,
-			Date endDate) {
-
-        // マネージャからデータを取得
-        String[] facilityIDs = new String[1];
-        facilityIDs[0] = facilityId;
-
-        int[] itemIDs = new int[1];
-        itemIDs[0] = itemInfo.getCollectorItemID();
-
-        RecordController controller = RecordController.getInstance();
-        // マネージャとの接続に失敗した場合はエラーダイアログを表示
-        if (controller == null) {
-            MessageDialog.openError(this.m_composite.getShell(), 
-            		Messages.getString("MESSAGE_0020"), 
-            		Messages.getString("CONNECTION_ERROR_MESSAGE"));
-            return;
-        }
-
         CollectedDataSet dataSet = controller.getRecordCollectedData(
-        		collectorID, facilityIDs, itemIDs, startDate, endDate);
+        		facilityId, itemInfo, startDate, endDate);
         // 性能データの取得に失敗した場合はエラーダイアログを表示
         if (dataSet == null) {
             MessageDialog.openError(this.m_composite.getShell(), 
-            		Messages.getString("MESSAGE_0020"), 
+            		Messages.getString("MESSAGE_0020"),  // "確認"
             		Messages.getString("GET_COLLECTEDDATA_ERROR_MESSAGE"));
             return;
         }
 
-        List dataList = dataSet
-                .getCollectedDataList(facilityIDs[0], itemIDs[0]);
+        List<CollectedDataInfo> dataList = dataSet
+                .getCollectedDataList(facilityId, itemInfo);
 
         if (dataList.size() != 0) { // 収集中のグラフ表示ではマネージャから値を取得できていない場合もあるため
             // グラフに値を設定
-            setItemData(itemCode, "itemInfo.getDeviceName()", dataList);
+            setItemData(itemInfo.getItemCode(), itemInfo
+                    .getDeviceName(), dataList);
         }
     }
-  
     
     /**
      * 指定の収集項目の詳細情報を内訳グラフとして表示します。（指定の収集項目のグラフを描画するわけではない）
@@ -411,10 +373,10 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     public synchronized void drawGraph2(CollectorItemInfo itemInfo,
             FacilityTreeItem treeItem, Date startDate, Date endDate) {
         // 内訳グラフ描画に必要な収集項目のリストを取得
-        List itemInfoList = selectItemInfo(itemInfo, this.m_itemInfoList);
+        List<CollectorItemInfo> itemInfoList = selectItemInfo(itemInfo, this.m_itemInfoList);
 
         // 内訳グラフの表示に必要な項目が収集されていない場合はエラー
-        if (itemInfoList == null) {
+        if (itemInfoList == null || itemInfoList.size() == 0) {
             // エラー処理
             MessageDialog.openError(this.m_composite.getShell(), 
             		Messages.getString("MESSAGE_0020"), 
@@ -423,15 +385,8 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         }
 
         // マネージャからデータを取得
-        String[] facilityID = new String[1];
-        facilityID[0] = treeItem.getData().getFacilityId();
-
-        int[] itemIDs = new int[itemInfoList.size()];
-        for (int i = 0; i < itemIDs.length; i++) {
-            itemIDs[i] = ((CollectorItemInfo) (itemInfoList.get(i)))
-                    .getCollectorItemID();
-        }
-
+        String facilityId = treeItem.getData().getFacilityId();
+ 
         RecordController controller = RecordController.getInstance();
         // マネージャとの接続に失敗した場合はエラーダイアログを表示
         if (controller == null) {
@@ -441,8 +396,8 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             return;
         }
 
-        CollectedDataSet dataSet = controller.getRecordCollectedData(itemInfo
-                .getCollectorID(), facilityID, itemIDs, startDate, endDate);
+        CollectedDataSet dataSet = controller.getRecordCollectedData(
+        		facilityId, itemInfoList, startDate, endDate);
         // 性能データの取得に失敗した場合はエラーダイアログを表示
         if (dataSet == null) {
             MessageDialog.openError(this.m_composite.getShell(), 
@@ -451,37 +406,37 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             return;
         }
 
-        ArrayList addedDataList = new ArrayList();
+        ArrayList<List<CollectedDataInfo>> addedDataList = new ArrayList<List<CollectedDataInfo>>();
         // 面グラフにするために値を加工
-        Iterator itr = itemInfoList.iterator();
+        Iterator<CollectorItemInfo> itr = itemInfoList.iterator();
+        List<CollectedDataInfo> collectedDataListTotal = null; // 性能値の合計を保持するリスト
         while (itr.hasNext()) {
-            CollectorItemInfo buffer = (CollectorItemInfo) itr.next();
-            List collectedDataList = dataSet.getCollectedDataList(treeItem
-                    .getData().getFacilityId(), buffer.getCollectorItemID());
+            CollectorItemInfo buffer = itr.next();
+            List<CollectedDataInfo> collectedDataList = dataSet.getCollectedDataList(
+            		treeItem.getData().getFacilityId(), buffer);
 
-            int size = addedDataList.size();
-            // 今まで取得したデータのリストに現在取得した値を足し込む
-            for (int i = 0; i < size; i++) {
-                List dataBuffer = (List) addedDataList.get(i);
-                addedDataList.set(i, getSumData(dataBuffer, collectedDataList));
+            if(addedDataList.size() == 0){
+            	collectedDataListTotal = collectedDataList;
+            } else {
+            	// 前の項目までの合計値
+            	collectedDataListTotal = getSumData(collectedDataListTotal, collectedDataList);
             }
-            addedDataList.add(collectedDataList);
+
+           	addedDataList.add(collectedDataListTotal);
         }
 
         // 時刻の最大値と最小値を設定
-        List bufferList = (List) addedDataList.get(0); // どれも同じ時刻であるため最初の要素で求める
+        List<CollectedDataInfo> bufferList = addedDataList.get(0); // どれも同じ時刻であるため最初の要素で求める
 
         if (bufferList.size() != 0) { // 収集中のグラフ表示ではマネージャから値を取得できていない場合もあるため
 
-            // グラフに値を設定
-            int itemSize = itemInfoList.size();
-            for (int i = 0; i < itemSize; i++) {
-                CollectorItemInfo buffer = (CollectorItemInfo) itemInfoList
-                        .get(i);
-                List collectedDataList = (List) addedDataList.get(i);
-                setItemData(buffer.getCollectorItemCode(), buffer
-                        .getDeviceName(), collectedDataList);
-            }
+        	// グラフに値を設定
+        	int itemSize = itemInfoList.size();
+        	for (int i = 0; i < itemSize; i++) {
+        		CollectorItemInfo buffer = itemInfoList.get(i);
+        		List<CollectedDataInfo> collectedDataList = addedDataList.get(i);
+        		setItemData(buffer.getItemCode(), buffer.getDeviceName(), collectedDataList);
+        	}
         }
     }
 
@@ -497,20 +452,14 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             FacilityTreeItem treeItem, Date startDate, Date endDate) {
         // 子スコープを設定する
         FacilityTreeItem[] children = treeItem.getChildren();
-        ArrayList targetFacilitys = new ArrayList();
+        ArrayList<String> targetFacilitys = new ArrayList<String>();
+        ArrayList<String> targetFacilityNames = new ArrayList<String>();
         for (int i = 0; i < children.length; i++) {
-            targetFacilitys.add(children[i].getData());
+            targetFacilitys.add(children[i].getData().getFacilityId());
+            targetFacilityNames.add(children[i].getData().getFacilityName());
         }
 
         // マネージャからデータを取得
-        String[] facilityIDs = new String[targetFacilitys.size()];
-        for (int i = 0; i < facilityIDs.length; i++) {
-            facilityIDs[i] = ((FacilityInfo) (targetFacilitys.get(i)))
-                    .getFacilityId();
-        }
-
-        int[] itemID = new int[1];
-        itemID[0] = itemInfo.getCollectorItemID();
 
         RecordController controller = RecordController.getInstance();
         // マネージャとの接続に失敗した場合はエラーダイアログを表示
@@ -521,8 +470,11 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             return;
         }
 
-        CollectedDataSet dataSet = controller.getRecordCollectedData(itemInfo
-                .getCollectorID(), facilityIDs, itemID, startDate, endDate);
+        CollectedDataSet dataSet = controller.getRecordCollectedData(
+        		targetFacilitys, 
+        		itemInfo, 
+        		startDate, 
+        		endDate);
         // 性能データの取得に失敗した場合はエラーダイアログを表示
         if (dataSet == null) {
             MessageDialog.openError(this.m_composite.getShell(), 
@@ -531,36 +483,29 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             return;
         }
 
-        // 時刻の最大値と最小値を設定
-        String facilityID = ((FacilityInfo) targetFacilitys.get(0))
-                .getFacilityId(); // どれも同じ時刻であるため最初の要素で求める
-        List bufferList = (List) dataSet.getCollectedDataList(facilityID,
-                itemInfo.getCollectorItemID());
-
-        if (bufferList.size() != 0) { // 収集中のグラフ表示ではマネージャから値を取得できていない場合もあるため
-
-            // グラフに値を設定
-            Iterator itr = targetFacilitys.iterator();
-            int i = 0;
-            while (itr.hasNext()) {
-                FacilityInfo facilityInfo = (FacilityInfo) itr.next();
-                List collectedDataList = dataSet.getCollectedDataList(
-                        facilityInfo.getFacilityId(), itemInfo
-                                .getCollectorItemID());
-                setFacilityData(i, collectedDataList);
-                i++;
-            }
-        }
+		// グラフに値を設定
+		Iterator<String> itr = targetFacilitys.iterator();
+		int i = 0;
+		while (itr.hasNext()) {
+			String targetFacility = itr.next();
+			List<CollectedDataInfo> collectedDataList = 
+					dataSet.getCollectedDataList(targetFacility, itemInfo);
+			setFacilityData(i, collectedDataList, targetFacilityNames);
+			i++;
+		}
     }
 
     /**
-     * 凡例を収集項目名として、グラフに値を設定します。（スコープ代表値グラフ、内訳グラフの場合）
-     * 
-     * @param composite グラフを関連づけるコンポジット
-     * @param itemCode 収集項目コード
-     * @param data 性能値
-     */
-    private void setItemData(String itemCode, String deviceName, List data) {
+	 * 凡例を収集項目名として、グラフに値を設定します。（スコープ代表値グラフ、内訳グラフの場合）
+	 * 
+	 * @param composite
+	 *            グラフを関連づけるコンポジット
+	 * @param itemCode
+	 *            収集項目コード
+	 * @param data
+	 *            性能値
+	 */
+    private void setItemData(String itemCode, String deviceName, List<CollectedDataInfo> data) {
         this.m_composite.setGraphData(CollectorItemCodeFactory.getFullItemName(
                 itemCode, deviceName), data);
     }
@@ -572,8 +517,8 @@ public class DrawRecordGraphAction extends SelectionAdapter {
      * @param itemCode 収集項目コード
      * @param data 性能値
      */
-    private void setFacilityData(int index, List data) {
-        this.m_composite.setSubscopeGraphData(index, data);
+    private void setFacilityData(int index, List<CollectedDataInfo> data, ArrayList<String> facilityNames) {
+        this.m_composite.setSubscopeGraphData(index, data, facilityNames);
     }
 
     /**
@@ -581,30 +526,29 @@ public class DrawRecordGraphAction extends SelectionAdapter {
      * 
      * @param itemList 収集項目のリスト
      */
-    private List selectItemInfo(CollectorItemInfo target, List itemList) {
-        ArrayList returnList = new ArrayList();
+    private List<CollectorItemInfo> selectItemInfo(CollectorItemInfo target, List<CollectorItemInfo> itemList) {
+        ArrayList<CollectorItemInfo> returnList = new ArrayList<CollectorItemInfo>();
 
         // 内訳表示に必要な収集項目コードを取得
-        List itemCodeList = CollectorItemCodeFactory.getSubItemCode(target
-                .getCollectorItemCode());
+        List<String> itemCodeList = CollectorItemCodeFactory.getSubItemCode(target
+                .getItemCode());
 
-        // デバイスインデックスを取得
-        int deviceIndex = target.getDeviceIndex();
+        // デバイス名を取得
+        String deviceName = target.getDeviceName();
 
         // 内訳表示に必要な収集項目コードの数だけループ
-        Iterator itrItemCodeList = itemCodeList.iterator();
+        Iterator<String> itrItemCodeList = itemCodeList.iterator();
         while (itrItemCodeList.hasNext()) {
-            String itemCode = (String) itrItemCodeList.next();
+            String itemCode = itrItemCodeList.next();
 
             CollectorItemInfo buffer = null;
 
-            Iterator itrItemList = itemList.iterator();
+            Iterator<CollectorItemInfo> itrItemList = itemList.iterator();
             while (itrItemList.hasNext()) {
-                CollectorItemInfo itemInfo = (CollectorItemInfo) itrItemList
-                        .next();
-                // itemList内に収集項目コードとデバイスインデックが同じ要素が重複して存在しないことが前提
-                if (itemInfo.getCollectorItemCode().equals(itemCode)
-                        && itemInfo.getDeviceIndex() == deviceIndex) {
+                CollectorItemInfo itemInfo = itrItemList.next();
+                // itemList内に収集項目コードとデバイス名が同じ要素が重複して存在しないことが前提
+                if (itemInfo.getItemCode().equals(itemCode)
+                        && itemInfo.getDeviceName().equals(deviceName)) {
                     buffer = itemInfo;
                 }
             }
@@ -622,23 +566,27 @@ public class DrawRecordGraphAction extends SelectionAdapter {
     /**
      * 2つの収集済み性能値リストの和をとります。
      */
-    private List getSumData(List dataSet1, List dataSet2) {
-        ArrayList dataList = new ArrayList();
+    private List<CollectedDataInfo> getSumData(List<CollectedDataInfo> dataSet1, List<CollectedDataInfo> dataSet2) {
+        ArrayList<CollectedDataInfo> dataList = new ArrayList<CollectedDataInfo>();
 
-        if (dataSet1.size() != dataSet2.size()) {
-            // エラー処理
-        }
+        Iterator<CollectedDataInfo> itr1 = dataSet1.iterator();
+        Iterator<CollectedDataInfo> itr2 = dataSet2.iterator();
 
-        Iterator itr1 = dataSet1.iterator();
-        Iterator itr2 = dataSet2.iterator();
-
-        while (itr1.hasNext()) {
-            CollectedDataInfo data1 = (CollectedDataInfo) itr1.next();
-            CollectedDataInfo data2 = (CollectedDataInfo) itr2.next();
-            CollectedDataInfo returnData = new CollectedDataInfo(data1
-                    .getFacilityID(), data1.getCollectorItemID(), data1
-                    .getDate(), data1.getValue() + data2.getValue());
-            dataList.add(returnData);
+        while (itr1.hasNext() && itr2.hasNext()) {
+        	CollectedDataInfo data1 = itr1.next();
+            CollectedDataInfo data2 = itr2.next();
+            
+            // 時刻がずれている場合は、別時刻の収集値であるため加算しない
+            if(data1.getDate().getTime() == data2.getDate().getTime()){
+            	CollectedDataInfo returnData = new CollectedDataInfo(
+            			data1.getFacilityId(), 
+            			data1.getItemCode(),
+            			data1.getDeviceName(),
+            			data1.getCollectMethod(),
+            			data1.getDate(), 
+            			data1.getValue() + data2.getValue());
+            	dataList.add(returnData);
+            }
         }
 
         return dataList;
@@ -657,7 +605,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
             return;
         }
 
-        Iterator itr = m_gotTimeArea.iterator();
+        Iterator<GraphDisplayRange> itr = m_gotTimeArea.iterator();
 
         while (itr.hasNext()) {
             GraphDisplayRange drBuffer = (GraphDisplayRange) itr.next();
@@ -720,7 +668,7 @@ public class DrawRecordGraphAction extends SelectionAdapter {
         returnDr.setStartTime(dr.getStartTime());
         returnDr.setEndTime(dr.getEndTime());
 
-        Iterator itr = m_gotTimeArea.iterator();
+        Iterator<GraphDisplayRange> itr = m_gotTimeArea.iterator();
 
         while (itr.hasNext()) {
             GraphDisplayRange drBuffer = (GraphDisplayRange) itr.next();
