@@ -29,6 +29,7 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
 import com.clustercontrol.bean.DataRangeConstant;
+import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.dialog.CommonDialog;
@@ -36,8 +37,8 @@ import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.monitor.run.bean.MonitorInfo;
 import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
 import com.clustercontrol.monitor.run.composite.MonitorBlockComposite;
-import com.clustercontrol.monitor.run.composite.NumericRunJobComposite;
 import com.clustercontrol.monitor.run.composite.NumericValueInfoComposite;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
 import com.clustercontrol.notify.composite.NotifyInfoComposite;
 import com.clustercontrol.performance.monitor.action.AddPerformance;
 import com.clustercontrol.performance.monitor.action.GetPerformance;
@@ -45,13 +46,13 @@ import com.clustercontrol.performance.monitor.action.ModifyPerformance;
 import com.clustercontrol.performance.monitor.composite.CollectorItemComboComposite;
 import com.clustercontrol.performance.monitor.composite.PerfMonitorBasicScopeComposite;
 import com.clustercontrol.performance.monitor.composite.PerfMonitorRuleComposite;
-import com.clustercontrol.performanceMGR.monitor.bean.MonitorPerfCheckInfo;
+import com.clustercontrol.performance.monitor.bean.MonitorPerfCheckInfo;
 import com.clustercontrol.util.Messages;
 
 /**
  * リソース監視作成・変更ダイアログクラス
  * 
- * @version 2.2.0
+ * @version 3.0.0
  * @since 2.0.0
  */
 public class PerformanceCreateDialog extends CommonDialog {
@@ -91,12 +92,6 @@ public class PerformanceCreateDialog extends CommonDialog {
     /** 通知情報 */
     private NotifyInfoComposite notifyInfo = null;
     
-    /** ジョブ実行 */
-    private Button m_checkJobRun = null;
-    
-    /** ジョブ実行情報 */
-    private NumericRunJobComposite m_jobRun = null;
-    
     /** この設定を有効にする */
     private Button confirmValid = null;
 
@@ -314,40 +309,7 @@ public class PerformanceCreateDialog extends CommonDialog {
 		gridData.grabExcessHorizontalSpace = true;
 		notifyInfo.setLayoutData(gridData);
 		
-		// ジョブ実行
-        this.m_checkJobRun = new Button(groupNotifyAttribute, SWT.CHECK);
-        gridData = new GridData();
-        gridData.horizontalSpan = 1;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        m_checkJobRun.setLayoutData(gridData);
-        m_checkJobRun.setText(Messages.getString("run") + " : ");
-        m_checkJobRun.addSelectionListener(new SelectionAdapter() {
-            public void widgetSelected(SelectionEvent e) {
-            	m_jobRun.setEnabled(m_checkJobRun.getSelection());
-            }
-        });
 		
-		// ジョブ実行グループ
-        Group groupRunJob = new Group(groupNotifyAttribute, SWT.NONE);
-        layout = new GridLayout(1, true);
-        layout.marginWidth = 5;
-        layout.marginHeight = 5;
-        layout.numColumns = 1;
-        groupRunJob.setLayout(layout);
-        gridData = new GridData();
-        gridData.horizontalSpan = 15;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        groupRunJob.setLayoutData(gridData);
-        
-        // 実行（実行，ジョブID，通知抑制と連動，呼出失敗時）
-		this.m_jobRun = new NumericRunJobComposite(groupRunJob, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = 1;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		m_jobRun.setLayoutData(gridData);
 		
         /*
          * 有効／無効
@@ -431,20 +393,16 @@ public class PerformanceCreateDialog extends CommonDialog {
         // ノード単位の結果判定の定義
         m_numericValueInfo.setInputData(monitor);
     	
-        // 通知情報の属性
-        if (monitor.getNotifyId() != null) {
-        	this.notifyInfo.setText(monitor.getNotifyId());
-        }
+    	
+        //通知情報の設定
+        if(monitor.getNotifyId() != null)
+        this.notifyInfo.setNotify(monitor.getNotifyId());
+
+        
         if (monitor.getApplication() != null) {
         	this.notifyInfo.setApplication(monitor.getApplication());
         }
         
-        // ジョブ実行
-        m_checkJobRun.setSelection(YesNoConstant.typeToBoolean(monitor.getJobRun()));
-        
-        // 各重要度のジョブ実行
-        m_jobRun.setInputData(monitor);
-        m_jobRun.setEnabled(YesNoConstant.typeToBoolean(monitor.getJobRun()));
         
         // 有効／無効
         if (monitor.getValid() == ValidConstant.TYPE_VALID) {
@@ -463,7 +421,7 @@ public class PerformanceCreateDialog extends CommonDialog {
         MonitorPerfCheckInfo perfCheckInfo = new MonitorPerfCheckInfo();
         info.setCheckInfo(perfCheckInfo);
     	
-    	info.setMonitorTypeId("PERF");
+    	info.setMonitorTypeId(HinemosModuleConstant.MONITOR_PERFORMANCE);
     	info.setMonitorType(MonitorTypeConstant.TYPE_NUMERIC);
     	
     	// 監視基本情報
@@ -499,32 +457,38 @@ public class PerformanceCreateDialog extends CommonDialog {
         	return null;
         }
         
-        // 通知情報の属性
-        if (this.notifyInfo.getText() != null
-                && !"".equals((this.notifyInfo.getText()).trim())) {
-        	info.setNotifyId(notifyInfo.getText());
-        }
-        else{
-        	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.9"));
-            return null;
-        }
-        if (this.notifyInfo.getApplication() != null
-                && !"".equals((this.notifyInfo.getApplication()).trim())) {
-        	info.setApplication(notifyInfo.getApplication());
-        }
-        else{
-        	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.10"));
-            return null;
-        }
+        //通知関連情報の設定
+		// 通知グループIDの設定
+		info.setNotifyGroupId(NotifyRelationInfo.createNotifyGroupId(HinemosModuleConstant.MONITOR_PERFORMANCE, info.getMonitorId()));
+		validateResult = notifyInfo.createInputData(info);
+		if (validateResult != null) {
+			if(validateResult.getID() == null){	// 通知ID警告用出力
+				if(!displayQuestion(validateResult)){
+					validateResult = null;
+					return null;
+				}
+			}
+			else{	// アプリケーション未入力チェック
+				return null;
+			}
+		}
+		
+//        //通知グループIDの設定
+//        info.setNotifyGroupId(NotifyRelationInfo.createNotifyGroupId(HinemosModuleConstant.MONITOR_PERFORMANCE,info.getMonitorId()));
+//        //通知情報へのNotifyGroupIdのセット
+//        this.notifyInfo.setNotifyGroupId(info.getNotifyGroupId());
+//        //コンポジットから通知情報を取得します。
+//        info.setNotifyId(this.notifyInfo.getNotify());
         
-        // ジョブ実行
-        info.setJobRun(YesNoConstant.booleanToType(m_checkJobRun.getSelection()));
+//        if (this.notifyInfo.getApplication() != null
+//                && !"".equals((this.notifyInfo.getApplication()).trim())) {
+//        	info.setApplication(notifyInfo.getApplication());
+//        }
+//        else{
+//        	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.10"));
+//            return null;
+//        }
         
-        // 各重要度のジョブ実行
-        validateResult = m_jobRun.createInputData(info);
-        if(validateResult != null){
-        	return null;
-        }
         
         // 有効/無効
         if (this.confirmValid.getSelection()) {
