@@ -38,7 +38,7 @@ import com.clustercontrol.performance.util.RealtimeCollectorInfo;
 import com.clustercontrol.performance.util.RealtimeCollectorItemInfo;
 import com.clustercontrol.performance.view.action.RealtimeSetGraphAction;
 import com.clustercontrol.performance.view.action.RealtimeSetGraphAction2;
-import com.clustercontrol.performanceMGR.bean.CollectorItemInfo;
+import com.clustercontrol.performance.bean.CollectorItemInfo;
 import com.clustercontrol.view.ScopeListBaseView;
 
 /**
@@ -93,14 +93,11 @@ public class RealtimeGraphView extends ScopeListBaseView {
 
 		// 動的に項目を設定する場合には、この方式は対応しきれない.
 		// 位置情報itemIdがNULLのときは初期状態と判定し、値がセットされているときは前回設定があると判定する.
-		collectorItemInfo.setItemInfo(0, "00000000", "NonDisplay", "0", "0",
-				null, true); // CPU(CODE_CPU_UTILIZATION)
-		collectorItemInfo.setItemInfo(1, "00000000", "NonDisplay", "0", "0",
-				null, true); // CPU(CODE_CPU_UTILIZATION)
-		collectorItemInfo.setItemInfo(2, "00000000", "NonDisplay", "0", "0",
-				null, true); // CPU(CODE_CPU_UTILIZATION)
-		collectorItemInfo.setItemInfo(3, "00000000", "NonDisplay", "0", "0",
-				null, true); // CPU(CODE_CPU_UTILIZATION)
+		// FIXME DBのマスタ情報が"CPU0100_CPU_UTIL"ではなくなった場合エラーとなる
+		collectorItemInfo.setItemInfo(0, "CPU0100_CPU_UTIL", "NonDisplay",	"", true); // CPU(CODE_CPU_UTILIZATION)
+		collectorItemInfo.setItemInfo(1, "CPU0100_CPU_UTIL", "NonDisplay",	"", true); // CPU(CODE_CPU_UTILIZATION)
+		collectorItemInfo.setItemInfo(2, "CPU0100_CPU_UTIL", "NonDisplay",	"", true); // CPU(CODE_CPU_UTILIZATION)
+		collectorItemInfo.setItemInfo(3, "CPU0100_CPU_UTIL", "NonDisplay",	"", true); // CPU(CODE_CPU_UTILIZATION)
 
 		String itemCodeList[] = CollectorItemCodeFactory.getCodeAll();
 		int itemCodeNum = 0;
@@ -125,8 +122,7 @@ public class RealtimeGraphView extends ScopeListBaseView {
 					isDetailed = false;
 				}
 				// 右の値はダミー値 : index=0, itemId=0, deviceName=dummy.
-				collectorItemInfo.setItemInfoForCollector(j, itemCodeList[i],
-						"0", "0", null, isDetailed);
+				collectorItemInfo.setItemInfoForCollector(j, itemCodeList[i], null, isDetailed);
 				j = j + 1;
 			}
 		} // for
@@ -199,16 +195,18 @@ public class RealtimeGraphView extends ScopeListBaseView {
 					// スコープ詳細表示可能であるか否かをチェックする.
 					boolean isDetailed = true;
 					List factorySubItemCodeList = CollectorItemCodeFactory
-							.getSubItemCode(itemInfo.getCollectorItemCode());
+							.getSubItemCode(itemInfo.getItemCode());
 					if (factorySubItemCodeList == null
 							|| factorySubItemCodeList.size() == 0) { // 子項目が存在しない項目の場合.
 						isDetailed = false;
 					}
 
-					collectorItemInfo.setItemInfoForCollector(i, itemInfo
-							.getCollectorItemCode(), Integer.toString(itemInfo
-							.getDeviceIndex()), Integer.toString(itemInfo
-							.getCollectorItemID()), itemInfo.getDeviceName(),
+					
+					
+					collectorItemInfo.setItemInfoForCollector(
+							i, 
+							itemInfo.getItemCode(), 
+							itemInfo.getDeviceName(),
 							isDetailed);
 				}
 			}
@@ -222,14 +220,10 @@ public class RealtimeGraphView extends ScopeListBaseView {
 						if (collectorItemInfo.getItemCode(i).equals(
 								collectorItemInfo.getItemCodeForCollector(j))
 								&& collectorItemInfo.getDeviceName(i).equals(
-										collectorItemInfo
-												.getDeviceNameForCollector(j))) {
-							collectorItemInfo.setItemId(i, Integer.toString(j));
+										collectorItemInfo.getDeviceNameForCollector(j))) {
 							found = true;
 							if (!collectorItemInfo.hasDevice(i)) {
 								collectorItemInfo.setHasDevice(i, true);
-								collectorItemInfo.setItemId(i, Integer
-										.toString(j)); // 収集対称のitemIdをセットする.
 							}
 							break loop2;
 						}
@@ -352,12 +346,9 @@ public class RealtimeGraphView extends ScopeListBaseView {
 
 			for (int i = 0; i < graphNum; i++) {
 				String itemCode = collectorItemInfo.getItemCode(i);
-				String itemId = collectorItemInfo.getItemId(i);
 				String deviceName = collectorItemInfo.getDeviceName(i); //  .getDeviceNameForCollector(Integer.valueOf(collectorItemInfo.getItemId(i)));
 				String displayType = collectorItemInfo.getDisplayType(i);
 				int graphPlotNum = collectorInfo.getGraphPlotNum();
-				int deviceIndex = Integer.valueOf(collectorItemInfo
-						.getDeviceIndex(i));
 
 				graphComposite.addGraph(i, //graphId,
 						itemCode, deviceName, collectorInfo.getSubScopeNum(),
@@ -366,8 +357,8 @@ public class RealtimeGraphView extends ScopeListBaseView {
 				collectorItemInfo.setIsCollect(i, graphComposite.isCollect());
 
 				if (graphComposite.isCollect()) {
-					setCollector(timestamp, timestampId, itemCode, itemId,
-							deviceIndex, deviceName, displayType, interval,
+					setCollector(timestamp, timestampId, itemCode,
+							deviceName, displayType, interval,
 							facilityId);
 				}
 			}
@@ -392,7 +383,7 @@ public class RealtimeGraphView extends ScopeListBaseView {
 	}
 
 	private void setCollector(Date timestamp, int collectTimestampId,
-			String itemCode, String itemId, int deviceIndex, String deviceName,
+			String itemCode, String deviceName,
 			String displayType, int interval, String facilityId) {
 		int requestInterval = collectorInfo.getRequestInterval();
 
@@ -400,7 +391,7 @@ public class RealtimeGraphView extends ScopeListBaseView {
 		}
 		// Threadインスタンスの生成(Threadの実行はまだ)
 		collector = new RealtimeCollectThread(timestamp, collectTimestampId,
-				graphComposite.m_timeseries, itemCode, itemId, deviceIndex,
+				graphComposite.m_timeseries, itemCode,
 				deviceName, displayType, interval, requestInterval, facilityId,
 				check, graphComposite); // 軸の変更対象を伝えるため.
 
