@@ -16,8 +16,6 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.ping.dialog;
 
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.events.SelectionAdapter;
-import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -31,11 +29,10 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.bean.DataRangeConstant;
-import com.clustercontrol.bean.MonitorConstant;
+import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.PingRunCountConstant;
 import com.clustercontrol.bean.PingRunIntervalConstant;
 import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.composite.PositiveNumberVerifyListener;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
@@ -46,8 +43,8 @@ import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
 import com.clustercontrol.monitor.run.composite.MonitorBasicScopeComposite;
 import com.clustercontrol.monitor.run.composite.MonitorBlockComposite;
 import com.clustercontrol.monitor.run.composite.MonitorRuleComposite;
-import com.clustercontrol.monitor.run.composite.NumericRunJobComposite;
 import com.clustercontrol.monitor.run.composite.NumericValueInfoComposite;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
 import com.clustercontrol.notify.composite.NotifyInfoComposite;
 import com.clustercontrol.ping.action.AddPing;
 import com.clustercontrol.ping.action.GetPing;
@@ -58,7 +55,7 @@ import com.clustercontrol.util.Messages;
 /**
  * ping監視作成・変更ダイアログクラス<BR>
  * 
- * @version 2.2.0
+ * @version 3.0.0
  * @since 2.0.0
  */
 public class PingCreateDialog extends CommonDialog {
@@ -104,8 +101,6 @@ public class PingCreateDialog extends CommonDialog {
     /** ジョブ実行 */
     private Button m_checkJobRun = null;
     
-    /** ジョブ実行情報 */
-    private NumericRunJobComposite m_jobRun = null;
     
     /** この設定を有効にする */
     private Button confirmValid = null;
@@ -428,41 +423,7 @@ public class PingCreateDialog extends CommonDialog {
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		notifyInfo.setLayoutData(gridData);
-		
-		// ジョブ実行
-        this.m_checkJobRun = new Button(groupNotifyAttribute, SWT.CHECK);
-        gridData = new GridData();
-        gridData.horizontalSpan = 1;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        m_checkJobRun.setLayoutData(gridData);
-        m_checkJobRun.setText(Messages.getString("run") + " : ");
-        m_checkJobRun.addSelectionListener(new SelectionAdapter() {
-            public void widgetSelected(SelectionEvent e) {
-            	m_jobRun.setEnabled(m_checkJobRun.getSelection());
-            }
-        });
-		
-		// ジョブ実行グループ
-        Group groupRunJob = new Group(groupNotifyAttribute, SWT.NONE);
-        layout = new GridLayout(1, true);
-        layout.marginWidth = 5;
-        layout.marginHeight = 5;
-        layout.numColumns = 1;
-        groupRunJob.setLayout(layout);
-        gridData = new GridData();
-        gridData.horizontalSpan = 15;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        groupRunJob.setLayoutData(gridData);
-        
-        // 実行（実行，ジョブID，通知抑制と連動，呼出失敗時）
-		this.m_jobRun = new NumericRunJobComposite(groupRunJob, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = 1;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		m_jobRun.setLayoutData(gridData);
+	
 		
         /*
          * 有効／無効
@@ -552,20 +513,16 @@ public class PingCreateDialog extends CommonDialog {
         // ノード単位の結果判定の定義
         m_numericValueInfo.setInputData(monitor);
     	
-        // 通知情報の属性
-        if (monitor.getNotifyId() != null) {
-        	this.notifyInfo.setText(monitor.getNotifyId());
-        }
+    	
+        //通知情報の設定
+        if(monitor.getNotifyId() != null)
+        this.notifyInfo.setNotify(monitor.getNotifyId());
+        
+        //アプリケーション
         if (monitor.getApplication() != null) {
         	this.notifyInfo.setApplication(monitor.getApplication());
         }
         
-        // ジョブ実行
-        m_checkJobRun.setSelection(YesNoConstant.typeToBoolean(monitor.getJobRun()));
-        
-        // 各重要度のジョブ実行
-        m_jobRun.setInputData(monitor);
-        m_jobRun.setEnabled(YesNoConstant.typeToBoolean(monitor.getJobRun()));
         
         // 有効／無効
         if (monitor.getValid() == ValidConstant.TYPE_VALID) {
@@ -581,7 +538,7 @@ public class PingCreateDialog extends CommonDialog {
     protected MonitorInfo createInputData() {
     	MonitorInfo info = new MonitorInfo();
 
-    	info.setMonitorTypeId(MonitorConstant.STRING_PING);
+    	info.setMonitorTypeId(HinemosModuleConstant.MONITOR_PING);
     	info.setMonitorType(MonitorTypeConstant.TYPE_NUMERIC);
     	
     	// 監視基本情報
@@ -598,7 +555,7 @@ public class PingCreateDialog extends CommonDialog {
         
         // 監視条件 ping監視情報
         MonitorPingInfo pingInfo = new MonitorPingInfo();
-        pingInfo.setMonitorTypeId(MonitorConstant.STRING_PING);
+        pingInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_PING);
         pingInfo.setMonitorId(info.getMonitorId());
         if (this.m_comboRunCount.getText() != null
                 && !"".equals((this.m_comboRunCount.getText()).trim())) {
@@ -668,34 +625,22 @@ public class PingCreateDialog extends CommonDialog {
         	return null;
         }
         
-        // 通知情報の属性
-        if (this.notifyInfo.getText() != null
-                && !"".equals((this.notifyInfo.getText()).trim())) {
-        	info.setNotifyId(notifyInfo.getText());
-        }
-
-        if (this.notifyInfo.getApplication() != null
-                && !"".equals((this.notifyInfo.getApplication()).trim())) {
-        	info.setApplication(notifyInfo.getApplication());
-        }
-        else{
-        	if (this.notifyInfo.getText() != null
-                    && !"".equals((this.notifyInfo.getText()).trim())) {
-            	info.setNotifyId(notifyInfo.getText());
-            	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.10"));
-                return null;
-            }
-        }
-        
-        // ジョブ実行
-        info.setJobRun(YesNoConstant.booleanToType(m_checkJobRun.getSelection()));
-        
-        // 各重要度のジョブ実行
-        validateResult = m_jobRun.createInputData(info);
-        if(validateResult != null){
-        	return null;
-        }
-        
+        // 通知関連情報とアプリケーションの設定
+		// 通知グループIDの設定
+		info.setNotifyGroupId(NotifyRelationInfo.createNotifyGroupId(HinemosModuleConstant.MONITOR_PING, info.getMonitorId()));
+		validateResult = notifyInfo.createInputData(info);
+		if (validateResult != null) {
+			if(validateResult.getID() == null){	// 通知ID警告用出力
+				if(!displayQuestion(validateResult)){
+					validateResult = null;
+					return null;
+				}
+			}
+			else{	// アプリケーション未入力チェック
+				return null;
+			}
+		}
+		
         // 有効/無効
         if (this.confirmValid.getSelection()) {
         	info.setValid(ValidConstant.TYPE_VALID);
