@@ -28,21 +28,30 @@ import java.util.regex.PatternSyntaxException;
 import javax.ejb.CreateException;
 import javax.ejb.FinderException;
 import javax.jms.JMSException;
+import javax.naming.InitialContext;
 import javax.naming.NamingException;
+import javax.rmi.PortableRemoteObject;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.PriorityConstant;
+import com.clustercontrol.monitor.run.factory.RunMonitor;
 import com.clustercontrol.monitor.run.factory.RunMonitorNumericValueType;
+import com.clustercontrol.poller.FacilityNotFoundException;
+import com.clustercontrol.poller.NotInitializedException;
+import com.clustercontrol.poller.snmp.SnmpPoller;
+import com.clustercontrol.poller.snmp.SnmpPollerManager;
 import com.clustercontrol.process.bean.SnmpSharedTableConstant;
 import com.clustercontrol.process.ejb.entity.MonitorProcessInfoLocal;
 import com.clustercontrol.process.ejb.entity.MonitorProcessInfoPK;
 import com.clustercontrol.process.ejb.entity.MonitorProcessInfoUtil;
 import com.clustercontrol.process.util.ProcessProperties;
 import com.clustercontrol.process.util.SnmpProcConnectionManager;
-import com.clustercontrol.sharedtable.bean.ValueObject;
-import com.clustercontrol.snmppoller.SnmpSharedTable;
+import com.clustercontrol.sharedtable.DataTable;
+import com.clustercontrol.sharedtable.DataTableNotFoundException;
+import com.clustercontrol.sharedtable.SharedTable;
+import com.clustercontrol.sharedtable.TableEntry;
 import com.clustercontrol.util.Messages;
 
 /**
@@ -70,7 +79,7 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 	protected String m_param = "";
 	
 	/** SNMP収集値の共有テーブル */
-	protected SnmpSharedTable m_sst = null;
+	protected SharedTable m_sst = null;
 	
 	/** メッセージ */
 	protected String m_message = null;
@@ -87,6 +96,9 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 	 */
 	private final int MAX_RETRY_COUNT = 1;
 	
+    // collectメソッドがスレッドセーフではないため、同期をとるために使用
+    private static Object m_syncObj = new Object();
+	
 	/**
 	 * コンストラクタ
 	 * 
@@ -98,6 +110,16 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 		setSnmpSharedTable();
 	}
 	
+	/**
+	 * マルチスレッドを実現するCallableTaskに渡すためのインスタンスを作成するメソッド
+	 * 
+	 * @see com.clustercontrol.monitor.run.factory.RunMonitor#runMonitorInfo()
+	 * @see com.clustercontrol.monitor.run.util.CallableTask
+	 */
+	public RunMonitor createMonitorInstance() throws NamingException, JMSException, CreateException{
+		return new RunMonitorProcess();
+	}
+	
 	/**
 	 * プロセス数を取得します。<BR>
 	 * 
@@ -138,20 +160,73 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 			return false;
 		}
 
-		// 実行間隔
-		int runInterval = m_monitor.getRunInterval().intValue();
-
+		// プロセス一覧が格納されたデータテーブルを取得
+		DataTable table = null;
+		try {
+			table = m_sst.getDataTable(m_monitorTypeId, facilityId, m_monitorId, 0);
+		} catch (DataTableNotFoundException e) {
+			// 以下のエラーチェックで処理
+		} catch (NotInitializedException e) {
+			// 以下のエラーチェックで処理
+		}
+		// テーブルが存在しない場合は作成
+		if(table == null){
+			// マルチスレッド対応（同時に呼ばれる可能性があるためsynchronized化し、再度getDataTableを試みる）
+			synchronized (m_syncObj) {
+				boolean isGetDateTable = true;
+				try {
+					setSnmpSharedTable();
+					table = m_sst.getDataTable(m_monitorTypeId, facilityId, m_monitorId, 0);
+				} catch (DataTableNotFoundException e1) {
+					isGetDateTable = false;
+				} catch (NotInitializedException e1) {
+					isGetDateTable = false;
+				} catch (NamingException e) {
+					m_log.error("DataTable create failure. (" + facilityId + ", " + m_monitorId + ")");
+				}
+				
+				if(!isGetDateTable){
+					m_log.warn("Create Table (" + facilityId + ", " + m_monitorId + ")");
+					m_sst.createDataTable(m_monitorTypeId, facilityId, 1);
+					try {
+						// 実行間隔
+						int runInterval = m_runInterval;
+						// 監視対象スコープ
+						String parentFacilityId = m_facilityId;//m_monitor.getFacilityId();
+						
+						// スケジュールも停止している可能性があるため再度登録
+						new ModifyPollingSchedule().addSchedule(m_monitorTypeId, m_monitorId, parentFacilityId, runInterval);
+						table = m_sst.getDataTable(m_monitorTypeId, facilityId, m_monitorId, 0);
+						
+						// なおテーブルが存在しない場合はエラー
+						if(table == null){
+							m_log.error("DataTable create failure. (" + facilityId + ", " + m_monitorId + ")");
+							
+							// 異常終了（メッセージ：「値を取得できませんでした」）
+							m_message = Messages.getString("message.process.6");
+							return false;
+						}
+					} catch (DataTableNotFoundException e) {
+						m_log.error(e.getMessage(), e);
+						// 異常終了（メッセージ：「値を取得できませんでした」）
+						m_message = Messages.getString("message.process.6");
+						return false;
+					} catch (NotInitializedException e) {
+						m_log.error(e.getMessage(), e);
+						// 異常終了（メッセージ：「値を取得できませんでした」）
+						m_message = Messages.getString("message.process.6");
+						return false;
+					}
+				}
+			}
+		}
+		
 		for (int retryCount = 0; retryCount <= MAX_RETRY_COUNT; retryCount++) {	
 			// 起動名を指定してサブツリーの値を一度に取得
-			Set valueSetName = m_sst.getValueSet(facilityId, runInterval,
-					SnmpSharedTableConstant.OID_RUN_NAME);
-			// 起動パラメータのOIDを指定してサブツリーの値を一度に取得
-			Set valueSetParam = m_sst.getValueSet(facilityId, runInterval,
-					SnmpSharedTableConstant.OID_RUN_PARAM);
-			//
-			Set valueSetCommand = m_sst.getValueSet(facilityId, runInterval,
-					SnmpSharedTableConstant.OID_RUN_PATH);
-
+			Set<TableEntry> valueSetName = table.getValueSetStartWith(SnmpSharedTableConstant.OID_RUN_NAME);
+			Set<TableEntry> valueSetParam = table.getValueSetStartWith(SnmpSharedTableConstant.OID_RUN_PARAM);
+			Set<TableEntry> valueSetCommand = table.getValueSetStartWith(SnmpSharedTableConstant.OID_RUN_PATH);
+			
 			/*
 			 * ・valueSetName、valueSetParam、valueSetCommandはそのファシリティ（ノード）の
 			 * プロセス全体が入っている。(Set)これがNULLの時は"不明を返す"
@@ -174,7 +249,18 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 					// 実際にポーリングに応答できないノードの場合はこのリトライとなる。
 					// ノードへのポーリングはシーケンシャルに実行されるため、
 					// 複数ノードが同時に通信不通となったときのことを考慮し、タイムアウト値を短くする。
-					m_sst.polling(facilityId, 3000);
+					try {
+						table = retryPolling(facilityId);
+					} catch (NotInitializedException e) {
+						m_log.error(e.getMessage(), e);
+					} catch (DataTableNotFoundException e) {
+						m_log.error(e.getMessage(), e);
+					} catch (FacilityNotFoundException e) {
+						m_log.error(e.getMessage(), e);
+					} catch (NamingException e) {
+						m_log.error(e.getMessage(), e);
+					}
+
 					continue;  // for文の初めからやり直す 
 				}
 
@@ -183,19 +269,23 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 				// 生存期間超過でSnmpSharedTableが削除されてしまった。など。
 				break;  // for文を抜ける
 			} else {
-				ValueObject valueObjCommand = null;
-				ValueObject valueObjParam = null;
-				ValueObject valueObjName = null;
+				m_log.debug("Name    : " + valueSetName.size());
+				m_log.debug("Param   : " + valueSetParam.size());
+				m_log.debug("Command : " + valueSetCommand.size());
+				
+				TableEntry valueObjCommand = null;
+				TableEntry valueObjParam = null;
+				TableEntry valueObjName = null;
 				String valueCommand = null;
 				String valueParam = null;
 				String valueName = null;
 
-				Iterator itr = valueSetName.iterator();
+				Iterator<TableEntry> itr = valueSetName.iterator();
 
 				// SnmpSharedTableの内容に不整合がある否かをチェックするフラグ。
 				boolean errorFlg = false;
 				while (itr.hasNext()) {
-					valueObjName = (ValueObject) itr.next();
+					valueObjName = itr.next();
 
 					if (valueObjName != null) {
 						// 取得時間がmostOldPollingTimeより小さい場合は、置き換える
@@ -226,8 +316,7 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 					String index = key.substring(key.lastIndexOf("."));
 
 					// 起動パスOIDを指定して値を取得
-					valueObjCommand = m_sst.getValue(facilityId, runInterval,
-							SnmpSharedTableConstant.OID_RUN_PATH + index);
+					valueObjCommand = table.getValue(SnmpSharedTableConstant.OID_RUN_PATH + index);
 					if (valueObjCommand != null) {
 						valueCommand = (String) valueObjCommand.getValue();
 						if (valueCommand == null) {
@@ -263,7 +352,7 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 
 						valueCommand = valueCommand + valueName;
 					}
-
+					
 					m = pCommand.matcher(valueCommand);
 
 					// 起動パスが、指定したコマンドと一致する場合
@@ -272,8 +361,7 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 								+ ", " + "valueObjCommand: " + valueObjCommand);
 
 						// 起動パラメータOIDを指定して値を取得
-						valueObjParam = m_sst.getValue(facilityId, runInterval,
-								SnmpSharedTableConstant.OID_RUN_PARAM + index);
+						valueObjParam = table.getValue(SnmpSharedTableConstant.OID_RUN_PARAM + index);
 						m_log.debug("collect()  FacilityID : " + facilityId
 								+ ", " + " valueObjParam: " + valueObjParam);
 
@@ -342,8 +430,21 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 						m_log.warn("collect() retry polling. FacilityID : "
 								+ facilityId + " " + m_message);
 
-						// タイムアウト10秒でポーリングを実行
-						m_sst.polling(facilityId, 10000);
+						// タイムアウト3秒でポーリングを実行
+						// 実際にポーリングに応答できないノードの場合はこのリトライとなる。
+						// ノードへのポーリングはシーケンシャルに実行されるため、
+						// 複数ノードが同時に通信不通となったときのことを考慮し、タイムアウト値を短くする。
+						try {
+							table = retryPolling(facilityId);
+						} catch (NotInitializedException e) {
+							m_log.error(e.getMessage(), e);
+						} catch (DataTableNotFoundException e) {
+							m_log.error(e.getMessage(), e);
+						} catch (FacilityNotFoundException e) {
+							m_log.error(e.getMessage(), e);
+						} catch (NamingException e) {
+							m_log.error(e.getMessage(), e);
+						}
 						continue;  // for文の初めからやり直す 
 					} else {
 						// 「値を取得できませんでした」もしくは、
@@ -387,6 +488,31 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 		return false;
 	}
 
+	/**
+	 * 即時にSNMPポーリングを実行します
+	 * @param facilityId ポーリング対象ノードのファシリティID
+	 * @return
+	 * @throws NamingException
+	 * @throws NotInitializedException
+	 * @throws DataTableNotFoundException
+	 * @throws FacilityNotFoundException
+	 */
+	private DataTable retryPolling(String facilityId) throws NamingException, NotInitializedException, DataTableNotFoundException, FacilityNotFoundException{
+		// ポーラを取得する
+		InitialContext ctx = new InitialContext();
+		Object obj = ctx.lookup(SnmpSharedTableConstant.POLLER_MANAGER_JNDI_NAME);
+		SnmpPollerManager manager = 
+			(SnmpPollerManager)PortableRemoteObject.narrow(obj, SnmpPollerManager.class);
+
+		SnmpPoller poller = manager.getPoller(m_monitorTypeId, facilityId);
+		// ない場合は生成する
+		if(poller == null){
+			poller = manager.createPoller(m_monitorTypeId, facilityId, true, m_monitorTypeId, facilityId);
+		}
+		// ポーリングを実行（タイムアウト：3000ミリ秒、リトライ1回）
+		return poller.polling(3000, 1, SnmpSharedTableConstant.PROCESS_OIDS);
+	}
+	
 	
 	/**
 	 * プロセス監視情報を取得します。<BR>
@@ -473,6 +599,6 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 	private void setSnmpSharedTable() throws NamingException{
 		
 		// SNMP収集値の共有テーブルをルックアップ
-		m_sst = SnmpProcConnectionManager.getConnectionManager().getSnmpSharedTable();
+		m_sst = SnmpProcConnectionManager.getSnmpSharedTable();
 	}
 }
