@@ -15,6 +15,10 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.repository.dialog;
 
+import java.net.Inet4Address;
+import java.net.Inet6Address;
+import java.net.InetAddress;
+import java.net.UnknownHostException;
 import java.util.ArrayList;
 import java.util.Hashtable;
 import java.util.Iterator;
@@ -259,53 +263,69 @@ public class NodeCreateDialog extends CommonDialog {
                 public void widgetSelected(SelectionEvent e) {
                         try{
                                 int portnum = Integer.parseInt(portBox.getText());
+                                String ipAddressString = (String)ipAddressBox.getText();
                                 
-                                //ip入力チェック
-                                if(((String)ipAddressBox.getText()).
-                                                matches("^[0-9]+\\.[0-9]+\\.[0-9]+\\.[0-9]+") && 
-                                                portnum <= 65536 
-                                ){  
-                                        Hashtable pollingData = new Hashtable();
-                                        pollingData.put("IPAddress",  ipAddressBox.getText());
-                                        pollingData.put("port",       portBox.getText());
-                                        pollingData.put("community",  communityBox.getText());
-                                        pollingData.put("version",    new Integer(versionBox.getSelectionIndex()));
-                                        
-                                        /*
-                                        System.out.println("IP Address : " + (String) pollingData.get("IPAddress") );
-                                        System.out.println("port : " + (String)pollingData.get("port"));
-                                        System.out.println("community : " + (String)pollingData.get("community"));
-                                        System.out.println("Version : " + (Integer)pollingData.get("version"));
-                                        */
-                                        
-                                        Property propertySNMP = null;
-                                        GetNodePropertyBySNMP poller = new GetNodePropertyBySNMP();
-                                        
-                                        if (isModifyDialog) {
-                                                propertySNMP = poller.search(pollingData,
-                                                                PropertyConstant.MODE_MODIFY);
-                                        } else {
-                                                propertySNMP = poller.search(pollingData,
-                                                                PropertyConstant.MODE_ADD);
-                                        }                    
-                                        propertySheet.setInput(propertySNMP);
-                                        
-                                        //プロパティシートの展開
-                                        //レベル1までの展開（デバイス情報、ファイルシステム情報は展開しない。）
-                                        propertySheet.expandToLevel(1);
-                                        //ネットワークのインデックスは3
-                                        Object element =  propertySheet.getElementAt(3);
-                                        propertySheet.expandToLevel(element, 2);
-                                        //OSのインデックスは4
-                                         element =   propertySheet.getElementAt(4);
-                                        propertySheet.expandToLevel(element, 2);
-                                        
-                                }else{
-                                        MessageDialog.openWarning(getShell(), "Warning", "The input is invalid.");
-                                } 
-                        }catch (NumberFormatException e1){
-                                MessageDialog.openWarning(getShell(), "Warning", "The input is invalid.");
-                        }
+                                // IPアドレスチェック
+                                InetAddress address = InetAddress.getByName(ipAddressString);
+                                
+                                if (address instanceof Inet4Address){
+
+                                	//IPv4の場合はさらにStringをチェック
+                                	if (!ipAddressString.matches(".{1,3}?\\..{1,3}?\\..{1,3}?\\..{1,3}?")){
+                                		MessageDialog.openWarning(getShell(), "Warning",  Messages.getString("message.repository.37"));
+                                		return;
+                                	}
+                                	
+                                } else if (address instanceof Inet6Address){
+                                	//IPv6の場合は特にStringチェックは無し
+                                } else {
+                                	MessageDialog.openWarning(getShell(), "Warning",  Messages.getString("message.repository.37"));
+                                	return;
+                                }
+                                
+                                Hashtable pollingData = new Hashtable();
+                                pollingData.put("IPAddress",  ipAddressBox.getText());
+                                pollingData.put("port",       portBox.getText());
+                                pollingData.put("community",  communityBox.getText());
+                                pollingData.put("version",    new Integer(versionBox.getSelectionIndex()));
+                                
+                                /*
+                                System.out.println("IP Address : " + (String) pollingData.get("IPAddress") );
+                                System.out.println("port : " + (String)pollingData.get("port"));
+                                System.out.println("community : " + (String)pollingData.get("community"));
+                                System.out.println("Version : " + (Integer)pollingData.get("version"));
+                                */
+                                
+                                Property propertySNMP = null;
+                                GetNodePropertyBySNMP poller = new GetNodePropertyBySNMP();
+                                
+                                if (isModifyDialog) {
+                                        propertySNMP = poller.search(pollingData,
+                                                        PropertyConstant.MODE_MODIFY);
+                                } else {
+                                        propertySNMP = poller.search(pollingData,
+                                                        PropertyConstant.MODE_ADD);
+                                }                    
+                                propertySheet.setInput(propertySNMP);
+                                
+                                //プロパティシートの展開
+                                //レベル1までの展開（デバイス情報、ファイルシステム情報は展開しない。）
+                                propertySheet.expandToLevel(1);
+                                //ネットワークのインデックスは6
+                                Object element =  propertySheet.getElementAt(6);
+                                propertySheet.expandToLevel(element, 2);
+                                //OSのインデックスは7
+                                 element =   propertySheet.getElementAt(7);
+                                propertySheet.expandToLevel(element, 2);
+
+                        } catch (NumberFormatException e1){
+                        	// port番号が不正な場合
+                        	MessageDialog.openWarning(getShell(), "Warning", Messages.getString("message.repository.38"));
+                            
+                        } catch (UnknownHostException e2) {
+                        	// IPアドレスが不正な場合
+                            MessageDialog.openWarning(getShell(), "Warning",  Messages.getString("message.repository.37"));
+						}
                 }
         });
         
@@ -443,11 +463,11 @@ public class NodeCreateDialog extends CommonDialog {
         //プロパティシートの展開
         //レベル1までの展開（デバイス情報、ファイルシステム情報は展開しない。）
         this.propertySheet.expandToLevel(1);
-        //ネットワークのインデックスは3
-        Object element =  this.propertySheet.getElementAt(3);
+        //ネットワークのインデックスは6
+        Object element =  this.propertySheet.getElementAt(6);
         this.propertySheet.expandToLevel(element, 2);
-        //OSのインデックスは4
-         element =  this.propertySheet.getElementAt(4);
+        //OSのインデックスは7
+         element =  this.propertySheet.getElementAt(7);
         this.propertySheet.expandToLevel(element, 2);
        
 
@@ -540,15 +560,54 @@ public class NodeCreateDialog extends CommonDialog {
 	            return result;
 			}
 			
-			//IPアドレスのチェック
-			values =  PropertyUtil.getPropertyValue(getInputData(), NodeProperty.IP_ADDRESS_V4);
-			value =  (String)values.get(0);
-			if(value.compareTo("") ==0){
-				result = new ValidateResult();
-				result.setID(Messages.getString("message.hinemos.1"));
-				result.setMessage(Messages.getString("message.repository.24"));
-				result.setValid(false);
-				return result;
+			//プラットフォームの入力チェック
+	        values = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.PLATFORM_FAMILY_NAME);
+			value = (String)values.get(0);
+			if(value.compareTo("") == 0){
+	            result = new ValidateResult();
+	            result.setID(Messages.getString("message.hinemos.1"));
+	            result.setMessage(Messages.getString("message.repository.36"));
+	            result.setValid(false);
+	            return result;
+			}
+			
+			//IPアドレスの入力チェック
+	        values = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.IP_ADDRESS_VERSION);
+	        Object obj = values.get(0);
+	     
+	        
+	        if(obj.getClass() == Integer.class){
+	        
+	        	value = ((Integer)obj).toString();
+	        	
+	        }else{
+	        	
+	        	value = (String)values.get(0);
+	        }
+	        
+			if(value.compareTo("") == 0 || value.compareTo("4") == 0  ){
+				//versionが空か4の場合には、
+				ArrayList ipValues =  PropertyUtil.getPropertyValue(getInputData(), NodeProperty.IP_ADDRESS_V4);
+				String ipvValue =  (String)ipValues.get(0);
+				if(ipvValue.compareTo("") ==0){
+					result = new ValidateResult();
+					result.setID(Messages.getString("message.hinemos.1"));
+					result.setMessage(Messages.getString("message.repository.24"));
+					result.setValid(false);
+					return result;
+				}
+			}else if(value.compareTo("6") == 0 ){
+				//	versionが6の場合には、
+				ArrayList ipValues =  PropertyUtil.getPropertyValue(getInputData(), NodeProperty.IP_ADDRESS_V6);
+				String ipvValue =  (String)ipValues.get(0);
+				if(ipvValue.compareTo("") ==0){
+					result = new ValidateResult();
+					result.setID(Messages.getString("message.hinemos.1"));
+					result.setMessage(Messages.getString("message.repository.25"));
+					result.setValid(false);
+					return result;
+				}
+				
 			}
 			
 			//ノード名の入力チェック
@@ -735,6 +794,26 @@ public class NodeCreateDialog extends CommonDialog {
 				}
 			}
 			
+			// 備考の重複チェック
+			values = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.NOTE);
+			String st1;
+			String st2;
+			for (int i = 0; i < values.size() - 1; i++ ){
+				st1 = (String) values.get(i);
+				for (int j = i + 1; j < values.size(); j++) {
+					st2 = (String) values.get(j);
+					if (st1.equals(st2)){
+						String[] args = { Messages.getString("note"), st1 };
+						result = new ValidateResult();
+			            result.setID(Messages.getString("message.hinemos.1"));
+			            result.setMessage(Messages.getString("message.repository.32", args));
+			            result.setValid(false);
+			            return result;
+					}
+				}
+			}
+			
+			
         }
         else{
 			//スコープの入力チェック
