@@ -35,9 +35,8 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.accesscontrol.util.LdapConnectionManager;
-import com.clustercontrol.accesscontrol.util.TimeKeeper;
-import com.clustercontrol.accesscontrol.util.TimeKeeperService;
 import com.clustercontrol.bean.FacilityConstant;
+import com.clustercontrol.bean.SnmpVersionConstant;
 import com.clustercontrol.repository.bean.FacilityAttributeConstant;
 import com.clustercontrol.repository.ejb.entity.FacilityBean;
 import com.clustercontrol.repository.ejb.entity.FacilityPK;
@@ -75,16 +74,13 @@ public class FacilityDAOImpl implements FacilityDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
+				
 			try {
 				clearBean(ejb);
 				
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
 				//dnをキーとしてLDAPアクセスし、属性を取得
 //				javax.naming.directory.Attributes attrs = ctx.getAttributes(pk.getDn());
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(createDnString(pk.getFacilityId()));
@@ -141,6 +137,10 @@ public class FacilityDAOImpl implements FacilityDAO {
 					if(attrs.get(FacilityAttributeConstant.CREATORSNAME) != null){
 						ejb.setCreatorsName((String)attrs.get(FacilityAttributeConstant.CREATORSNAME).get(0));
 					}
+					//ccValid取得
+					if(attrs.get(FacilityAttributeConstant.VALID) != null){
+						ejb.setValid(stringToBoolean((String)attrs.get(FacilityAttributeConstant.VALID).get(0)));
+					}
 					//ccDhcpClient取得
 					if(attrs.get(FacilityAttributeConstant.DHCPCLIENT) != null){
 						ejb.setDhcpClient(stringToBoolean((String)attrs.get(FacilityAttributeConstant.DHCPCLIENT).get(0)));
@@ -242,9 +242,65 @@ public class FacilityDAOImpl implements FacilityDAO {
 					
 					//ccFacilitySortValue取得
 					if(attrs.get(FacilityAttributeConstant.SORT_VALUE) != null){
-						ejb.setSortValue(new Integer((String)attrs.get(FacilityAttributeConstant.SORT_VALUE).get(0))); 
+						ejb.setSnmpVersion((String)attrs.get(FacilityAttributeConstant.SORT_VALUE).get(0));
+					}
+
+					
+					//ccSnmpTimeout取得
+					if(attrs.get(FacilityAttributeConstant.SNMPTIMEOUT) != null){
+						ejb.setSnmpTimeout(new Integer((String)attrs.get(FacilityAttributeConstant.SNMPTIMEOUT).get(0)));
+					}
+
+					//ccSnmpRetries取得
+					if(attrs.get(FacilityAttributeConstant.SNMPRETRIES) != null){
+						ejb.setSnmpRetries(new Integer((String)attrs.get(FacilityAttributeConstant.SNMPRETRIES).get(0)));
 					}
 					
+					//ccSnmpProxy取得
+					if(attrs.get(FacilityAttributeConstant.SNMPPROXY) != null){
+						ejb.setSnmpProxy((String)attrs.get(FacilityAttributeConstant.SNMPPROXY).get(0));
+					}
+
+					//ccNote取得
+					if(attrs.get(FacilityAttributeConstant.NOTE) != null){
+						javax.naming.NamingEnumeration notes = attrs.get(FacilityAttributeConstant.NOTE).getAll();
+						ArrayList noteList = new ArrayList();
+						while ( notes.hasMoreElements() ) {
+							String note = (String)notes.nextElement();
+							noteList.add(note);
+						}
+						ejb.setNote(noteList);
+					}
+					
+					//ccIconImage取得
+					if(attrs.get(FacilityAttributeConstant.ICONIMAGE) != null){
+						ejb.setIconImage((String)attrs.get(FacilityAttributeConstant.ICONIMAGE).get(0));
+					}
+
+					//ccVirtualizationNodeType取得
+					if(attrs.get(FacilityAttributeConstant.VIRTNODETYPE) != null){
+						ejb.setVirtNodeType((String)attrs.get(FacilityAttributeConstant.VIRTNODETYPE).get(0));
+					}
+					
+					//ccVMManagementNode取得
+					if(attrs.get(FacilityAttributeConstant.VMMANAGEMENTNODE) != null){
+						ejb.setVMManagementNode((String)attrs.get(FacilityAttributeConstant.VMMANAGEMENTNODE).get(0));
+					}
+					
+					//ccVMINDEX取得
+					if(attrs.get(FacilityAttributeConstant.VMINDEX) != null){
+						ejb.setVmIndex(new Integer((String)attrs.get(FacilityAttributeConstant.VMINDEX).get(0)));
+					}
+					
+					//ccVMName取得
+					if(attrs.get(FacilityAttributeConstant.VMNAME) != null){
+						ejb.setVmName((String)attrs.get(FacilityAttributeConstant.VMNAME).get(0));
+					}
+					
+					//ccVirtualizationSolution取得
+					if(attrs.get(FacilityAttributeConstant.VIRTSOLUTION) != null){
+						ejb.setVirtSolution((String)attrs.get(FacilityAttributeConstant.VIRTSOLUTION).get(0));
+					}
 				}
 			} catch (javax.naming.NamingException ex) {
 				if (ex instanceof CommunicationException) {
@@ -285,11 +341,8 @@ public class FacilityDAOImpl implements FacilityDAO {
 						ctx.close();
 					}
 				} catch (NamingException e) {
-					m_log.error("load() context close failed : " + e.getMessage(), e);
+					m_log.error("load() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 			return;
 		}
@@ -303,14 +356,11 @@ public class FacilityDAOImpl implements FacilityDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
+				
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
 				//dnをキーとしてLDAPアクセスし、属性を取得
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(ejb.getDn());
 				
@@ -400,6 +450,16 @@ public class FacilityDAOImpl implements FacilityDAO {
 					else if(attrs.get(FacilityAttributeConstant.CREATORSNAME) != null && ejb.getCreatorsName() != null){
 						replaceAttrs.put(FacilityAttributeConstant.CREATORSNAME, ejb.getCreatorsName());
 					}
+					//ccValid設定
+					if(attrs.get(FacilityAttributeConstant.VALID) == null && ejb.getValid() != null){
+						addAttrs.put(FacilityAttributeConstant.VALID, booleanToString(ejb.getValid()));
+					}
+					else if(attrs.get(FacilityAttributeConstant.VALID) != null && ejb.getValid() == null){
+						removeAttrs.put(FacilityAttributeConstant.VALID, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.VALID) != null && ejb.getValid() != null){
+						replaceAttrs.put(FacilityAttributeConstant.VALID, booleanToString(ejb.getValid()));
+					}
 					//ccDhcpClient設定
 					if(attrs.get(FacilityAttributeConstant.DHCPCLIENT) == null && ejb.getDhcpClient() != null){
 						addAttrs.put(FacilityAttributeConstant.DHCPCLIENT, booleanToString(ejb.getDhcpClient()));
@@ -647,18 +707,141 @@ public class FacilityDAOImpl implements FacilityDAO {
 					
 					//ccSortValue設定
 					if(attrs.get(FacilityAttributeConstant.SORT_VALUE) == null && ejb.getSortValue() != null){
-						
 						addAttrs.put(FacilityAttributeConstant.SORT_VALUE, ejb.getSortValue().toString());
 					}
 					else if(attrs.get(FacilityAttributeConstant.SORT_VALUE) != null && ejb.getSortValue() == null){
-						
 						removeAttrs.put(FacilityAttributeConstant.SORT_VALUE, null);
 					}
 					else if(attrs.get(FacilityAttributeConstant.SORT_VALUE) != null && ejb.getSortValue() != null){
-						
 						replaceAttrs.put(FacilityAttributeConstant.SORT_VALUE, ejb.getSortValue().toString());
 					}
 					
+					
+					
+					//ccSnmpTimeout設定
+					if(attrs.get(FacilityAttributeConstant.SNMPTIMEOUT) == null && ejb.getSnmpTimeout() != null){
+						addAttrs.put(FacilityAttributeConstant.SNMPTIMEOUT, ejb.getSnmpTimeout().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.SNMPTIMEOUT) != null && ejb.getSnmpTimeout() == null){
+						removeAttrs.put(FacilityAttributeConstant.SNMPTIMEOUT, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.SNMPTIMEOUT) != null && ejb.getSnmpTimeout() != null){
+						replaceAttrs.put(FacilityAttributeConstant.SNMPTIMEOUT, ejb.getSnmpTimeout().toString());
+					}
+					
+					//ccSnmpRetries設定
+					if(attrs.get(FacilityAttributeConstant.SNMPRETRIES) == null && ejb.getSnmpRetries() != null){
+						addAttrs.put(FacilityAttributeConstant.SNMPRETRIES, ejb.getSnmpRetries().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.SNMPRETRIES) != null && ejb.getSnmpRetries() == null){
+						removeAttrs.put(FacilityAttributeConstant.SNMPRETRIES, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.SNMPRETRIES) != null && ejb.getSnmpRetries() != null){
+						replaceAttrs.put(FacilityAttributeConstant.SNMPRETRIES, ejb.getSnmpRetries().toString());
+					}
+					
+					//ccSnmpProxy設定
+					if(attrs.get(FacilityAttributeConstant.SNMPPROXY) == null && ejb.getSnmpProxy() != null){
+						addAttrs.put(FacilityAttributeConstant.SNMPPROXY, ejb.getSnmpProxy().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.SNMPPROXY) != null && ejb.getSnmpProxy() == null){
+						removeAttrs.put(FacilityAttributeConstant.SNMPPROXY, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.SNMPPROXY) != null && ejb.getSnmpProxy() != null){
+						replaceAttrs.put(FacilityAttributeConstant.SNMPPROXY, ejb.getSnmpProxy().toString());
+					}
+					
+					//ccNote設定
+					if(attrs.get(FacilityAttributeConstant.NOTE) == null && ejb.getNote() != null){
+						javax.naming.directory.Attribute attr =
+							new javax.naming.directory.BasicAttribute(FacilityAttributeConstant.NOTE);
+						ArrayList list = ejb.getNote();
+						for(int i = 0; i < list.size(); i++) {
+							String note = (String)list.get(i);
+							attr.add(i, note);
+						}
+						addAttrs.put(attr);
+					}
+					else if(attrs.get(FacilityAttributeConstant.NOTE) != null && ejb.getNote() == null){
+						removeAttrs.put(FacilityAttributeConstant.NOTE, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.NOTE) != null && ejb.getNote() != null){
+						javax.naming.directory.Attribute attr =
+							new javax.naming.directory.BasicAttribute(FacilityAttributeConstant.NOTE);
+						ArrayList list = ejb.getNote();
+						for(int i = 0; i < list.size(); i++) {
+							String note = (String)list.get(i);
+							attr.add(i, note);
+						}
+						replaceAttrs.put(attr);
+					}
+					
+					//ccIconImage設定
+					if(attrs.get(FacilityAttributeConstant.ICONIMAGE) == null && ejb.getIconImage() != null){
+						addAttrs.put(FacilityAttributeConstant.ICONIMAGE, ejb.getIconImage());
+					}
+					else if(attrs.get(FacilityAttributeConstant.ICONIMAGE) != null && ejb.getIconImage() == null){
+						removeAttrs.put(FacilityAttributeConstant.ICONIMAGE, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.ICONIMAGE) != null && ejb.getIconImage() != null){
+						replaceAttrs.put(FacilityAttributeConstant.ICONIMAGE, ejb.getIconImage());
+					}
+					
+					//ccVirtualizationNoteType設定
+					if(attrs.get(FacilityAttributeConstant.VIRTNODETYPE) == null && ejb.getVirtNodeType() != null){
+						addAttrs.put(FacilityAttributeConstant.VIRTNODETYPE, ejb.getVirtNodeType().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.VIRTNODETYPE) != null && ejb.getVirtNodeType() == null){
+						removeAttrs.put(FacilityAttributeConstant.VIRTNODETYPE, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.VIRTNODETYPE) != null && ejb.getVirtNodeType() != null){
+						replaceAttrs.put(FacilityAttributeConstant.VIRTNODETYPE, ejb.getVirtNodeType().toString());
+					}
+					
+					//ccVMManagementNode設定
+					if(attrs.get(FacilityAttributeConstant.VMMANAGEMENTNODE) == null && ejb.getVMManagementNode() != null){
+						addAttrs.put(FacilityAttributeConstant.VMMANAGEMENTNODE, ejb.getVMManagementNode().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.VMMANAGEMENTNODE) != null && ejb.getVMManagementNode() == null){
+						removeAttrs.put(FacilityAttributeConstant.VMMANAGEMENTNODE, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.VMMANAGEMENTNODE) != null && ejb.getVMManagementNode() != null){
+						replaceAttrs.put(FacilityAttributeConstant.VMMANAGEMENTNODE, ejb.getVMManagementNode().toString());
+					}
+					
+					//ccVMID設定
+					if(attrs.get(FacilityAttributeConstant.VMINDEX) == null && ejb.getVmIndex() != null){
+						addAttrs.put(FacilityAttributeConstant.VMINDEX, ejb.getVmIndex().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.VMINDEX) != null && ejb.getVmIndex() == null){
+						removeAttrs.put(FacilityAttributeConstant.VMINDEX, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.VMINDEX) != null && ejb.getVmIndex() != null){
+						replaceAttrs.put(FacilityAttributeConstant.VMINDEX, ejb.getVmIndex().toString());
+					}
+					
+					//ccVMName設定
+					if(attrs.get(FacilityAttributeConstant.VMNAME) == null && ejb.getVmName() != null){
+						addAttrs.put(FacilityAttributeConstant.VMNAME, ejb.getVmName().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.VMNAME) != null && ejb.getVmName() == null){
+						removeAttrs.put(FacilityAttributeConstant.VMNAME, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.VMNAME) != null && ejb.getVmName() != null){
+						replaceAttrs.put(FacilityAttributeConstant.VMNAME, ejb.getVmName().toString());
+					}
+					
+					//ccVirtualizationSolution設定
+					if(attrs.get(FacilityAttributeConstant.VIRTSOLUTION) == null && ejb.getVirtSolution() != null){
+						addAttrs.put(FacilityAttributeConstant.VIRTSOLUTION, ejb.getVirtSolution().toString());
+					}
+					else if(attrs.get(FacilityAttributeConstant.VIRTSOLUTION) != null && ejb.getVirtSolution() == null){
+						removeAttrs.put(FacilityAttributeConstant.VIRTSOLUTION, null);
+					}
+					else if(attrs.get(FacilityAttributeConstant.VIRTSOLUTION) != null && ejb.getVirtSolution() != null){
+						replaceAttrs.put(FacilityAttributeConstant.VIRTSOLUTION, ejb.getVirtSolution().toString());
+					}
+
 				}
 				//属性を変更する（追加）
 				ctx.modifyAttributes(
@@ -717,11 +900,8 @@ public class FacilityDAOImpl implements FacilityDAO {
 						ctx.close();
 					}
 				} catch (NamingException e) {
-					m_log.error("store() context close failed : " + e.getMessage(), e);
+					m_log.error("store() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 			return ;
 		}
@@ -735,13 +915,10 @@ public class FacilityDAOImpl implements FacilityDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
+			
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
-
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
 	
 				//dnをキーとしてLDAPアクセスし、エントリを削除
 //				ctx.destroySubcontext(pk.getDn());
@@ -791,11 +968,8 @@ public class FacilityDAOImpl implements FacilityDAO {
 						ctx.close();
 					}
 				} catch (NamingException e) {
-					m_log.error("remove() context close failed : " + e.getMessage(), e);
+					m_log.error("remove() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 			return;
 		}
@@ -812,14 +986,11 @@ public class FacilityDAOImpl implements FacilityDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
+				
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
 				// Attributes for new entry
 				javax.naming.directory.Attributes attrs =
 					new javax.naming.directory.BasicAttributes();
@@ -917,11 +1088,8 @@ public class FacilityDAOImpl implements FacilityDAO {
 						ctx.close();
 					}
 				} catch (NamingException e) {
-					m_log.error("create() context close failed : " + e.getMessage(), e);
+					m_log.error("create() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 	
 			return pk;
@@ -960,14 +1128,10 @@ public class FacilityDAOImpl implements FacilityDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null) {
@@ -1031,11 +1195,8 @@ public class FacilityDAOImpl implements FacilityDAO {
 					if(ctx != null)
 						ctx.close();
 				} catch (NamingException e) {
-					m_log.error("findAll() context close failed : " + e.getMessage(), e);
+					m_log.error("findAll() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 			
 			return ret;
@@ -1076,14 +1237,11 @@ public class FacilityDAOImpl implements FacilityDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
+			
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null ) {
@@ -1147,11 +1305,8 @@ public class FacilityDAOImpl implements FacilityDAO {
 					if(ctx != null)
 						ctx.close();
 				} catch (NamingException e) {
-					m_log.error("findAllNode() context close failed : " + e.getMessage(), e);
+					m_log.error("findAllNode() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 			
 			return ret;
@@ -1166,7 +1321,6 @@ public class FacilityDAOImpl implements FacilityDAO {
 		javax.naming.directory.DirContext ctx = null;
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
 			try {
 //				m_log.debug("findByPrimaryKey() : dn = " + pk.getDn());
 				m_log.debug("findByPrimaryKey() : facilityId = " + pk.getFacilityId());
@@ -1174,9 +1328,6 @@ public class FacilityDAOImpl implements FacilityDAO {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
 				//dnをキーとしてLDAPアクセスし、属性を取得
 //				javax.naming.directory.Attributes attrs = ctx.getAttributes(pk.getDn());
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(createDnString(pk.getFacilityId()));
@@ -1226,11 +1377,8 @@ public class FacilityDAOImpl implements FacilityDAO {
 						ctx.close();
 					}
 				} catch (NamingException e) {
-					m_log.error("findByPrimaryKey() context close failed : " + e.getMessage(), e);
+					m_log.error("findByPrimaryKey() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 			return pk;
 		}
@@ -1241,11 +1389,11 @@ public class FacilityDAOImpl implements FacilityDAO {
 	 * @see com.clustercontrol.repository.dao.FacilityDAO#findByFacilityId(java.lang.String)
 	 */
 	public FacilityPK findByFacilityId(String facilityId) throws FinderException {
-		m_log.debug("findByFacilityId() start : FacilityId = " + facilityId);
-			
-		FacilityPK pk = new FacilityPK(facilityId);
 		
-		m_log.debug("findByFacilityId() end  : FacilityId = " + facilityId);
+		m_log.debug("start");
+		
+		FacilityPK pk = new FacilityPK(facilityId);
+		m_log.debug("end");
 		return pk;
 		
 		
@@ -1363,7 +1511,8 @@ public class FacilityDAOImpl implements FacilityDAO {
 			String facilityId, 
 			String facilityName, 
 			String description, 
-			String ipAddress, 
+			String ipAddressV4, 
+			String ipAddressV6, 
 			String osName, 
 			String osRelease, 
 			String managerName, 
@@ -1375,7 +1524,8 @@ public class FacilityDAOImpl implements FacilityDAO {
 				", FacilityId = " + facilityId + 
 				", FacilityName = " + facilityName + 
 				", Description = " + description + 
-				", ipAddress = " + ipAddress + 
+				", ipAddressV4 = " + ipAddressV4 + 
+				", ipAddressV6 = " + ipAddressV6 + 
 				", osName = " + osName + 
 				", osRelease = " + osRelease + 
 				", managerName = " + managerName + 
@@ -1419,12 +1569,19 @@ public class FacilityDAOImpl implements FacilityDAO {
 			search.append("=");
 			search.append(description);
 		}
-		// IPアドレスを検索文字列に設定
-		if(ipAddress != null && ipAddress.compareTo("") != 0){
+		// IPアドレスv4を検索文字列に設定
+		if(ipAddressV4 != null && ipAddressV4.compareTo("") != 0){
 			search.append(")(");
 			search.append(FacilityAttributeConstant.IPNETWORKNUMBER);
 			search.append("=");
-			search.append(ipAddress);
+			search.append(ipAddressV4);
+		}
+		// IPアドレスv6を検索文字列に設定
+		if(ipAddressV6 != null && ipAddressV6.compareTo("") != 0){
+			search.append(")(");
+			search.append(FacilityAttributeConstant.IPNETWORKNUMBER);
+			search.append("=");
+			search.append(ipAddressV6);
 		}
 		// OS名を検索文字列に設定
 		if(osName != null && osName.compareTo("") != 0){
@@ -1463,14 +1620,10 @@ public class FacilityDAOImpl implements FacilityDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null ) {
@@ -1479,7 +1632,8 @@ public class FacilityDAOImpl implements FacilityDAO {
 					        ", FacilityId = " + facilityId + 
 					        ", FacilityName = " + facilityName + 
 					        ", Description = " + description + 
-					        ", ipAddress = " + ipAddress + 
+					        ", ipAddressV4 = " + ipAddressV4 + 
+					        ", ipAddressV6 = " + ipAddressV6 + 
 					        ", osName = " + osName + 
 					        ", osRelease = " + osRelease + 
 					        ", managerName = " + managerName + 
@@ -1543,11 +1697,8 @@ public class FacilityDAOImpl implements FacilityDAO {
 					if(ctx != null)
 						ctx.close();
 				} catch (NamingException e) {
-					m_log.error("findNode() context close failed : " + e.getMessage(), e);
+					m_log.error("findNode() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 			
 			return ret;
@@ -1596,14 +1747,10 @@ public class FacilityDAOImpl implements FacilityDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null ) {
@@ -1667,11 +1814,8 @@ public class FacilityDAOImpl implements FacilityDAO {
 					if(ctx != null)
 						ctx.close();
 				} catch (NamingException e) {
-					m_log.error("findByIpAddress() context close failed : " + e.getMessage(), e);
+					m_log.error("findByIpAddress() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 	
 			return ret;
@@ -1719,14 +1863,12 @@ public class FacilityDAOImpl implements FacilityDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
+			
+				
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null ) {
@@ -1787,11 +1929,8 @@ public class FacilityDAOImpl implements FacilityDAO {
 					if(ctx != null)
 						ctx.close();
 				} catch (NamingException e) {
-					m_log.error("findByNodeName() context close failed : " + e.getMessage(), e);
+					m_log.error("findByNodeName() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 			return ret;
 	    }
