@@ -29,12 +29,12 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.accesscontrol.util.LdapConnectionManager;
-import com.clustercontrol.accesscontrol.util.TimeKeeper;
-import com.clustercontrol.accesscontrol.util.TimeKeeperService;
 import com.clustercontrol.bean.FacilityConstant;
+import com.clustercontrol.repository.bean.FacilityAttributeConstant;
 import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
 import com.clustercontrol.repository.ejb.entity.FacilityTreeBean;
 import com.clustercontrol.repository.ejb.entity.FacilityTreePK;
+import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
 import com.clustercontrol.util.apllog.AplLogger;
 
 /**
@@ -68,16 +68,13 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
+
 			try {
 				clearBean(ejb);
 				
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
-
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-	
+				
 				//属性を取得
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(pk.getDn());
 	
@@ -89,6 +86,7 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				ejb.setTreeType(new Integer((String)attrs.get(FacilityTreeAttributeConstant.TREETYPE).get(0)));
 				ejb.setBuiltIn((new Boolean((String)attrs.get(FacilityTreeAttributeConstant.BUILTIN).get(0))));
 				ejb.setSortValue(new Integer((String)attrs.get(FacilityTreeAttributeConstant.SORT_VALUE).get(0)));
+				ejb.setValid((new Boolean((String)attrs.get(FacilityTreeAttributeConstant.VALID).get(0))));
 	
 				m_log.debug("load() : Dn " + pk.getDn() + " FacilityId " + ejb.getFacilityId() + " TreeType " + ejb.getTreeType());
 					
@@ -134,9 +132,6 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("load() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 			m_log.trace("load() : end " + pk.getDn());
 			return;
@@ -147,7 +142,80 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 	 * @see com.clustercontrol.repository.dao.FacilityTreeDAO#store(com.clustercontrol.repository.ejb.FacilityTreeBean)
 	 */
 	public void store(FacilityTreeBean ejb) throws EJBException {
+		javax.naming.directory.DirContext ctx = null;
+		
+		int retryCount=0;
+		while(MAX_RETRY > retryCount){
+			try {				
+				// LDAP用のコンテキストの作成
+				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
+				
+				//dnをキーとしてLDAPアクセスし、属性を取得
+				javax.naming.directory.Attributes attrs = ctx.getAttributes(ejb.getDn());
+			
+				javax.naming.directory.Attributes addAttrs = 
+					new javax.naming.directory.BasicAttributes();
+				javax.naming.directory.Attributes replaceAttrs = 
+					new javax.naming.directory.BasicAttributes();
+				javax.naming.directory.Attributes removeAttrs = 
+					new javax.naming.directory.BasicAttributes();
+				
+				//ccValid設定
+				if(attrs.get(FacilityAttributeConstant.VALID) == null && ejb.getValid() != null){
+					addAttrs.put(FacilityAttributeConstant.VALID, booleanToString(ejb.getValid()));
+				}
+				else if(attrs.get(FacilityAttributeConstant.VALID) != null && ejb.getValid() == null){
+					removeAttrs.put(FacilityAttributeConstant.VALID, null);
+				}
+				else if(attrs.get(FacilityAttributeConstant.VALID) != null && ejb.getValid() != null){
+					replaceAttrs.put(FacilityAttributeConstant.VALID, booleanToString(ejb.getValid()));
+				}
+				
+				//属性を変更する（追加）
+				ctx.modifyAttributes(
+						ejb.getDn(),
+						javax.naming.directory.DirContext.ADD_ATTRIBUTE, 
+						addAttrs);
+				//属性を変更する（置換）
+				ctx.modifyAttributes(
+						ejb.getDn(), 
+						javax.naming.directory.DirContext.REPLACE_ATTRIBUTE, 
+						replaceAttrs);
+				//属性を変更する（削除）
+				ctx.modifyAttributes(
+						ejb.getDn(), 
+						javax.naming.directory.DirContext.REMOVE_ATTRIBUTE, 
+						removeAttrs);
 
+			} catch (NamingException e) {
+				if (e instanceof CommunicationException) {
+					LdapConnectionManager.getConnectionManager().setDirContext(null);
+				}
+					
+				// NamingExceptionが発生した場合は、catchしリトライする
+				m_log.debug("store(): catch NamingException" + e.getMessage());
+				
+				// whileループの判定の前に、メッソッドを抜けるかのチェックをするため、
+				// ここでカウントアップする。
+				retryCount++;
+				if(retryCount >= MAX_RETRY){
+					throw new EJBException(e);
+				} else {
+					//リトライ上限以下の場合には再度LDAPに問い合わせをします。
+					//whlie loopに戻ります。
+					continue;
+				}
+			} finally {
+				try {
+					if (ctx != null) {
+						ctx.close();
+					}
+				} catch (NamingException e) {
+					m_log.error("load() context close failed : " + e.getMessage());
+				}
+			}
+			return;
+		}
 	}
 
 	/* (non-Javadoc)
@@ -158,14 +226,10 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		javax.naming.directory.DirContext ctx = null;
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
 				//エントリを削除
 				ctx.destroySubcontext(pk.getDn());
 				
@@ -213,9 +277,6 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("remove() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 			m_log.trace("remove() : end " + pk.getDn());
 			return;
@@ -230,8 +291,8 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		FacilityTreePK pk = null;
 		javax.naming.directory.DirContext ctx = null;
 		int retryCount=0;
-		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
+		while(MAX_RETRY > retryCount){	
+			
 			try {
 				//親のdnを取得
 				String baseDn = BASE_DN;
@@ -257,6 +318,7 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				attrs.put(FacilityTreeAttributeConstant.TREETYPE, ejb.getTreeType().toString());
 				attrs.put(FacilityTreeAttributeConstant.SORT_VALUE, ejb.getSortValue().toString());
 				attrs.put(FacilityTreeAttributeConstant.BUILTIN,"FALSE");
+				attrs.put(FacilityTreeAttributeConstant.VALID, ejb.getValid().toString().toUpperCase());
 				
 				//↑FALSEは小文字falseはNG
 				
@@ -271,10 +333,7 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				
 				//dn設定
 				ejb.setDn(dn.toString());
-				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
+	
 				//エントリの作成
 				ctx.createSubcontext(ejb.getDn(), attrs);
 	
@@ -329,9 +388,6 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("create() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 			return pk;
 		}
@@ -432,14 +488,11 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		
 		int retryCount=0;	
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
+			
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
 				results = ctx.search(baseDn.toString(), search.toString(), constraints);
 				
 				if (results == null ) {
@@ -507,9 +560,6 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("findAll() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 			
 			return ret;
@@ -525,16 +575,12 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		
 		int retryCount=0;	
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
 			try {
 			    m_log.debug("findByPrimaryKey() : dn = " + pk.getDn());
 			    
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
 				//属性取得
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(pk.getDn());
 				
@@ -585,9 +631,6 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("findByPrimaryKey() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 		}
 		return pk;
@@ -623,14 +666,10 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
 				results = ctx.search(pk.getDn(), search.toString(), constraints);
 				
 				if (results == null ) {
@@ -690,9 +729,6 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("findChildren() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 			return ret;
 		}
@@ -741,14 +777,11 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
+			
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null) {
@@ -817,9 +850,6 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("findScopeByFacilityId() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 	
 			return pk;
@@ -827,10 +857,30 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		return pk;
 	}
 	
-	/* (non-Javadoc)
-	 * @see com.clustercontrol.repository.dao.FacilityTreeDAO#findNodeByFacilityId(java.lang.String)
+	/**
+	 * 
+	 * 引数で指定されたファシリティID, 有効/無効フラグを持つ、
+	 * FacilityTreeのリストを取得する。
+	 * 
+	 * @param facilityId
+	 * @return　facilitytreeのリスト（重複を含む）
+	 * @throws FinderException
 	 */
 	public Collection findByFacilityId(String facilityId) throws FinderException {
+		return findByFacilityId(facilityId, null);
+	}
+	
+	/**
+	 * 
+	 * 引数で指定されたファシリティID, 有効/無効フラグを持つ、
+	 * FacilityTreeのリストを重複を許して取得する。
+	 * 
+	 * @param facilityId
+	 * @param valid
+	 * @return　facilitytreeのリスト（重複を含む）
+	 * @throws FinderException
+	 */
+	public Collection findByFacilityId(String facilityId, Boolean valid) throws FinderException {
 		ArrayList ret = new ArrayList();
 		
 		m_log.debug("findByFacilityId() : FacilityId = " + facilityId);
@@ -852,6 +902,15 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		search.append(FacilityTreeAttributeConstant.FACILITYID);
 		search.append("=");
 		search.append(facilityId);
+		
+		//有効/無効フラグが指定されていれば、検索条件として追加
+		if (valid != null) {
+			search.append(")(");
+			search.append(FacilityTreeAttributeConstant.VALID);
+			search.append("=");
+			search.append(valid.toString().toUpperCase());
+		}
+		
 		search.append("))");
 		
 		//検索実行
@@ -861,14 +920,10 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				timer = TimeKeeperService.start();
-				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null ) {
@@ -928,9 +983,6 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("findByFacilityId() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 
 			return ret;
@@ -1032,15 +1084,10 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
-			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
-				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
-				// タイマースレッドを停止
-				timer = TimeKeeperService.start();
-				
 				results = ctx.search(baseDn.toString(), search.toString(), constraints);
 				
 				if (results == null ) {
@@ -1101,15 +1148,194 @@ public class FacilityTreeDAOImpl implements FacilityTreeDAO {
 				} catch (NamingException e) {
 					m_log.error("findOneLevel() context close failed : " + e.getMessage());
 				}
-				
-				// タイマースレッドを停止
-				TimeKeeperService.stop(timer);
 			}
 	
 			return ret;
 		}
 		return ret;
 	}
+	
+	/**
+	 *　ファシリティツリー配下検索
+	 * facilityId配下に存在するノードのうち、
+	 * 指定された有効/無効フラグを持つファシリティIDのみを取得する
+	 * 
+	 * @version 3.0.0
+	 * @since 3.0.0
+	 * 
+	 * @param facilityId 検索対象のルートとなるファシリティID
+	 * @param valid 有効/無効フラグ
+	 * @return
+	 * @throws FinderException
+	 */
+	public Collection findAllNodeByValid(String facilityId, Boolean valid) throws FinderException {
+		return findNodeListByValid(facilityId, RepositoryControllerBean.ALL, valid);
+	}
+	
+	/**　
+	 * ファシリティツリー直下検索
+	 * facilityId直下に存在するノードのうち、
+	 * 指定された有効/無効フラグを持つファシリティIDのみを取得する
+	 * 
+	 * @version 3.0.0
+	 * @since 3.0.0
+	 * 
+	 * @param facilityId 検索対象のルートとなるファシリティID
+	 * @param valid 有効/無効フラグ
+	 * @return
+	 * @throws FinderException
+	 */
+	public Collection findOneLevelNodeByValid(String facilityId, Boolean valid) throws FinderException {
+		return findNodeListByValid(facilityId, RepositoryControllerBean.ONE_LEVEL, valid);
+	}
+	
+	private Collection findNodeListByValid(String facilityId, int level, Boolean valid) throws FinderException {
+		ArrayList ret = new ArrayList();
+
+		m_log.debug("findAllNodeByValid() : FacilityId = " + facilityId + ", Valid = " + valid);
+		
+		// dn文字列作成
+		StringBuffer baseDn = new StringBuffer();
+		if(facilityId == null || facilityId.compareTo("") == 0){
+			baseDn.append(BASE_DN);
+		}
+		else{
+			try {
+				FacilityTreePK pk = findScopeByFacilityId(facilityId);
+				baseDn.append(pk.getDn());
+			} catch (FinderException e) {
+				
+				m_log.debug("findAllNodeByValid() : No Search Result : FacilityId = " + facilityId + ", Valid = " + valid);
+				m_log.debug("findAllNodeByValid() :" + e.getMessage());
+				return ret;
+			}
+		}
+		
+		// エントリの検索
+		javax.naming.directory.SearchControls constraints = 
+			new javax.naming.directory.SearchControls();
+
+		// BaseDN以下にぶら下がるすべてのレベルを検索の対象
+		if (level == RepositoryControllerBean.ALL)
+			constraints.setSearchScope(javax.naming.directory.SearchControls.SUBTREE_SCOPE);
+		else 
+			constraints.setSearchScope(javax.naming.directory.SearchControls.ONELEVEL_SCOPE);
+		
+		
+		// 検索文字列作成
+		StringBuffer search = new StringBuffer();
+		search.append("(&(");
+		search.append(OBJECTCLASS);
+		search.append("=");
+		search.append(OBJECT_CLASS_FACILITY_TREE);
+		search.append(")(");
+		search.append(FacilityTreeAttributeConstant.TREETYPE);
+		search.append("=");
+		search.append(FacilityConstant.TYPE_NODE);
+		search.append(")(");
+		search.append(FacilityTreeAttributeConstant.VALID);
+		search.append("=");
+		search.append(valid.toString().toUpperCase());
+		search.append("))");
+		
+		//検索実行
+		javax.naming.NamingEnumeration results = null;
+		javax.naming.directory.DirContext ctx = null;
+		
+		int retryCount=0;
+		
+		while(MAX_RETRY > retryCount){
+			try {
+				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
+				results = ctx.search(baseDn.toString(), search.toString(), constraints);
+
+				if (results == null ) {
+					m_log.warn("findAllNodeByValid() : No Search Result : FacilityId = " + facilityId + ", Valid = " + valid);
+					return ret;
+				}
+
+				//検索結果を取得
+				while ( results.hasMoreElements() ) {
+					javax.naming.directory.SearchResult aResult = 
+						(javax.naming.directory.SearchResult)results.nextElement();
+					FacilityTreePK pk = new FacilityTreePK(aResult.getName() + "," + baseDn.toString());
+					ret.add(pk);
+				}
+			} catch (NamingException ex) {
+				if(ex instanceof CommunicationException){
+					LdapConnectionManager.getConnectionManager().setDirContext(null);
+				}
+				m_log.debug("findNodeListByValid() : " + ex.getMessage());
+				// 中身を空にします。
+				ret.clear();
+
+				// whileループの判定の前に、メッソッドを抜けるかのチェックをするため、
+				// ここでカウントアップする。
+				retryCount++;
+				if(retryCount >= MAX_RETRY){
+					throw new EJBException(ex);
+				} else {
+					//リトライ上限以下の場合には再度LDAPに問い合わせをします。
+					//whlie loopに戻ります。
+					continue;
+				}
+
+			} catch (NullPointerException ex){
+				//jreのバグ（？）により、hasMoreElements()でNullPointerExceptionが発生することがある。
+				//根本対処の方法がないため、NullPointerExcetionをcatchする。（2007/06/19　宮本）
+				m_log.debug("findNodeListByValid() : LDAP query result is null");
+				// 中身を空にします。
+				ret.clear();
+
+				// whileループの判定の前に、メッソッドを抜けるかのチェックをするため、
+				// ここでカウントアップする。
+				retryCount++;
+				if(retryCount >= MAX_RETRY){
+					throw new EJBException(ex);
+				} else {
+					//リトライ上限以下の場合には再度LDAPに問い合わせをします。
+					//whlie loopに戻ります。
+					continue;
+				}	
+			} finally {
+				try {
+					if(results != null)
+						results.close();
+					if(ctx != null)
+						ctx.close();
+				} catch (NamingException e) {
+					m_log.error("findNodeListByValid() context close failed : " + e.getMessage());
+				}
+			}
+			return ret;
+		}
+	
+		return ret;
+	}
+	
+	/**
+	 * BooleanをStringに変換する
+	 * 
+	 * @version 1.0.0
+	 * @since 1.0.0
+	 * 
+	 * @param value
+	 * @return
+	 */
+	public String booleanToString(Boolean value) {
+		String ret = null;
+		
+		if(value.booleanValue()){
+			ret = "TRUE";
+		}
+		else{
+			ret = "FALSE";
+		}
+		
+		return ret;
+	}
+
+	
 	/**
 	 * Beanクリア処理
 	 * 
