@@ -23,23 +23,32 @@ import java.util.Locale;
 import javax.ejb.FinderException;
 import javax.naming.NamingException;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.PropertyConstant;
 import com.clustercontrol.bean.SnmpVersionConstant;
+import com.clustercontrol.repository.ejb.entity.CollectorPlatformMstLocal;
+import com.clustercontrol.repository.ejb.entity.CollectorPlatformMstUtil;
 import com.clustercontrol.repository.ejb.entity.DeviceInfoLocal;
 import com.clustercontrol.repository.ejb.entity.FacilityLocal;
+import com.clustercontrol.repository.ejb.entity.FacilityUtil;
 import com.clustercontrol.repository.ejb.entity.FileSystemInfoLocal;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PropertyUtil;
 
 /**
  * ノード用プロパティを作成するクラス<BR>
- *
+ * 
  * @version 1.0.0
  * @since 1.0.0
  */
 public class NodeProperty {
+	
+	private static Log m_log = LogFactory.getLog(NodeProperty.class);
+	
 	/** ファシリティID */
 	public static final String FACILITY_ID = "facilityId";
 	/** ファシリティ名 */
@@ -140,6 +149,22 @@ public class NodeProperty {
 	/** SNMP */
 	public static final String SNMP ="snmp";
 	
+	/** 有効/無効フラグ */
+	public static final String VALID = "valid";
+	
+	public static final String SNMPTIMEOUT = "snmpTimeout"; 
+	public static final String SNMPRETRIES= "snmpRetries";
+	public static final String SNMPPROXY= "snmpProxy";
+	public static final String NOTE= "note";
+	public static final String ICONIMAGE= "iconImage";
+	
+	public static final String VIRTUALIZATION = "virtualization";
+	public static final String VIRTNODETYPE= "virtualizationNodeType";
+	public static final String VMMANAGEMENTNODE= "vMManagementNode";
+	public static final String VMINDEX= "VMINDEX";
+	public static final String VMNAME= "VMName";
+	public static final String VIRTSOLUTION= "virtualizationSolution";
+	
 	/**
 	 * ノード用プロパティを返します。
 	 * 
@@ -170,6 +195,13 @@ public class NodeProperty {
 				if(facility.getDescription() != null && facility.getDescription().compareTo("") != 0){
 					((Property)propertyList.get(0)).setValue(facility.getDescription());
 				}
+				
+				//有効/無効フラグ
+				propertyList = PropertyUtil.getProperty(property, VALID);
+				if(facility.getValid() != null) {
+					((Property)propertyList.get(0)).setValue(facility.getValid());
+				}				
+				
 //				//エージェント制御
 //				propertyList = PropertyUtil.getProperty(property, AGENT_CONTROL);
 //				if(facility.getAgentControl() != null){
@@ -308,7 +340,7 @@ public class NodeProperty {
 //				}
 				//プラットフォーム
 				propertyList = PropertyUtil.getProperty(property, PLATFORM_FAMILY_NAME);
-				if(facility.getPlatform() != null && facility.getPlatform().compareTo("") != 0){
+				if(facility.getPlatform() != null){
 					((Property)propertyList.get(0)).setValue(facility.getPlatform());
 				}
 //				//ステータス監視
@@ -334,6 +366,80 @@ public class NodeProperty {
 					((Property)propertyList.get(0)).setValue(facility.getSnmpVersion());
 				}
 				
+				//SNMPタイムアウト
+				propertyList = PropertyUtil.getProperty(property, SNMPTIMEOUT);
+				if(facility.getSnmpTimeout() != null){
+					((Property)propertyList.get(0)).setValue(facility.getSnmpTimeout());
+				}
+				
+				//SNMPリトライ回数
+				propertyList = PropertyUtil.getProperty(property, SNMPRETRIES);
+				if(facility.getSnmpRetries() != null){
+					((Property)propertyList.get(0)).setValue(facility.getSnmpRetries());
+				}
+				
+				//SNMPプロキシ
+				propertyList = PropertyUtil.getProperty(property, SNMPPROXY);
+				if(facility.getSnmpProxy() != null){
+					((Property)propertyList.get(0)).setValue(facility.getSnmpProxy());
+				}
+				
+				//備考
+				propertyList = PropertyUtil.getProperty(property, NOTE);
+				Property parentNote = (Property)((Property)propertyList.get(0)).getParent();
+				if(facility.getNote() != null){
+					int index = PropertyUtil.getPropertyIndex(parentNote, (Property)propertyList.get(0));
+					for(int i = 0; i < facility.getNote().size(); i++){
+						if(i == 0){
+							((Property)propertyList.get(0)).setValue(facility.getNote().get(i));
+						}
+						else{
+							Property copy = PropertyUtil.copy((Property)propertyList.get(0));
+							
+							((Property)propertyList.get(0)).setValue(facility.getNote().get(i));
+							
+							parentNote.addChildren(copy, index + i);
+						}
+					}
+				}
+				
+				//画面アイコンイメージ
+				propertyList = PropertyUtil.getProperty(property, ICONIMAGE);
+				if(facility.getIconImage() != null){
+					((Property)propertyList.get(0)).setValue(facility.getIconImage());
+				}
+				
+				//仮想化ノード種別
+				propertyList = PropertyUtil.getProperty(property, VIRTNODETYPE);
+				if(facility.getVirtNodeType() != null){
+					((Property)propertyList.get(0)).setValue(facility.getVirtNodeType());
+				}
+				
+				//仮想マシン管理ノード
+				propertyList = PropertyUtil.getProperty(property, VMMANAGEMENTNODE);
+				if(facility.getVMManagementNode() != null){
+					((Property)propertyList.get(0)).setValue(facility.getVMManagementNode());
+				}
+				
+				//仮想マシンID
+				propertyList = PropertyUtil.getProperty(property, VMINDEX);
+				if(facility.getVmIndex() != null){
+					((Property)propertyList.get(0)).setValue(facility.getVmIndex());
+				}
+				
+				//仮想マシン名
+				propertyList = PropertyUtil.getProperty(property, VMNAME);
+				if(facility.getVmName() != null){
+					((Property)propertyList.get(0)).setValue(facility.getVmName());
+				}
+				
+				//仮想化ソリューション
+				propertyList = PropertyUtil.getProperty(property, VIRTSOLUTION);
+				if(facility.getVirtSolution() != null){
+					((Property)propertyList.get(0)).setValue(facility.getVirtSolution());
+				}
+				
+				
 				//デバイス
 				propertyList = PropertyUtil.getProperty(property, DEVICE);
 				Property deviceProperty = (Property)propertyList.get(0);
@@ -514,7 +620,7 @@ public class NodeProperty {
 	 * @param mode
 	 * @return ノード用プロパティ
 	 */
-	public Property getProperty(int mode, Locale locale) {
+	public Property getProperty(int mode, Locale locale) throws FinderException, NamingException {
 	    //ファシリティID
 		Property facilityId =
 			new Property(FACILITY_ID, Messages.getString("facility.id", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
@@ -524,6 +630,11 @@ public class NodeProperty {
 		//説明
 		Property description =
 			new Property(DESCRIPTION, Messages.getString("description", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
+		
+		//有効/無効
+		Property valid =
+			new Property(VALID, Messages.getString("management.object", locale), PropertyConstant.EDITOR_BOOL);
+		
 //		//PING監視
 //		Property pingMonitoring =
 //			new Property(PING_MONITOR, Messages.getString("ping.monitor", local), PropertyConstant.EDITOR_BOOL);
@@ -553,7 +664,7 @@ public class NodeProperty {
 			new Property(IP_ADDRESS_TYPE, Messages.getString("ip.address.type", locale), PropertyConstant.EDITOR_NUM, DataRangeConstant.SMALLINT_HIGH, 0);
 		//IPバージョン
 		Property ipAddressVersion =
-			new Property(IP_ADDRESS_VERSION, Messages.getString("ip.address.version", locale), PropertyConstant.EDITOR_NUM, DataRangeConstant.SMALLINT_HIGH, 0);
+			new Property(IP_ADDRESS_VERSION, Messages.getString("ip.address.version", locale), PropertyConstant.EDITOR_VERSION);
 		//IPアドレスV4
 		Property ipAddressV4 =
 			new Property(IP_ADDRESS_V4, Messages.getString("ip.address.v4", locale), PropertyConstant.EDITOR_IPV4);
@@ -568,7 +679,7 @@ public class NodeProperty {
 			new Property(HARDWARE_TYPE, Messages.getString("hardware.type", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 		//プラットフォーム
 		Property platformFamilyName =
-			new Property(PLATFORM_FAMILY_NAME, Messages.getString("platform.family.name", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
+			new Property(PLATFORM_FAMILY_NAME, Messages.getString("platform.family.name", locale), PropertyConstant.EDITOR_SELECT);
 		//OS名
 		Property osName =
 			new Property(OS_NAME, Messages.getString("os.name", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
@@ -663,11 +774,57 @@ public class NodeProperty {
 		//SNMP
 		Property snmp =
 			new Property(SNMP, Messages.getString("snmp", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
+
+		//SNMPタイムアウト
+		Property snmpTimeout =
+			new Property(SNMPTIMEOUT, Messages.getString("snmp.timeout", locale), PropertyConstant.EDITOR_NUM, Integer.MAX_VALUE, 0);
+
+		//SNMPリトライ回数
+		Property snmpRetries = 
+			new Property(SNMPRETRIES, Messages.getString("snmp.retries", locale), PropertyConstant.EDITOR_NUM, Integer.MAX_VALUE, 0);
+
+		//SNMPプロキシ
+		Property snmpProxy = 
+			new Property(SNMPPROXY, Messages.getString("snmp.proxy", locale), PropertyConstant.EDITOR_SELECT);
+
+		//備考
+		Property note =
+			new Property(NOTE, Messages.getString("note", locale), PropertyConstant.EDITOR_TEXTAREA, DataRangeConstant.TEXT);
+		
+		//画面アイコンイメージ
+		Property iconImage =
+			new Property(ICONIMAGE, Messages.getString("icon.image", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
+		
+		Property virtualization = 
+			new Property(VIRTUALIZATION, Messages.getString("virtualization", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
+		
+		
+		//仮想化ノード種別
+		Property virtNodeType =
+			new Property(VIRTNODETYPE, Messages.getString("virtualization.node.type", locale), PropertyConstant.EDITOR_SELECT);
+		
+		//仮想マシン管理ノード
+		Property vmManagementNode =
+			new Property(VMMANAGEMENTNODE, Messages.getString("vm.management.node", locale), PropertyConstant.EDITOR_SELECT);
+		
+		//仮想マシンID
+		Property vmIndex =
+			new Property(VMINDEX, Messages.getString("vm.index", locale), PropertyConstant.EDITOR_NUM, Integer.MAX_VALUE, 0);
+		//仮想マシン名
+		Property vmName =
+			new Property(VMNAME, Messages.getString("vm.name", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
+		//仮想化ソリューション
+		Property virtSolution =
+			new Property(VIRTSOLUTION, Messages.getString("virtualization.solution", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
+
+		
+		
 		
 		//値を初期化
 		facilityId.setValue("");
 		facilityName.setValue("");
 		description.setValue("");
+		valid.setValue(new Boolean(true));
 //		pingMonitoring.setValue(new Boolean(false));
 //		pingMonitoringStatus.setValue("");
 //		agentMonitoring.setValue(new Boolean(false));
@@ -682,7 +839,10 @@ public class NodeProperty {
 		ipAddressV6.setValue("");
 		hostName.setValue("");
 		hardwareType.setValue("");
+		
+		platformFamilyName.setSelectValues(getPlatformNames());
 		platformFamilyName.setValue("");
+		
 		osName.setValue("");
 		nodeName.setValue("");
 		osRelease.setValue("");
@@ -722,12 +882,39 @@ public class NodeProperty {
 		device.setValue("");
 		fileSystem.setValue("");
 		snmp.setValue("");
+		
+		snmpProxy.setSelectValues(getFacilityIdAndFacilityName());
+		snmpProxy.setValue("");
+		snmpTimeout.setValue("");
+		snmpRetries.setValue("");
+		snmpPort.setValue("");
+		
+		note.setValue("");
+		
+		iconImage.setValue("");
+		
+		virtNodeType.setValue("");
+		Object vmNodeTypeValue[][] = {
+				{ "", "host", "guest" },
+				{ "", "host", "guest" }
+		};
+		
+		virtualization.setValue("");
+		virtNodeType.setSelectValues(vmNodeTypeValue);
+		virtNodeType.setValue("");
+		vmManagementNode.setSelectValues(getFacilityIdAndFacilityName());
+		vmManagementNode.setValue("");
+		vmIndex.setValue("");
+		vmName.setValue("");
+		virtSolution.setValue("");
+	
 
 		//モードにより、変更可及びコピー可を設定
 		if(mode == PropertyConstant.MODE_ADD){
 			facilityId.setModify(PropertyConstant.MODIFY_OK);
 			facilityName.setModify(PropertyConstant.MODIFY_OK);
 			description.setModify(PropertyConstant.MODIFY_OK);
+			valid.setModify(PropertyConstant.MODIFY_OK);
 //			pingMonitoring.setModify(PropertyConstant.MODIFY_OK);
 //			agentMonitoring.setModify(PropertyConstant.MODIFY_OK);
 //			agentMonitoringStatus.setModify(PropertyConstant.MODIFY_OK);
@@ -766,13 +953,30 @@ public class NodeProperty {
 			snmpCommunity.setModify(PropertyConstant.MODIFY_OK);
 			snmpVersion.setModify(PropertyConstant.MODIFY_OK);
 			
+			snmpTimeout.setModify(PropertyConstant.MODIFY_OK);
+			snmpRetries.setModify(PropertyConstant.MODIFY_OK);
+			snmpProxy.setModify(PropertyConstant.MODIFY_OK);
+			
+			note.setModify(PropertyConstant.MODIFY_OK);
+			
+			iconImage.setModify(PropertyConstant.MODIFY_OK);
+
+			virtNodeType.setModify(PropertyConstant.MODIFY_OK);
+			vmManagementNode.setModify(PropertyConstant.MODIFY_OK);
+			vmIndex.setModify(PropertyConstant.MODIFY_OK);
+			vmName.setModify(PropertyConstant.MODIFY_OK);
+			virtSolution.setModify(PropertyConstant.MODIFY_OK);
+			
 			hostName.setCopy(PropertyConstant.COPY_OK);
+			note.setCopy(PropertyConstant.COPY_OK);
+			note.setModify(PropertyConstant.MODIFY_OK);
 			device.setCopy(PropertyConstant.COPY_OK);
 			fileSystem.setCopy(PropertyConstant.COPY_OK);
 		}
 		else if(mode == PropertyConstant.MODE_MODIFY){
 			facilityName.setModify(PropertyConstant.MODIFY_OK);
 			description.setModify(PropertyConstant.MODIFY_OK);
+			valid.setModify(PropertyConstant.MODIFY_OK);
 //			pingMonitoring.setModify(PropertyConstant.MODIFY_OK);
 //			agentMonitoring.setModify(PropertyConstant.MODIFY_OK);
 //			agentMonitoringStatus.setModify(PropertyConstant.MODIFY_OK);
@@ -811,7 +1015,23 @@ public class NodeProperty {
 			snmpCommunity.setModify(PropertyConstant.MODIFY_OK);
 			snmpVersion.setModify(PropertyConstant.MODIFY_OK);
 			
+			snmpTimeout.setModify(PropertyConstant.MODIFY_OK);
+			snmpRetries.setModify(PropertyConstant.MODIFY_OK);
+			snmpProxy.setModify(PropertyConstant.MODIFY_OK);
+			
+			note.setModify(PropertyConstant.MODIFY_OK);
+			
+			iconImage.setModify(PropertyConstant.MODIFY_OK);
+
+			virtNodeType.setModify(PropertyConstant.MODIFY_OK);
+			vmManagementNode.setModify(PropertyConstant.MODIFY_OK);
+			vmIndex.setModify(PropertyConstant.MODIFY_OK);
+			vmName.setModify(PropertyConstant.MODIFY_OK);
+			virtSolution.setModify(PropertyConstant.MODIFY_OK);
+			
 			hostName.setCopy(PropertyConstant.COPY_OK);
+			note.setCopy(PropertyConstant.COPY_OK);
+			note.setModify(PropertyConstant.MODIFY_OK);
 			device.setCopy(PropertyConstant.COPY_OK);
 			fileSystem.setCopy(PropertyConstant.COPY_OK);
 		}
@@ -823,8 +1043,13 @@ public class NodeProperty {
 		property.addChildren(facilityId);
 		property.addChildren(facilityName);
 		property.addChildren(description);
+		property.addChildren(platformFamilyName);
+		property.addChildren(hardwareType);
+		property.addChildren(iconImage);
+		property.addChildren(valid);
 		property.addChildren(network);
 		property.addChildren(os);
+		property.addChildren(virtualization);
 		property.addChildren(maintenance);
 		property.addChildren(device);
 		property.addChildren(fileSystem);
@@ -832,6 +1057,7 @@ public class NodeProperty {
 		property.addChildren(creatorName);
 		property.addChildren(modifyTime);
 		property.addChildren(modifierName);
+		property.addChildren(note);
 		
 		// ネットワークツリー
 		network.removeChildren();
@@ -849,11 +1075,15 @@ public class NodeProperty {
 		network.addChildren(ipAddressV4);
 		network.addChildren(ipAddressV6);
 		network.addChildren(hostName);
-
+		
 		snmp.removeChildren();
 		snmp.addChildren(snmpPort);
 		snmp.addChildren(snmpCommunity);
 		snmp.addChildren(snmpVersion);
+		snmp.addChildren(snmpTimeout);
+		snmp.addChildren(snmpRetries);
+		snmp.addChildren(snmpProxy);
+
 		
 		// OSツリー
 		os.removeChildren();
@@ -861,10 +1091,17 @@ public class NodeProperty {
 		os.addChildren(osName);
 		os.addChildren(osRelease);
 		os.addChildren(osVersion);
-		os.addChildren(platformFamilyName);
-		os.addChildren(hardwareType);
 		os.addChildren(characterSet);
 		
+		
+		// 仮想化ツリー
+		virtualization.removeChildren();
+		virtualization.addChildren(virtNodeType);
+		virtualization.addChildren(vmManagementNode);
+		virtualization.addChildren(vmIndex);
+		virtualization.addChildren(vmName);
+		virtualization.addChildren(virtSolution);
+		
 		// 保守ツリー
 		maintenance.removeChildren();
 		maintenance.addChildren(administrator);
@@ -889,4 +1126,98 @@ public class NodeProperty {
 
 		return property;
 	}
+	
+	
+	/**
+	 * 
+	 * コンボボックス表示のためのプラットフォームID, プラットフォーム名を返すメソッド
+	 * 返り値は下記の構成の２次元配列である。
+	 * 
+	 * {{value1, value2, ...}, {DisplayText1, DisplayText2, ...}}
+	 * 
+	 * value		：　プラットフォームID
+	 * DisplayText	：　プラットフォーム名
+	 * 
+	 * 値をセットするメソッドの引数がObject型の２次元配列のため、その形式で返す
+	 * 
+	 * @return オブジェクト配列
+	 */
+	private Object[][] getPlatformNames() throws FinderException, NamingException {
+		Object[][] ret = null;
+		
+		try {
+			Collection platforms = CollectorPlatformMstUtil.getLocalHome().findAll();
+			Iterator iterator = platforms.iterator();
+			
+			ArrayList<String> platformIdList = new ArrayList();
+			ArrayList<String> platformNameList = new ArrayList();
+			
+			while(iterator.hasNext()) {
+				CollectorPlatformMstLocal platform = (CollectorPlatformMstLocal) iterator.next();
+				platformIdList.add(platform.getPlatformId());
+				platformNameList.add(platform.getPlatformName() + "(" + platform.getPlatformId() + ")");
+			}
+			
+			ret = new Object[2][platformIdList.size()];
+			ret[PropertyConstant.SELECT_VALUE] = platformIdList.toArray();
+			ret[PropertyConstant.SELECT_DISP_TEXT] = platformNameList.toArray();
+			
+		} catch (FinderException e) {
+			m_log.error("getPlatformNames() : findAllNode failure ", e);
+			throw e;
+		} catch (NamingException e) {
+			m_log.error("getPlatformNames() : FacilityUtil.getLocalHome() failure ", e);
+			throw e;
+		}
+
+		
+		
+		return ret;
+	}
+	
+	/**
+	 * 
+	 * コンボボックス表示のためのファシリティID, ファシリティ名を返すメソッド
+	 * 返り値は下記の構成の２次元配列である。
+	 * 
+	 * {{value1, value2, ...}, {DisplayText1, DisplayText2, ...}}
+	 * 
+	 * value		：　ファシリティID
+	 * DisplayText	：　ファシリティ名(ファシリティID)
+	 * 
+	 * 値をセットするメソッドの引数がObject型の２次元配列のため、その形式で返す
+	 * 
+	 * @return オブジェクト配列
+	 */
+	private Object[][] getFacilityIdAndFacilityName() throws FinderException, NamingException {
+		
+		Object[][] ret = null;
+		
+		try {
+			Collection nodes = FacilityUtil.getLocalHome().findAllNode();
+			Iterator iterator = nodes.iterator();
+			ArrayList<String> facilityIdList = new ArrayList();
+			ArrayList<String> facilityNameList = new ArrayList();
+			facilityIdList.add("");
+			facilityNameList.add("");
+			while (iterator.hasNext()) {
+				FacilityLocal facility = (FacilityLocal)iterator.next();
+				facilityIdList.add(facility.getFacilityId());
+				facilityNameList.add(facility.getCn() + "(" + facility.getFacilityId() + ")" );
+			}
+			
+			ret = new Object[2][facilityIdList.size()];
+			ret[PropertyConstant.SELECT_VALUE] = facilityIdList.toArray();
+			ret[PropertyConstant.SELECT_DISP_TEXT] = facilityNameList.toArray();
+			
+		} catch (FinderException e) {
+			m_log.error("getFacilityIdAndFacilityName() : findAllNode failure ", e);
+			throw e;
+		} catch (NamingException e) {
+			m_log.error("getFacilityIdAndFacilityName() : FacilityUtil.getLocalHome() failure ", e);
+			throw e;
+		}
+		
+		return ret;
+	}
 }
