@@ -28,15 +28,16 @@ import javax.naming.NamingException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.bean.MonitorConstant;
+import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.monitor.run.bean.MonitorNumericValueInfo;
 import com.clustercontrol.monitor.run.ejb.entity.MonitorInfoLocal;
 import com.clustercontrol.monitor.run.ejb.entity.MonitorInfoPK;
 import com.clustercontrol.monitor.run.ejb.entity.MonitorInfoUtil;
-import com.clustercontrol.monitor.run.ejb.entity.MonitorNumericValueInfoLocal;
-import com.clustercontrol.monitor.run.ejb.entity.MonitorNumericValueInfoUtil;
+import com.clustercontrol.monitor.run.factory.SelectSchedule;
+import com.clustercontrol.notify.ejb.session.NotifyControllerLocal;
+import com.clustercontrol.notify.ejb.session.NotifyControllerUtil;
 import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
@@ -60,7 +61,7 @@ import com.clustercontrol.util.apllog.AplLogger;
 /**
  * 監視情報検索クラス
  *
- * @version 2.1.0
+ * @version 3.0.0
  * @since 2.1.0
  */
 public class SelectMonitorInfo {
@@ -88,29 +89,35 @@ public class SelectMonitorInfo {
 						new SnmpTrapInfoPK(monitorId));
 	
 			
+			//監視設定（共通）の情報を取得
 			MonitorInfoPK mipk = new MonitorInfoPK(info.getMonitorId(),
-													MonitorConstant.STRING_SNMPTRAP);
-			
+					HinemosModuleConstant.MONITOR_SNMPTRAP);
 		    MonitorInfoLocal infoLocal = MonitorInfoUtil.getLocalHome().findByPrimaryKey(mipk);
 			
+		    
 			// スコープの取得
 			String facilityPath = repository.getFacilityPath(info.getFacilityId(), null);
 			
 			
+			//通知情報の取得
+			NotifyControllerLocal nc = NotifyControllerUtil.getLocalHome().create();
+			Collection notifyId = nc.getNotifyRelation(infoLocal.getNotifyGroupId());
+		
+			
 			monitorInfo = new MonitorSnmpTrapInfo();
 			
 			//FIXME
 			/* Monitor情報から何をロードすべきかわからないのでとりあえずのnotNull
 			 * の項目のみを埋めておく*/
 			monitorInfo.setMonitorType(infoLocal.getMonitorType());
-			monitorInfo.setMonitorTypeId(MonitorConstant.STRING_SNMPTRAP);
+			monitorInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_SNMPTRAP);
 			
 			monitorInfo.setMonitorId(info.getMonitorId());
 			monitorInfo.setDescription(info.getDescription());
 			monitorInfo.setFacilityId(info.getFacilityId());
 			monitorInfo.setScope(facilityPath);
 			monitorInfo.setCommunityName(info.getCommunityName());
-			monitorInfo.setNotifyId(info.getNotifyId());
+			monitorInfo.setNotifyGroupId(info.getNotifyGroupId());
 			monitorInfo.setApplication(info.getApplication());
 			monitorInfo.setValid(info.getValidFlg().intValue());
 			monitorInfo.setCalendarId(info.getCalendarId());
@@ -119,6 +126,7 @@ public class SelectMonitorInfo {
 			monitorInfo.setRegUser(info.getRegUser());
 			monitorInfo.setUpdateUser(info.getUpdateUser());
 			monitorInfo.setCheckMode(info.getCheckMode());
+			monitorInfo.setNotifyId(notifyId);
 			
 			// 監視OID情報取得
 			Collection oids = info.getSnmpTrapOidInfo();
@@ -177,13 +185,13 @@ public class SelectMonitorInfo {
 		
 		// 監視情報（cc_monitor_info）から、ジョブ実行フラグのみを取得
 		try{
-			MonitorInfoPK mipk = new MonitorInfoPK(monitorId, MonitorConstant.STRING_SNMPTRAP);
+			MonitorInfoPK mipk = new MonitorInfoPK(monitorId, HinemosModuleConstant.MONITOR_SNMPTRAP);
 			MonitorInfoLocal infoLocal = MonitorInfoUtil.getLocalHome().findByPrimaryKey(mipk);
-			monitorInfo.setJobRun(infoLocal.getJobRun());
+			
 			
 			// c_monitor_numeric_value_infoテーブルからジョブ連動の情報取得
-			Collection ct = MonitorNumericValueInfoUtil.getLocalHome().
-			findByMonitorTypeIdAndMonitorId(MonitorConstant.STRING_SNMPTRAP, monitorId);
+			/*Collection ct = MonitorNumericValueInfoUtil.getLocalHome().
+			findByMonitorTypeIdAndMonitorId(HinemosModuleConstant.MONITOR_SNMPTRAP, monitorId);
 			Iterator itr = ct.iterator();
 			
 			ArrayList<MonitorNumericValueInfo> valueList = new ArrayList<MonitorNumericValueInfo>();
@@ -198,23 +206,19 @@ public class SelectMonitorInfo {
 						local.getMonitorTypeId(),
 						local.getPriority(),
 						local.getThresholdLowerLimit(),
-						local.getThresholdUpperLimit(),
-						local.getJobRun(),
-						local.getJobId(),
-						local.getJobInhibitionFlg(),
-						local.getJobFailurePriority());
+						local.getThresholdUpperLimit());
 				valueList.add(value);
 			}
 			if(valueList.size() != 0){
 				monitorInfo.setJudgementInfo(valueList);
-			}
+			}*/
 		} catch (FinderException e) {
 			// ジョブ連携の定義がDBに登録されていない場合は、ジョブ連携情報を付加しない
 			// ver2.2.1まではSNMPトラップ監視機能でのジョブ連携が実装されておらず、
 			// SNMPトラップ監視機能で、cc_monitor_infoとcc_monitor_numeric_value_infoテーブルを
 			// 利用していないため、ver2.2.1から移行されたDBでは、このルートを通る
 			m_log.warn("getMonitorInfo():" + " MonitorInfo not found '" + monitorId + "', " + e.getMessage());
-			monitorInfo.setJobRun(YesNoConstant.TYPE_NO);
+			//monitorInfo.setJobRun(YesNoConstant.TYPE_NO);
 		}
 		
 		return monitorInfo;
@@ -475,24 +479,37 @@ public class SelectMonitorInfo {
 				snmpTrapInfo.setFacilityId(facilityId);
 				
 				ArrayList<String> facilityIdList = null;
+				
+				if (facilityId.equals(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE)) {
+					// 自分自身を登録
+					// see com.clustercontrol.snmptrap.factory.TrapSNMP.snmpReceivedTrap
+					facilityIdList = repository.getExecTargetFacilityIdList(FacilityTreeAttributeConstant.REGISTEREFD_SCOPE);
+				} else {
+					facilityIdList = repository.getExecTargetFacilityIdList(facilityId);
+				}
+				
 				//指定のファシリティIDがノードならば、自分自身をトラップ受信対象の
 				//ファシリティに登録
+//				
+//				if(repository.isNode(facilityId)){
+//					facilityIdList = new ArrayList<String>();
+//					facilityIdList.add(facilityId);
+//				}
+//				//未登録ノードスコープの場合　
+//				else if(facilityId.equals(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE) ){
+//					
+//					//自分自身を登録
+//					//see com.clustercontrol.snmptrap.factory.TrapSNMP.snmpReceivedTrap
+//					facilityIdList = new ArrayList<String>();
+//					facilityIdList = repository.getNodeFacilityIdList(FacilityTreeAttributeConstant.REGISTEREFD_SCOPE, RepositoryControllerBean.ALL);
+//				}
+//				else{
+//					facilityIdList = repository.getNodeFacilityIdList(facilityId, RepositoryControllerBean.ALL);
+//				}
+				
+				
+				
 				
-				if(repository.isNode(facilityId)){
-					facilityIdList = new ArrayList<String>();
-					facilityIdList.add(facilityId);
-				}
-				//未登録ノードスコープの場合　
-				else if(facilityId.equals(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE) ){
-					
-					//自分自身を登録
-					//see com.clustercontrol.snmptrap.factory.TrapSNMP.snmpReceivedTrap
-					facilityIdList = new ArrayList<String>();
-					facilityIdList = repository.getNodeFacilityIdList(FacilityTreeAttributeConstant.REGISTEREFD_SCOPE, RepositoryControllerBean.ALL);
-				}
-				else{
-					facilityIdList = repository.getNodeFacilityIdList(facilityId, RepositoryControllerBean.ALL);
-				}
 				snmpTrapInfo.setFacilityIdList(facilityIdList);
 				
 				snmpTrapInfo.setCommunityName(info.getCommunityName());
@@ -593,22 +610,38 @@ public class SelectMonitorInfo {
 					
 					
 					//配下のノードたちのfacilityIDを格納（ダイアログ設定でノードの場合には自分自身）
-					ArrayList<String> facilityIdList = null;
-					if(repository.isNode(facilityId)){
-						facilityIdList = new ArrayList();
-						facilityIdList.add(facilityId);
-					}else if(facilityId.equals(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE)){
-						
-						//未登録ノードスコープの時は自分を検索対象ファシリティにします。
-//						see com.clustercontrol.snmptrap.factory.TrapSNMP.snmpReceivedTrap
-						facilityIdList = new ArrayList<String>();
-						/*登録ノードをはじくために登録済みノードすべてのリストを追加*/
-						facilityIdList = repository.getNodeFacilityIdList(FacilityTreeAttributeConstant.REGISTEREFD_SCOPE, RepositoryControllerBean.ALL);
 					
+					ArrayList<String> facilityIdList = null;
+					
+					if (facilityId.equals(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE)) {
+						// 未登録ノードスコープの時は自分を検索対象ファシリティにします。
+						// see com.clustercontrol.snmptrap.factory.TrapSNMP.snmpReceivedTrap
+						// 登録ノードをはじくために登録済みノードすべてのリストを追加
+						facilityIdList = repository.getExecTargetFacilityIdList(FacilityTreeAttributeConstant.REGISTEREFD_SCOPE);
+					} else {
+						facilityIdList = repository.getExecTargetFacilityIdList(facilityId);
 					}
-					else{
-						facilityIdList = repository.getNodeFacilityIdList(facilityId, RepositoryControllerBean.ALL);
-					}
+					
+//					ArrayList<String> facilityIdList = null;
+//					if(repository.isNode(facilityId)){
+//						facilityIdList = new ArrayList();
+//						facilityIdList.add(facilityId);
+//					}else if(facilityId.equals(FacilityTreeAttributeConstant.UNREGISTEREFD_SCOPE)){
+//						
+//						//未登録ノードスコープの時は自分を検索対象ファシリティにします。
+////						see com.clustercontrol.snmptrap.factory.TrapSNMP.snmpReceivedTrap
+//						facilityIdList = new ArrayList<String>();
+//						/*登録ノードをはじくために登録済みノードすべてのリストを追加*/
+//						facilityIdList = repository.getNodeFacilityIdList(FacilityTreeAttributeConstant.REGISTEREFD_SCOPE, RepositoryControllerBean.ALL);
+//					
+//					}
+//					else{
+//						facilityIdList = repository.getNodeFacilityIdList(facilityId, RepositoryControllerBean.ALL);
+//					}
+					
+					
+					
+					
 					snmpTrapInfo.setFacilityIdList(facilityIdList);
 					
 					
