@@ -103,6 +103,25 @@ public class TrapSnmpManager {
 	/** リポジトリ情報 */
 	protected RepositoryControllerLocal m_repository;
 	
+	/**
+	 * 待ち受けホスト名
+	 */
+	private String m_host;
+	
+	/**
+	 * 待ち受けポート番号
+	 */
+	private int m_port = 162;
+	
+	/**
+	 * コンストラクタ
+	 * @param port 待ち受けポート番号
+	 */
+	public TrapSnmpManager(String host, int port){
+		m_host = host;
+		m_port = port;
+	}
+	
 	/**
 	 * 開始処理
 	 */
@@ -693,4 +712,21 @@ public class TrapSnmpManager {
 		}
 		return null;
 	}
+	
+	/**
+	 * 待ち受けポート番号を取得
+	 *
+	 * @return 待ち受けポート番号
+	 */
+	public int getPort(){
+		return m_port;
+	}
+
+	/**
+	 * ホスト名を取得
+	 * @return ホスト名
+	 */
+	public String getHost() {
+		return m_host;
+	}
 }
\ No newline at end of file
